@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.36 $
+//$Revision: 1.38 $
 #include "hk_button.h"
 #include "hk_form.h"
 #include "hk_database.h"
@@ -74,7 +74,7 @@ class hk_buttonmodeprivate
 
 
 
-hk_button::hk_button(hk_form* form):hk_dsvisible(form)
+hk_button::hk_button(hk_form* frm):hk_dsvisible(frm)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_button::hk_button");
@@ -150,10 +150,10 @@ bool    hk_button::push_action(void)
             hk_actionquery* a= datasource()->database()->new_actionquery();
             if (a)
             {
-                hk_string query=u2l(datasource()->database()->load(p_object,ft_query));
+                hk_string querystring=u2l(datasource()->database()->load(p_object,ft_query));
                 hk_string sql;
-                get_tagvalue(query,"DATASOURCE",query);
-                get_tagvalue(query,"SQL",sql);
+                get_tagvalue(querystring,"DATASOURCE",querystring);
+                get_tagvalue(querystring,"SQL",sql);
 
                 a->set_sql(sql.c_str(),sql.size());
                 bool res= a->execute();
@@ -179,54 +179,54 @@ bool    hk_button::push_action(void)
 }
 
 
-void hk_button::set_action(const hk_string& action,const hk_string& object,bool showmaximized, bool registerchange)
+void hk_button::set_action(const hk_string& actionstring,const hk_string& objectname,bool showmaximized, bool registerchange)
 {
 #ifdef HK_DEBUG
-    hkdebug("hk_button::set_action ",action);
-    hkdebug("object: ",object);
+    hkdebug("hk_button::set_action ",actionstring);
+    hkdebug("object: ",objectname);
 #endif
     long int a=-1;
-    if (action=="open_form") a=0;
+    if (actionstring=="open_form") a=0;
     else
-    if (action=="close_form") a=1;
+    if (actionstring=="close_form") a=1;
         else
-        if (action=="open_table") a=2;
+        if (actionstring=="open_table") a=2;
             else
-            if (action=="open_query") a=3;
+            if (actionstring=="open_query") a=3;
                 else
-                if (action=="preview_report") a=4;
+                if (actionstring=="preview_report") a=4;
                     else
-                    if (action=="print_report") a=5;
+                    if (actionstring=="print_report") a=5;
                         else
-                        if (action=="goto_firstrow") a=6;
+                        if (actionstring=="goto_firstrow") a=6;
                             else
-                            if (action=="goto_lastrow") a=7;
+                            if (actionstring=="goto_lastrow") a=7;
                                 else
-                                if (action=="goto_nextrow") a=8;
+                                if (actionstring=="goto_nextrow") a=8;
                                     else
-                                    if (action=="goto_previousrow") a=9;
+                                    if (actionstring=="goto_previousrow") a=9;
                                         else
-                                        if (action=="insert_row") a=10;
+                                        if (actionstring=="insert_row") a=10;
                                             else
-                                            if (action=="delete_row") a=11;
+                                            if (actionstring=="delete_row") a=11;
                                                 else
-                                                if (action=="store_row") a=12;
+                                                if (actionstring=="store_row") a=12;
                                                     else
-                                                    if (action=="action_query") a=13;
+                                                    if (actionstring=="action_query") a=13;
 						    else
-						    if (action=="close_application") a=14;
+						    if (actionstring=="close_application") a=14;
 						    else
-						    if (action=="open_view") a=15;
+						    if (actionstring=="open_view") a=15;
 
-  set_action(a,object,showmaximized,registerchange);
+  set_action(a,objectname,showmaximized,registerchange);
 
 }
 
 
-void hk_button::set_action(long action,const hk_string& object,bool showmaximized,bool registerchange)
+void hk_button::set_action(long actionid,const hk_string& objectname,bool showmaximized,bool registerchange)
 {
-    p_action=action;
-    p_object=object;
+    p_action=actionid;
+    p_object=objectname;
     p_showmaximized=showmaximized;
     has_changed(registerchange);
 
@@ -460,7 +460,7 @@ void hk_button::clear_conditions(bool registerchange)
 
 
 hk_string hk_button::parsed_condition(hk_presentation* pr)
-{  cerr<<endl<<endl<<"parsed_condition"<<endl<<endl;
+{  //cerr<<endl<<endl<<"parsed_condition"<<endl<<endl;
     hk_string result;
     if (!p_presentation) return "";
     hk_datasource* prdatasource=NULL;
