@@ -14,6 +14,58 @@
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
+#ifdef HAVE_STDINT_H
+#include <stdint.h>
+#else
+
+#ifndef _STDINT_H
+
+#include <features.h>
+#include <bits/wchar.h>
+#include <bits/wordsize.h>
+#if __WORDSIZE == 64
+# ifndef __intptr_t_defined
+typedef long int		intptr_t;
+#  define __intptr_t_defined
+# endif
+typedef unsigned long int	uintptr_t;
+#else
+# ifndef __intptr_t_defined
+typedef int			intptr_t;
+#  define __intptr_t_defined
+# endif
+typedef unsigned int		uintptr_t;
+#endif
+#ifndef __int8_t_defined
+# define __int8_t_defined
+typedef signed char		int8_t;
+typedef short int		int16_t;
+typedef int			int32_t;
+# if __WORDSIZE == 64
+typedef long int		int64_t;
+# else
+__extension__
+typedef long long int		int64_t;
+# endif
+#endif
+
+/* Unsigned.  */
+typedef unsigned char		uint8_t;
+typedef unsigned short int	uint16_t;
+#ifndef __uint32_t_defined
+typedef unsigned int		uint32_t;
+# define __uint32_t_defined
+#endif
+#if __WORDSIZE == 64
+typedef unsigned long int	uint64_t;
+#else
+__extension__
+typedef unsigned long long int	uint64_t;
+#endif
+
+#endif // !_STDINT_H
+#endif // !HAVE_STDINT_H
+
 #ifdef NO_IOSTREAM
 #include <iostream.h>
 #include <fstream.h>
@@ -41,7 +93,7 @@ typedef bool progress_dialogtype(long int,long int,const hk_string&);
  * hk_class is the basic class for all other defined classes. It has some methods to support
  * a simple debugging.
  * @short basic class for all other defined classes.
- *@version $Revision: 1.45 $
+ *@version $Revision: 1.47 $
  * @author Horst Knorr (hk_classes@knoda.org)
  * @internal
  */
@@ -166,7 +218,7 @@ enum enum_interaction {noninteractive,interactive};
         static  bool get_tagvalue(const hk_string &where, const hk_string &tag, int &value, int position=1);
         static  bool get_tagvalue(const hk_string &where, const hk_string &tag, bool &value, int position=1);
 /**
- * Each value will be stored between delimiting tags in the form <tag>value</tag>\n
+ * Each value will be stored between delimiting tags in the form &lt;tag>value&lt;/tag>\n
  *@param stream a stream to which the value will be written
  *@param tag the tag name
  *@param value the value to be stored
@@ -178,13 +230,13 @@ enum enum_interaction {noninteractive,interactive};
         static  void set_tagvalue(ostream& stream,const hk_string& tag,int value);
         static  void set_tagvalue(ostream& stream,const hk_string& tag,bool value);
 /**
- *just writes <tag> to a stream. Use this function if you want to begin a section.
+ *just writes &lt;tag> to a stream. Use this function if you want to begin a section.
  *Don't forget to call @ref end_mastertag
  *
  */
         static  void start_mastertag(ostream& stream,const hk_string& tag);
 /**
- *just writes </tag> to a stream. Use this function if you want to end a section
+ *just writes &lt;/tag> to a stream. Use this function if you want to end a section
  */
         static  void end_mastertag(ostream& stream,const hk_string& tag);
         static  void set_defaultdatetimeformat(const hk_string& timeformat,const hk_string& dateformat,const hk_string&datetimeformat);
