@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.63 $
+//$Revision: 1.64 $
 #include "hk_column.h"
 #include "hk_datasource.h"
 #include "hk_dsdatavisible.h"
@@ -602,21 +602,21 @@ bool hk_column::load_from_file(const hk_string& filename)
 #ifdef HK_DEBUG
     hkdebug("hk_column::load_from_file");
 #endif
-    long size;
+    long fsize;
     FILE *in;
     in=fopen(filename.c_str(),"r");
     if (in==NULL)return false;
     fseek(in,0,SEEK_END);
-    size=ftell(in);
+    fsize=ftell(in);
     fseek(in,0,SEEK_SET);
     if (p_original_new_data!=NULL)
     {
         delete[] p_original_new_data;
         p_original_new_data=NULL;
     }
-    p_original_new_data=new char[size];
-    p_original_new_data_size=size;
-    fread(p_original_new_data,size,1,in);
+    p_original_new_data=new char[fsize];
+    p_original_new_data_size=fsize;
+    fread(p_original_new_data,fsize,1,in);
     driver_specific_asbinary(p_original_new_data);
     set_has_changed();
 
@@ -640,36 +640,36 @@ bool hk_column::save_to_file(const hk_string& filename)
 }
 
 
-bool    hk_column::driver_specific_asstring(const hk_string& d)
+bool    hk_column::driver_specific_asstring(const hk_string& )
 {
     return true;
 }
 
 
-hk_string hk_column::driver_specific_asstring_at(unsigned long a)
+hk_string hk_column::driver_specific_asstring_at(unsigned long )
 {
     return "";
 }
 
 
-const struct_raw_data* hk_column::driver_specific_asbinary_at(unsigned long a)
+const struct_raw_data* hk_column::driver_specific_asbinary_at(unsigned long )
 {
     return NULL;
 }
 
 
-bool        hk_column::driver_specific_asbinary(const char* b)
+bool        hk_column::driver_specific_asbinary(const char* )
 {
     return false;
 }
 
 
-void        hk_column::driver_specific_asbool(bool b)
+void        hk_column::driver_specific_asbool(bool )
 {
 }
 
 
-bool hk_column::driver_specific_asbool_at(unsigned long a)
+bool hk_column::driver_specific_asbool_at(unsigned long )
 {
     return false;
 }
