@@ -19,7 +19,7 @@ class hk_dsdatavisible;
 /**
  *
  *@short represents one column of a datasource.
- *@version $Revision: 1.51 $
+ *@version $Revision: 1.53 $
  *@author Horst Knorr (hk_classes@knoda.org)
  *
  *represents one column of a datasource. The data of the current row (set in @ref hk_datasource)
@@ -149,10 +149,10 @@ class hk_column:public hk_class
 /**
  * @param s new value of the column.
  */
-        void    set_asstring(const hk_string&, bool registerchange=true);
+        void    set_asstring(const hk_string& s, bool registerchange=true);
         void    set_asstring(const hk_string& s,bool registerchange,bool is_locale);
 /**
- * Columns can contain characters such as \0, \n, ' and so on.
+ * Columns can contain characters such as \\0, \\n, ' and so on.
  * Some SQL Servers need to encode this data, so this function delivers the encoded and
  * nonlocalized version.
  */
@@ -194,7 +194,7 @@ class hk_column:public hk_class
 /**
  * @param s new value of the column.
  */
-	void set_asinteger(long int, bool registerchange=true);
+	void set_asinteger(long int s, bool registerchange=true);
 	long int asinteger(void);
 	long int asinteger_at(unsigned long );
 	long int changed_data_asinteger(void);
@@ -202,7 +202,7 @@ class hk_column:public hk_class
 /**
  * @param s new value of the column.
  */
-	void set_asdouble(double, bool registerchange=true);
+	void set_asdouble(double s, bool registerchange=true);
 	double asdouble(void);
 	double asdouble_at(unsigned long );
 	double changed_data_asdouble(void);
@@ -280,16 +280,19 @@ class hk_column:public hk_class
  * format with this function. See @ref hk_datetime for details.
  */
         void set_dateformat(const hk_string& df){p_dateformat=df;}
+        hk_string dateformat(void) const {return p_dateformat;}
 /**
  * if the column is of type date, time or datetime you can specify the wished
  * format with this function. See @ref hk_datetime for details.
  */
         void set_timeformat(const hk_string& tf){p_timeformat=tf;}
+        hk_string timeformat(void) const{return p_timeformat;}
 /**
  * if the column is of type date, time or datetime you can specify the wished
  * format with this function. See @ref hk_datetime for details.
  */
         void set_datetimeformat(const hk_string& dtf){p_datetimeformat=dtf;}
+        hk_string datetimeformat(void) const{return p_datetimeformat;}
 /**
  * save the value of this column in a file. Very useful for binary-columns
  */
