@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.73 $
+//$Revision: 1.77 $
 #include "hk_connection.h"
 #include "hk_database.h"
 #include "hk_datasource.h"
@@ -420,14 +420,14 @@ bool hk_connection::create_database(const hk_string& dbase)
 }
 
 
-bool hk_connection::delete_database(const hk_string& dbase)
+bool hk_connection::delete_database(const hk_string& dbase,enum_interaction c)
 {
     if (p_database==NULL) new_database();
     if (p_database==NULL||!is_connected()) return false;
     bool result=false;
     hk_string warning=hk_translate("Delete the database \"%DBNAME%\"?");
     warning=replace_all("%DBNAME%",warning,dbase);
-    if(show_yesnodialog(warning,true))
+    if(c==noninteractive || show_yesnodialog(warning,true))
     {
        result=driver_specific_delete_database(dbase);
     }
@@ -895,7 +895,7 @@ bool hk_connection::booleanemulation(void) const
   return p_private->p_booleanemulation;
 }
 
-bool hk_connection::rename_database(const hk_string& originalname, const hk_string& new_name)
+bool hk_connection::rename_database(const hk_string& /*originalname*/, const hk_string& /*new_name*/)
 {
 return false;
 }
@@ -904,7 +904,7 @@ return false;
 
 void hk_connection::set_last_servermessage(const hk_string& m)
 {
-   p_lastservermessage=m; cerr <<"set_last_servermessage= "<<m<<endl;
+   p_lastservermessage=m; //cerr <<"set_last_servermessage= "<<m<<endl;
 }
 
 void hk_connection::set_defaultdatabase(const hk_string& db)
@@ -947,12 +947,14 @@ hk_string hk_connection::check_capabilities(hk_connection* from,hk_connection* t
  if (!internal_copy_check(from,to,SUPPORTS_MEMOCOLUMN)) result+="* "+hk_translate("No 'memo' field type")+"\n";
  if (!internal_copy_check(from,to,SUPPORTS_TIMESTAMPCOLUMN)) result+="* "+hk_translate("No 'timestamp' field type")+"\n";
  if (!internal_copy_check(from,to,SUPPORTS_SQL)) result+="* "+hk_translate("Target does not support SQL")+"\n";
-if (!internal_copy_check(from,to,SUPPORTS_SQL_GROUP_BY)) result+="* "+hk_translate("SQL does not support 'GROUP BY' statement")+"\n";
- if (!internal_copy_check(from,to,SUPPORTS_SQL_ORDER_BY)) result+="* "+hk_translate("SQL does not support 'ORDER BY' statement")+"\n";
- if (!internal_copy_check(from,to,SUPPORTS_SQL_HAVING)) result+="* "+hk_translate("SQL does not support 'HAVING' statement")+"\n";
- if (!internal_copy_check(from,to,SUPPORTS_SQL_WHERE)) result+="* "+hk_translate("SQL does not support 'WHERE' statement")+"\n";
- if (!internal_copy_check(from,to,SUPPORTS_SQL_ALIAS)) result+="* "+hk_translate("SQL does not support 'ALIAS' statement")+"\n";
-
+ else
+ {
+  if (!internal_copy_check(from,to,SUPPORTS_SQL_GROUP_BY)) result+="* "+hk_translate("SQL does not support 'GROUP BY' statement")+"\n";
+  if (!internal_copy_check(from,to,SUPPORTS_SQL_ORDER_BY)) result+="* "+hk_translate("SQL does not support 'ORDER BY' statement")+"\n";
+  if (!internal_copy_check(from,to,SUPPORTS_SQL_HAVING)) result+="* "+hk_translate("SQL does not support 'HAVING' statement")+"\n";
+  if (!internal_copy_check(from,to,SUPPORTS_SQL_WHERE)) result+="* "+hk_translate("SQL does not support 'WHERE' statement")+"\n";
+  if (!internal_copy_check(from,to,SUPPORTS_SQL_ALIAS)) result+="* "+hk_translate("SQL does not support 'ALIAS' statement")+"\n";
+ }
  if (!internal_copy_check(from,to,SUPPORTS_REFERENTIALINTEGRITY)) result+="* "+hk_translate("Referential integrity not supported")+"\n";
  if (!internal_copy_check(from,to,SUPPORTS_CREATE_INDEX)) result+="* "+hk_translate("Indices are not supported")+"\n";
  if (!internal_copy_check(from,to,SUPPORTS_VIEWS)
