@@ -21,7 +21,7 @@ class hk_connectionprivate;
 class hk_database;
 /**
  *@short connects to the SQL Server
- *@version $Revision: 1.57 $
+ *@version $Revision: 1.63 $
  *@author Horst Knorr (hk_classes@knoda.org)
  *
  *connects to the SQL Server. Set @ref set_host,@ref set_user, @ref set_password ,
@@ -84,7 +84,7 @@ class hk_connection:public hk_class
  *The list will be created new every time you call this function.
  *So be careful. Never use i.e. for_each(dblist()->begin(),dblist()->end(),anyfunction)
  *Use instead:
- *list<hk_string>* mylist=dblist();
+ *list&lt;hk_string>* mylist=dblist();
  *for_each(mylist->begin(),mylist->end(),anyfunction)
 
  */
@@ -150,6 +150,8 @@ class hk_connection:public hk_class
 	    SUPPORTS_SQL_WHERE=183,
 	    SUPPORTS_SQL_ALIAS=184,
 	    SUPPORTS_SQL_SUBSELECTS=185,
+	    SUPPORTS_SQL_JOINS=186, // means at least INNER JOIN and LEFT (OUTER) JOIN
+	    SUPPORTS_SQL_UNION=187,
 
 	    SUPPORTS_LOCAL_FILEFORMAT=200,
 	    SUPPORTS_NONALPHANUM_FIELDNAMES=201, // if not set field name can only have [a-zA-Z0-9]
@@ -198,7 +200,7 @@ virtual        bool    create_database(const hk_string& dbase);
  *@param dbase name of an existing database
  *@return true if successful else flase
  */
-virtual        bool    delete_database(const hk_string& dbase);
+virtual        bool    delete_database(const hk_string& dbase,enum_interaction c=interactive);
 /**
  * checks whether a database exists
  */
@@ -265,6 +267,9 @@ virtual unsigned int maxfieldnamesize(void) const {return (unsigned int)-1;}
 */
 virtual long int maxcharsize(void) const {return 255;}
 
+virtual hk_string left_join_statement(void) {return " LEFT JOIN ";}
+virtual hk_string inner_join_statement(void) {return " INNER JOIN ";}
+
 
 
     protected:
@@ -272,7 +277,7 @@ virtual long int maxcharsize(void) const {return 255;}
         bool    p_connected;
         virtual bool    driver_specific_connect(void){return false;}
         virtual bool    driver_specific_disconnect(void){return false;}
-	virtual bool    driver_specific_rename_database(const hk_string& oldname,const hk_string& newname){return false;}
+	virtual bool    driver_specific_rename_database(const hk_string& /*oldname*/,const hk_string& /*newname*/){return false;}
         virtual  vector<hk_string>* driver_specific_dblist(void){return NULL;}
         virtual hk_database* driver_specific_new_database(void){return NULL;}
         virtual bool    driver_specific_new_password(const hk_string&){return false;}
@@ -284,11 +289,11 @@ virtual long int maxcharsize(void) const {return 255;}
         void inform_databases_disconnect(void);
         vector<hk_string> p_databaselist;
 /**
- *saves the tags <HOST><USER><TCP-PORT><SQLDELIMITER> with the equivalent values
+ *saves the tags &lt;HOST>&lt;USER>&lt;TCP-PORT>&lt;SQLDELIMITER> with the equivalent values
  */
         virtual void savedata(ostream& s);
 /**
- *load the tags <HOST><USER><TCP-PORT><SQLDELIMITER> with the equivalent values
+ *load the tags &lt;HOST>&lt;USER>&lt;TCP-PORT><SQLDELIMITER> with the equivalent values
  */
         virtual void loaddata(const hk_string& definition);
 
