@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.114 $
+//$Revision: 1.117 $
 #include "hk_database.h"
 #include "hk_data.h"
 #include "hk_dbvisible.h"
@@ -213,7 +213,7 @@ bool hk_database::query_exists(const hk_string& queryname)
     return res;
 }
 
-bool hk_database::form_exists(const hk_string& name)
+bool hk_database::form_exists(const hk_string& nm)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_database::form_exists");
@@ -224,7 +224,7 @@ bool hk_database::form_exists(const hk_string& name)
     vector<hk_string>::iterator it= liste->begin();
     while (it!=liste->end())
     {
-        if ((*it)==name)return true;
+        if ((*it)==nm)return true;
 
         it++;
     }
@@ -232,7 +232,7 @@ bool hk_database::form_exists(const hk_string& name)
     return res;
 }
 
-bool hk_database::report_exists(const hk_string& name)
+bool hk_database::report_exists(const hk_string& nm)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_database::report_exists");
@@ -243,7 +243,7 @@ bool hk_database::report_exists(const hk_string& name)
     vector<hk_string>::iterator it= liste->begin();
     while (it!=liste->end())
     {
-        if ((*it)==name)return true;
+        if ((*it)==nm)return true;
 
         it++;
     }
@@ -255,7 +255,7 @@ bool hk_database::report_exists(const hk_string& name)
 
 
 
-hk_datasource* hk_database::new_table(const hk_string& name,hk_presentation* p)
+hk_datasource* hk_database::new_table(const hk_string& nm,hk_presentation* p)
 {
 if (!p_connection->database_exists(p_private->p_dbname)) return NULL;
     hk_datasource* tb=driver_specific_new_table(p);
@@ -272,12 +272,12 @@ if (!p_connection->database_exists(p_private->p_dbname)) return NULL;
      return NULL;
     }
 
-    if (name.size()>0)tb->set_name(name,false);
+    if (nm.size()>0)tb->set_name(nm,false);
     return tb;
 }
 
 
-hk_datasource* hk_database::new_view(const hk_string& name,hk_presentation* p)
+hk_datasource* hk_database::new_view(const hk_string& nm,hk_presentation* p)
 {
    hk_datasource* ds= driver_specific_new_view(p);
     if (ds!=NULL)
@@ -293,7 +293,7 @@ hk_datasource* hk_database::new_view(const hk_string& name,hk_presentation* p)
      return NULL;
     }
 
-    if (name.size()>0)ds->set_name(name,false);
+    if (nm.size()>0)ds->set_name(nm,false);
     return ds;
 }
 
@@ -346,6 +346,7 @@ bool hk_database::select_db(const hk_string& newname)
 #ifdef HK_DEBUG
     hkdebug("hk_database::select_db");
 #endif
+ if (in_presentationload()) return false;
     hk_string oldname=name();
     clear_presentationlist();
     clear_visiblelist();
@@ -480,7 +481,7 @@ bool hk_database::delete_table(const hk_string& table,enum_interaction x)
 
         if (q!=NULL)
         {
-            hk_datasource* d=new_table();
+            d=new_table();
             d->set_name(table);
             d->driver_specific_before_drop_table();
             delete d;
@@ -614,33 +615,33 @@ void hk_database::inform_datasources_before_closing(void)
 }
 
 
-void hk_database::save(const hk_string& statement,const hk_string& name,filetype type,bool ask_before_overwrite,bool ask_for_new_name)
+void hk_database::save(const hk_string& statement,const hk_string& nm,filetype type,bool ask_before_overwrite,bool ask_for_new_name)
 {
-  save(st_overwrite,statement,name,type,ask_before_overwrite,ask_for_new_name);
+  save(st_overwrite,statement,nm,type,ask_before_overwrite,ask_for_new_name);
 }
-void hk_database::save(enum_storage storage,const hk_string& statement,const hk_string& name,filetype type,bool ask_before_overwrite,bool ask_for_new_name)
+void hk_database::save(enum_storage storage,const hk_string& statement,const hk_string& nm,filetype type,bool ask_before_overwrite,bool ask_for_new_name)
 {
 
 #ifdef HK_DEBUG
     hkdebug("hk_database::save");
 #endif
 
-return (p_private->p_storagemode[type]==central?save_central(storage,statement,name,type,ask_before_overwrite,ask_for_new_name):save_local(storage,statement,name,type,ask_before_overwrite,ask_for_new_name));
+return (p_private->p_storagemode[type]==central?save_central(storage,statement,nm,type,ask_before_overwrite,ask_for_new_name):save_local(storage,statement,nm,type,ask_before_overwrite,ask_for_new_name));
 }
 
 
 
-void hk_database::save_local(const hk_string& statement,const hk_string& name,filetype type,bool ask_before_overwrite,bool ask_for_new_name)
+void hk_database::save_local(const hk_string& statement,const hk_string& nm,filetype type,bool ask_before_overwrite,bool ask_for_new_name)
 {
-save_local( st_overwrite,statement,name,type,ask_before_overwrite,ask_for_new_name);
+save_local( st_overwrite,statement,nm,type,ask_before_overwrite,ask_for_new_name);
 }
 
-void hk_database::save_local(enum_storage storage, const hk_string& statement,const hk_string& name,filetype type,bool ask_before_overwrite,bool ask_for_new_name)
+void hk_database::save_local(enum_storage /*storage*/, const hk_string& statement,const hk_string& nm,filetype type,bool ask_before_overwrite,bool ask_for_new_name)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_database::save_local");
 #endif
-    ofstream* s=savestream(name,type,ask_before_overwrite,false,ask_for_new_name);
+    ofstream* s=savestream(nm,type,ask_before_overwrite,false,ask_for_new_name);
     if (!s) return ;
     (*s)<<statement;
     s->close();
@@ -651,13 +652,13 @@ void hk_database::save_local(enum_storage storage, const hk_string& statement,co
 }
 
 
-void hk_database::save_central(const hk_string& statement,const hk_string& name,filetype type,bool ask_before_overwrite,bool ask_for_new_name)
+void hk_database::save_central(const hk_string& statement,const hk_string& nm,filetype type,bool ask_before_overwrite,bool ask_for_new_name)
 {
-save_central(st_overwrite,statement,name,type,ask_before_overwrite,ask_for_new_name);
+save_central(st_overwrite,statement,nm,type,ask_before_overwrite,ask_for_new_name);
 }
 
 
-void hk_database::save_central(enum_storage storage,const hk_string& statement,const hk_string& name,filetype type,bool ask_before_overwrite,bool ask_for_new_name)
+void hk_database::save_central(enum_storage storage,const hk_string& statement,const hk_string& nm,filetype type,bool ask_before_overwrite,bool ask_for_new_name)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_database::save_central");
@@ -682,19 +683,19 @@ hk_datasource* ds=new_table("HKCLASSES");
     delete ds;
     return;
    }
-  unsigned int row=n->find(name,true,true);
+  unsigned int row=n->find(nm,true,true);
   if (row > ds->max_rows())
   { // not existing => append object
     ds->setmode_insertrow();
     t->set_asinteger(type);
-    n->set_asstring(name);
+    n->set_asstring(nm);
   }
   else
   {  // replace existing object
     if (ask_before_overwrite )
     {
 
-    hk_string dialog=savemessage(type,storage,name);
+    hk_string dialog=savemessage(type,storage,nm);
      if(runtime_only() || !show_yesnodialog(dialog,true))
             {
               // no, so don't overwrite it
@@ -745,45 +746,45 @@ hk_datasource* ds=new_table("HKCLASSES");
 
 
 
-ofstream* hk_database::savestream(const hk_string&name,filetype type,bool ask_before_overwrite)
+ofstream* hk_database::savestream(const hk_string&nm,filetype type,bool ask_before_overwrite)
 {
-    return savestream(name,type,ask_before_overwrite,true,false);
+    return savestream(nm,type,ask_before_overwrite,true,false);
 }
 
-hk_string hk_database::savemessage(filetype type,enum_storage storage,hk_string name)
+hk_string hk_database::savemessage(filetype type,enum_storage storage,hk_string nm)
 {
  hk_string dialog;
  if (storage==st_overwrite)
  {
-    if (type==ft_query)dialog=replace_all("%1",hk_translate("Query '%1' already exists. Overwrite it?"),name);
-    else if (type==ft_form)dialog=replace_all("%1",hk_translate("Form '%1' already exists. Overwrite it?"),name);
-    else if (type==ft_report)dialog=replace_all("%1",hk_translate("Report '%1' already exists. Overwrite it?"),name);
-    else dialog=replace_all("%1",hk_translate("File '%1' already exists. Overwrite it?"),name);
+    if (type==ft_query)dialog=replace_all("%1",hk_translate("Query '%1' already exists. Overwrite it?"),nm);
+    else if (type==ft_form)dialog=replace_all("%1",hk_translate("Form '%1' already exists. Overwrite it?"),nm);
+    else if (type==ft_report)dialog=replace_all("%1",hk_translate("Report '%1' already exists. Overwrite it?"),nm);
+    else dialog=replace_all("%1",hk_translate("File '%1' already exists. Overwrite it?"),nm);
  }
  else
  {
-    if (type==ft_query)dialog=replace_all("%1",hk_translate("Query '%1' has changed. Store changes?"),name);
-    else if (type==ft_form)dialog=replace_all("%1",hk_translate("Form '%1' has changed. Store changes?"),name);
-    else if (type==ft_report)dialog=replace_all("%1",hk_translate("Report '%1' has changed. Store changes?"),name);
-    else dialog=replace_all("%1",hk_translate("File '%1' has changed. Store changes?"),name);
+    if (type==ft_query)dialog=replace_all("%1",hk_translate("Query '%1' has changed. Store changes?"),nm);
+    else if (type==ft_form)dialog=replace_all("%1",hk_translate("Form '%1' has changed. Store changes?"),nm);
+    else if (type==ft_report)dialog=replace_all("%1",hk_translate("Report '%1' has changed. Store changes?"),nm);
+    else dialog=replace_all("%1",hk_translate("File '%1' has changed. Store changes?"),nm);
  }
  return dialog;
 }
 
-ofstream* hk_database::savestream(const hk_string&name,filetype type,bool ask_before_overwrite,bool with_header,bool ask_for_new_name)
+ofstream* hk_database::savestream(const hk_string&nm,filetype type,bool ask_before_overwrite,bool with_header,bool ask_for_new_name)
 {
-  return savestream(st_overwrite,name,type,ask_before_overwrite,with_header,ask_for_new_name);
+  return savestream(st_overwrite,nm,type,ask_before_overwrite,with_header,ask_for_new_name);
 }
 
 
-ofstream* hk_database::savestream(enum_storage storage,const hk_string&name,filetype type,bool ask_before_overwrite,bool with_header,bool ask_for_new_name)
+ofstream* hk_database::savestream(enum_storage storage,const hk_string&nm,filetype type,bool ask_before_overwrite,bool with_header,bool ask_for_new_name)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_database::savestream");
 #endif
     hk_string filename=p_private->p_databasepath+"/";
-    filename+=name+fileendings(type);
-    hk_string dialog=savemessage(type,storage,name);
+    filename+=nm+fileendings(type);
+    hk_string dialog=savemessage(type,storage,nm);
     
     if (ask_before_overwrite)
     {
@@ -846,7 +847,7 @@ ofstream* hk_database::savestream(enum_storage storage,const hk_string&name,file
     return savestringstream(type,true);
 }
 
-    STRINGSTREAM*  hk_database::savestringstream(filetype type,bool with_header)
+    STRINGSTREAM*  hk_database::savestringstream(filetype /*type*/,bool with_header)
 
 
 {
@@ -878,23 +879,23 @@ ofstream* hk_database::savestream(enum_storage storage,const hk_string&name,file
 
 
 
-hk_string hk_database::load(const hk_string& name,filetype type)
+hk_string hk_database::load(const hk_string& nm,filetype type)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_database::load");
 #endif
-return (p_private->p_loadmode[type]==central?load_central(name,type):load_local(name,type));
+return (p_private->p_loadmode[type]==central?load_central(nm,type):load_local(nm,type));
 }
 
 
-hk_string hk_database::load_local(const hk_string& name,filetype type)
+hk_string hk_database::load_local(const hk_string& nm,filetype type)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_database::load_local");
 #endif
-    if (name.size()==0) return "";
+    if (nm.size()==0) return "";
     hk_string n=p_private->p_databasepath+"/";
-    n+=name+fileendings(type);
+    n+=nm+fileendings(type);
     hk_string result;
     ifstream ifs(n.c_str(),ios::in);
     if (ifs)
@@ -908,7 +909,7 @@ hk_string hk_database::load_local(const hk_string& name,filetype type)
 }
 
 
-hk_string hk_database::load_central(const hk_string& name,filetype type)
+hk_string hk_database::load_central(const hk_string& nm,filetype type)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_database::load_central");
@@ -933,7 +934,7 @@ hk_datasource* ds=new_table("HKCLASSES");
     delete ds;
     return "";
    }
-  unsigned int row=n->find(name,true,true);
+  unsigned int row=n->find(nm,true,true);
   if (row > ds->max_rows())
   { // not existing
      /*show_warningmessage(replace_all("%1",hk_translate("Error: hk_database::load_central object '%1' not found"),name));*/
@@ -1055,12 +1056,12 @@ vector<hk_string>* hk_database::central_filelist(filetype type)
    ds->set_sql(query);
    ds->enable();
    unsigned k=0;
-   hk_column* name=ds->column_by_name("name");
-   if (name)
+   hk_column* namecol=ds->column_by_name("name");
+   if (namecol)
    {
      while (k<ds->max_rows())
      {
-       p_private->p_filelist.insert(p_private->p_filelist.end(),name->asstring());
+       p_private->p_filelist.insert(p_private->p_filelist.end(),namecol->asstring());
        ds->goto_next();++k;
      };
    }
@@ -1107,7 +1108,7 @@ vector<hk_string>* hk_database::local_filelist(filetype type)
 }
 
 
-bool  hk_database::delete_file(const hk_string& name,filetype type,enum_interaction x)
+bool  hk_database::delete_file(const hk_string& nm,filetype type,enum_interaction x)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_database::delete_file");
@@ -1123,15 +1124,15 @@ bool  hk_database::delete_file(const hk_string& name,filetype type,enum_interact
         message=hk_translate("Delete the form:%FNAME%?");
     else
         message=hk_translate("Delete the file:%FNAME%");
-    message=replace_all("%FNAME%",message,name);
+    message=replace_all("%FNAME%",message,nm);
     if(x==interactive&&!show_yesnodialog(message,true))
         return false;
-return (p_private->p_loadmode[type]==central?delete_centralfile(name,type,x):delete_localfile(name,type,x));
+return (p_private->p_loadmode[type]==central?delete_centralfile(nm,type,x):delete_localfile(nm,type,x));
 
 }
 
 
-bool  hk_database::delete_centralfile(const hk_string& name,filetype type,enum_interaction x)
+bool  hk_database::delete_centralfile(const hk_string& nm,filetype type,enum_interaction /*x*/)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_database::delete_centralfile");
@@ -1156,10 +1157,10 @@ hk_datasource* ds=new_table("HKCLASSES");
     delete ds;
     return false;
    }
-  unsigned int row=n->find(name,true,true);
+  unsigned int row=n->find(nm,true,true);
   if (row > ds->max_rows())
   { // not existing
-     show_warningmessage(replace_all("%1",hk_translate("Error: hk_database::delete_centralfile object '%1' not found"),name));
+     show_warningmessage(replace_all("%1",hk_translate("Error: hk_database::delete_centralfile object '%1' not found"),nm));
      delete ds;
      return false;
   }
@@ -1176,13 +1177,13 @@ return true;
 
 
 
-bool  hk_database::delete_localfile(const hk_string& name,filetype type,enum_interaction x)
+bool  hk_database::delete_localfile(const hk_string& nm,filetype type,enum_interaction /*x*/)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_database::delete_file");
 #endif
     hk_string filename=p_private->p_databasepath+"/";
-    filename+=name+fileendings(type);
+    filename+=nm+fileendings(type);
     int r=unlink(filename.c_str());
     if (r==0)
     {
@@ -1225,7 +1226,7 @@ void hk_database::inform_datasources_filelist_changes(listtype type)
 }
 
 
-hk_datasource*  hk_database::load_datasource(const hk_string& name,datasourcetype dt,hk_presentation* p)
+hk_datasource*  hk_database::load_datasource(const hk_string& nm,datasourcetype dt,hk_presentation* p)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_database::load_datasource");
@@ -1236,8 +1237,8 @@ hk_datasource*  hk_database::load_datasource(const hk_string& name,datasourcetyp
       case dt_query:
     {
         hk_datasource* d=NULL;
-	if (name.size()==0) return new_resultquery(p);
-        hk_string r=load(name,ft_query);
+	if (nm.size()==0) return new_resultquery(p);
+        hk_string r=load(nm,ft_query);
         if (r.size()>0)
         {
             d=new_resultquery(p);
@@ -1247,29 +1248,29 @@ hk_datasource*  hk_database::load_datasource(const hk_string& name,datasourcetyp
     }
     case dt_view:
         {
-        return new_view(name,p);
+        return new_view(nm,p);
         }
     default:
-        return new_table(name,p);
+        return new_table(nm,p);
 
     }
 
 }
 
 
-hk_datasource* hk_database::driver_specific_new_table(hk_presentation* p)
+hk_datasource* hk_database::driver_specific_new_table(hk_presentation* )
 {
     return NULL;
 }
 
 
-hk_datasource* hk_database::driver_specific_new_view(hk_presentation* p)
+hk_datasource* hk_database::driver_specific_new_view(hk_presentation* )
 {
     return NULL;
 }
 
 
-hk_datasource* hk_database::driver_specific_new_resultquery(hk_presentation* p)
+hk_datasource* hk_database::driver_specific_new_resultquery(hk_presentation* )
 {
     return NULL;
 }
@@ -1367,6 +1368,24 @@ list <hk_presentation*>* hk_database::presentationlist() const
   return &p_private->p_presentations;
 }
 
+
+bool hk_database::in_presentationload(void)
+{
+    list<hk_presentation*>::iterator it;
+    it=p_private->p_presentations.begin();
+    while ( it!=p_private->p_presentations.end() )
+    {
+#ifdef HK_DEBUG
+        hkdebug("dv->classname: ");
+        hkdebug((*it)->hkclassname());
+#endif
+        if ((*it)->while_loading()) return true;
+        ++it;
+    }
+return false;
+
+}
+
 void hk_database::clear_presentationlist(void)
 {
 #ifdef HK_DEBUG
@@ -1389,7 +1408,7 @@ void hk_database::clear_presentationlist(void)
 }
 
 
-hk_presentation* hk_database::existing_presentation(const hk_string& name, hk_presentation::enum_presentationtype t)
+hk_presentation* hk_database::existing_presentation(const hk_string& nm, hk_presentation::enum_presentationtype t)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_database::existing_presentation");
@@ -1400,7 +1419,7 @@ hk_presentation* hk_database::existing_presentation(const hk_string& name, hk_pr
     {
         hk_presentation* dv=*it;
         ++it;
-        if (dv->name()==name &&dv->presentationtype()== t&&!dv->is_subpresentation())
+        if (dv->name()==nm &&dv->presentationtype()== t&&!dv->is_subpresentation())
         {
             return dv;
         }
@@ -1409,16 +1428,16 @@ hk_presentation* hk_database::existing_presentation(const hk_string& name, hk_pr
 }
 
 
-hk_form* hk_database::existing_form(const hk_string name)
+hk_form* hk_database::existing_form(const hk_string nm)
 {
-  hk_form*f =dynamic_cast<hk_form*>(existing_presentation(name,hk_presentation::form));
+  hk_form*f =dynamic_cast<hk_form*>(existing_presentation(nm,hk_presentation::form));
   return f;
 }
 
 
-hk_report* hk_database::existing_report(const hk_string name)
+hk_report* hk_database::existing_report(const hk_string nm)
 {
-  hk_report*r =dynamic_cast<hk_report*>(existing_presentation(name,hk_presentation::report));
+  hk_report*r =dynamic_cast<hk_report*>(existing_presentation(nm,hk_presentation::report));
   return r;
 
 }
@@ -1439,11 +1458,7 @@ bool hk_database::copy_table(hk_datasource* fromdatasource,bool schema_and_data,
     if ((tblexists&&runtime_only()) || (tblexists&&!ask&&!replacetable))return false;
     hk_datasource* newds=new_table();
     hk_string structure,buffer;
-#ifdef HAVE_SSTREAM
-    stringstream stream;
-#else
-    strstream stream;
-#endif
+    STRINGSTREAM stream;
     fromdatasource->save_datasourcedefinition(stream);
 //    while (stream >>buffer) structure+=buffer;
             char c;
@@ -1486,21 +1501,21 @@ bool hk_database::copy_table(hk_datasource* fromdatasource,bool schema_and_data,
             list<hk_column*>::iterator it=fromdatasource->columns()->begin();
             while (it!=fromdatasource->columns()->end())
             {
-                hk_column* c=newds->column_by_name(newds->systemcolumnname((*it)->name()),fromdatasource->columnname_occurance(*it));
+                hk_column* cl=newds->column_by_name(newds->systemcolumnname((*it)->name()),fromdatasource->columnname_occurance(*it));
 		//cerr <<"    add c:"<<c<<" name:"<<newds->systemcolumnname((*it)->name())<<endl;
-                if (c&&!(*it)->is_nullvalue())
+                if (cl&&!(*it)->is_nullvalue())
                 {
 
-                    switch(c->columntype())
+                    switch(cl->columntype())
                     {
                         case hk_column::binarycolumn: if (connection()->server_supports(hk_connection::SUPPORTS_BINARYCOLUMN))
-							c->set_asbinary((*it)->asbinary());
+							cl->set_asbinary((*it)->asbinary());
 							break;
-                        case hk_column::boolcolumn: c->set_asbool((*it)->asbool());break;
+                        case hk_column::boolcolumn: cl->set_asbool((*it)->asbool());break;
                         default: if ((*it)->asstring().size()>0)
                         {
 
-                            c->set_asstring((*it)->asstring());
+                            cl->set_asstring((*it)->asstring());
                         }
                     }
                 }
@@ -1724,7 +1739,7 @@ void hk_database::set_usewidgetparent(hk_class* parent)
  p_private->p_parent=parent;
 }
 
-bool hk_database::rename_table(const hk_string& originalname, const hk_string& new_name,enum_interaction x)
+bool hk_database::rename_table(const hk_string& originalname, const hk_string& new_name,enum_interaction )
 {
    if ( driver_specific_rename_table(originalname,new_name))
    {
@@ -1819,14 +1834,14 @@ bool hk_database::rename_file(const hk_string& originalname, const hk_string& ne
 }
 
 
-void hk_database::set_storagemode(filetype type,enum_storagemode load,enum_storagemode store)
+void hk_database::set_storagemode(filetype type,enum_storagemode loadmd,enum_storagemode storemd)
 {
    if (type>ft_report) return;
    bool hascentraltable =has_centralstoragetable();
-      p_private->p_loadmode[type]=((hascentraltable && load==hk_database::central)?
+      p_private->p_loadmode[type]=((hascentraltable && loadmd==hk_database::central)?
                              hk_database::central:hk_database::local
                             );
-      p_private->p_storagemode[type]=((hascentraltable && store==hk_database::central)?
+      p_private->p_storagemode[type]=((hascentraltable && storemd==hk_database::central)?
                              hk_database::central:hk_database::local
                             );
 }
