@@ -37,7 +37,7 @@ typedef hk_dsquery* newquery_type(hk_class*);
 
 /**
  *@short represents a particular database on the SQL Server
- *@version $Revision: 1.59 $
+ *@version $Revision: 1.62 $
  *@author Horst Knorr (hk_classes@knoda.org)
  *
  *represents a particular existing database on the SQL Server. To use
@@ -125,8 +125,8 @@ virtual bool    set_name(const hk_string& n);
  * removes  a table from the database and deletes all data.
  */
 
-        bool    delete_table(const hk_string& table,enum_interaction x=interactive);
-	bool    delete_view(const hk_string& view, enum_interaction x=interactive);
+virtual bool    delete_table(const hk_string& table,enum_interaction x=interactive);
+virtual bool    delete_view(const hk_string& view, enum_interaction x=interactive);
 /**
  * checks whether a table exists
  */
@@ -289,7 +289,7 @@ hk_string databasecharset(void) const;
         virtual hk_datasource* driver_specific_new_view(hk_presentation* p);
         virtual hk_datasource* driver_specific_new_resultquery(hk_presentation* p);
         virtual hk_actionquery*   driver_specific_new_actionquery(void){return NULL;}
-	virtual bool    driver_specific_rename_table(const hk_string& oldname,const hk_string& newname){return false;}
+	virtual bool    driver_specific_rename_table(const hk_string& /*oldname*/,const hk_string& /*newname*/){return false;}
         virtual bool driver_specific_select_db(void){return false;}
         virtual void driver_specific_set_name(void){}
         hk_connection* p_connection;
@@ -310,11 +310,12 @@ hk_string databasecharset(void) const;
         virtual void savedata(ostream& s);
         virtual void loaddata(const hk_string& definition);
         hk_url p_url;
+        void inform_datasources_filelist_changes(listtype type);
     private:
         void clear_presentationlist();
+        bool in_presentationload(void);
         void mark_datasources_as_not_handled(void);
         void mark_visible_objects_as_not_handled(void);
-        void inform_datasources_filelist_changes(listtype type);
         hk_string savemessage(filetype t,enum_storage s, hk_string name);
 	hk_databaseprivate* p_private;
         static newform_type *p_newformfunction;
