@@ -27,7 +27,7 @@ class hk_datasourceprivate;
 /**
  *
  *@short  represents a resultquery or a table of a database.
- *@version $Revision: 1.93 $
+ *@version $Revision: 1.98 $
  *@author Horst Knorr (hk_classes@knoda.org)
 
  *hk_datasource is the basic class which represents a resultquery or a table of a database.
@@ -334,6 +334,9 @@ See also @ref set_depending_on for details
  */
         bool    set_depending_on(hk_datasource* d,bool react_on_data_changes=false,enum_dependingmodes mode=depending_standard);
         hk_datasource* depending_on(void);
+        
+        void set_depending_on_is_left_join(bool, bool registerchange=true);
+        bool depending_on_is_left_join(void);
 /**
  *See @ref dependingmode for details
  */
@@ -450,43 +453,45 @@ See also @ref set_depending_on for details
             p_dateformat=date;
             p_timeformat=time;
         }
-
+	hk_string dateformat(void)const {return p_dateformat;}
+	hk_string datetimeformat(void)const {return p_datetimeformat;}
+	hk_string timeformat(void)const {return p_timeformat;}
         hk_database* database(void);
 /**
  *stores the object's values to stream s. The following tags will be used
  *
- *<TYPE> either QUERY or TABLE
+ *&lt;TYPE> either QUERY or TABLE
  *
- *<DATASOURCENAME>  the name set with @ref set_name
+ *&lt;DATASOURCENAME>  the name set with @ref set_name
  *
- *<SQL> the used sql statement
+ *&lt;SQL> the used sql statement
  *
- *Additionally the section <DATASOURCEEXTRA> has the following tags
+ *Additionally the section &lt;DATASOURCEEXTRA> has the following tags
  *
- *<FILTER> the filter set with @ref set_filter
+ *&lt;FILTER> the filter set with @ref set_filter
  *
- *<SORTING> the sorting direction set with @ref set_sorting
+ *&lt;SORTING> the sorting direction set with @ref set_sorting
  *
- *<DATETIMEFORMAT>
+ *&lt;DATETIMEFORMAT>
  *
- *<DATEFORMAT>
+ *&lt;DATEFORMAT>
  *
- *<TIMEFORMAT>
+ *&lt;TIMEFORMAT>
  *
  *if this datasource is part of a @ref hk_presentation also the following tags will be stored
  *
- *<UPN>   the unique presentation number. See @ref presentationnumber
+ *&lt;UPN>   the unique presentation number. See @ref presentationnumber
  *
- *<DEPENDING_ON>  the depending on datasource set with @ref set_depending_on_presentationdatasource
+ *&lt;DEPENDING_ON>  the depending on datasource set with @ref set_depending_on_presentationdatasource
  *
- *one or more <DEPENDINGFIELDS> sections with the following tags
+ *one or more &lt;DEPENDINGFIELDS> sections with the following tags
  *
- *<THISFIELD>   set with @ref add_depending_fields
+ *&lt;THISFIELD>   set with @ref add_depending_fields
  *
- *<MASTERFIELD> set with @ref add_depending_fields
+ *&lt;MASTERFIELD> set with @ref add_depending_fields
  *
  *@param s the stream to which the data will be written
- *@param saveall if true the section <DATASOURCEEXTRA> will be stored additionally to the normal data
+ *@param saveall if true the section &lt;DATASOURCEEXTRA> will be stored additionally to the normal data
  */
         void  savedata(ostream& s,bool saveall=true);
 /**
@@ -528,7 +533,7 @@ See also @ref set_depending_on for details
 /**
  *  Delete rows beginning from row number "from" to row number "to"
  */
-        bool delete_rows(unsigned long from,unsigned long to,bool check_depending_datasources=true,bool ask=true);
+virtual        bool delete_rows(unsigned long from,unsigned long to,bool check_depending_datasources=true,enum_interaction c=interactive);
 /**
  * Start a transaction. If the SQL server does not support transaction this function does nothing
  *@param name the name of the transaction
@@ -779,6 +784,7 @@ static void set_enablefunction(voidfunction*, long counter);
         hk_string   p_sql_delimiter;
         hk_string       p_true;
         hk_string       p_false;
+        bool   p_depending_on_is_left_join;
 
         bool    p_tablesql_set;
         void set_has_changed(void);
