@@ -8,13 +8,13 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.18 $
+//$Revision: 1.19 $
 #include "hk_datetime.h"
 #include <stdio.h>
 #include <time.h>
 
 static const int months[12] ={31,29,31,30,31,30,31,31,30,31,30,31};
-hk_datetime::hk_datetime()
+hk_datetime::hk_datetime():hk_class()
 {
 #ifdef HK_DEBUG
     hkdebug("hk_datetime::constructor");
@@ -33,39 +33,39 @@ hk_datetime::hk_datetime()
 }
 
 
-hk_datetime::hk_datetime(const hk_datetime& d)
+hk_datetime::hk_datetime(const hk_datetime& d):hk_class()
 {
     set_hk_datetime(d);
 
 }
 
 
-bool hk_datetime::set_date( int day,  int month,  int year)
+bool hk_datetime::set_date( int d,  int m,  int y)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_datetime::set_date( int day,  int month,  int year)");
 #endif
-    if (is_ok_date(day,month,year))
+    if (is_ok_date(d,m,y))
     {
-        p_day=day;
-        p_month=month;
-        p_year=year;
+        p_day=d;
+        p_month=m;
+        p_year=y;
         return true;
     }
     return false;
 }
 
 
-bool hk_datetime::set_time( int hour, int minute,  int second)
+bool hk_datetime::set_time( int h, int m,  int s)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_datetime::set_time( int hour, int minute,  int second)");
 #endif
-    if (is_ok_time(hour,minute,second))
+    if (is_ok_time(h,m,s))
     {
-        p_hour=hour;
-        p_minute=minute;
-        p_second=second;
+        p_hour=h;
+        p_minute=m;
+        p_second=s;
         return true;
     }
     return false;
@@ -73,36 +73,36 @@ bool hk_datetime::set_time( int hour, int minute,  int second)
 }
 
 
-bool hk_datetime::set_datetime( int day,  int month,  int year,  int hour, int minute,  int second)
+bool hk_datetime::set_datetime( int d,  int m,  int y,  int h, int mi,  int s)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_datetime::set_datetime( int day,  int month,...");
 #endif
-    if ((set_date(day,month,year))&&(set_time(hour,minute,second))) return true;
+    if ((set_date(d,m,y))&&(set_time(h,mi,s))) return true;
     return false;
 }
 
 
-bool hk_datetime::is_ok_date( int day,  int month,  int year)
+bool hk_datetime::is_ok_date( int d,  int m,  int y)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_datetime::is_ok_date");
 #endif
-    if (month<13&& month>0 && year!=-1)
-        if (day<=months[month-1]) return true;
+    if (m<13&& m>0 && y!=-1)
+        if (d<=months[m-1]) return true;
 
     return false;
 
 }
 
 
-bool hk_datetime::is_ok_time( int hour, int minute,  int second)
+bool hk_datetime::is_ok_time( int h, int m,  int s)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_datetime::is_ok_time");
 #endif
-    if (hour<0||minute<0||second<0)return false;
-    if ((hour <( int)24)&&(minute<( int)60)&&(second<( int)60))
+    if (h<0||m<0||s<0)return false;
+    if ((h <( int)24)&&(m<( int)60)&&(s<( int)60))
         return true;
     else  return false;
 }
@@ -238,8 +238,8 @@ bool hk_datetime::set_date_asstring(const hk_string& s)
     hkdebug("hk_datetime::set_date_asstring");
 #endif
     bool r=true;
-    int day,month,year;
-    day=month=year=-1;
+    int d,m,y;
+    d=m=y=-1;
     int k,l;
     k=l=0;
     while ((k<(int)p_dateformat.size())&&(l<(int)s.size())&&(r==true))
@@ -253,14 +253,14 @@ bool hk_datetime::set_date_asstring(const hk_string& s)
         {
             switch(p_dateformat[k])
             {
-                case 'D' :   day=p_setvalue(l,s);
-                if (day<1)r=false;
+                case 'D' :   d=p_setvalue(l,s);
+                if (d<1)r=false;
                 break;
-                case 'M':    month=p_setvalue(l,s);
-                if (month<1)r=false;
+                case 'M':    m=p_setvalue(l,s);
+                if (m<1)r=false;
                 break;
-                case 'Y':    year=p_setvalue(l,s,true);
-                if (year<0)r=false;
+                case 'Y':    y=p_setvalue(l,s,true);
+                if (y<0)r=false;
                 break;
                 default: r=false;
             }
@@ -268,24 +268,24 @@ bool hk_datetime::set_date_asstring(const hk_string& s)
         }
     }
 
-    if (r) r=set_date(day,month,year);
+    if (r) r=set_date(d,m,y);
     return r;
 }
 
 
-bool hk_datetime::set_time_asstring(const hk_string& s)
+bool hk_datetime::set_time_asstring(const hk_string& ts)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_datetime::set_time_asstring");
 #endif
     bool r=true;
-    int hour,minute,second;
-    hour=minute=second=-1;
+    int h,m,s;
+    h=m=s=-1;
     int k,l;
     k=l=0;
-    while ((k<(int)p_timeformat.size())&&(l<(int)s.size())&&(r==true))
+    while ((k<(int)p_timeformat.size())&&(l<(int)ts.size())&&(r==true))
     {
-        if (s[l]==p_timeformat[k])
+        if (ts[l]==p_timeformat[k])
         {
             k++;
             l++;
@@ -294,14 +294,14 @@ bool hk_datetime::set_time_asstring(const hk_string& s)
         {
             switch(p_timeformat[k])
             {
-                case 'h' :   hour=p_setvalue(l,s);
-                if (hour<0)r=false;
+                case 'h' :   h=p_setvalue(l,ts);
+                if (h<0)r=false;
                 break;
-                case 'm':    minute=p_setvalue(l,s);
-                if (minute<0)r=false;
+                case 'm':    m=p_setvalue(l,ts);
+                if (m<0)r=false;
                 break;
-                case 's':    second=p_setvalue(l,s);
-                if (second<0)r=false;
+                case 's':    s=p_setvalue(l,ts);
+                if (s<0)r=false;
                 break;
                 default: r=false;
             }
@@ -309,25 +309,25 @@ bool hk_datetime::set_time_asstring(const hk_string& s)
         }
     }
 
-    if (r) r=set_time(hour,minute,second);
+    if (r) r=set_time(h,m,s);
     return r;
 
 }
 
 
-bool hk_datetime::set_datetime_asstring(const hk_string& s)
+bool hk_datetime::set_datetime_asstring(const hk_string& ts)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_datetime::set_datetime_asstring");
 #endif
     bool r=true;
-    int hour,minute,second,year,month,day;
-    year=month=day=hour=minute=second=-1;
+    int h,m,s,y,mo,d;
+    y=mo=d=h=m=s=-1;
     int k,l;
     k=l=0;
-    while ((k<(int)p_datetimeformat.size())&&(l<(int)s.size())&&(r==true))
+    while ((k<(int)p_datetimeformat.size())&&(l<(int)ts.size())&&(r==true))
     {
-        if (s[l]==p_datetimeformat[k])
+        if (ts[l]==p_datetimeformat[k])
         {
             k++;
             l++;
@@ -336,23 +336,23 @@ bool hk_datetime::set_datetime_asstring(const hk_string& s)
         {
             switch(p_datetimeformat[k])
             {
-                case 'h' :   hour=p_setvalue(l,s);
-                if (hour<0)r=false;
+                case 'h' :   h=p_setvalue(l,ts);
+                if (h<0)r=false;
                 break;
-                case 'm':    minute=p_setvalue(l,s);
-                if (minute<0)r=false;
+                case 'm':    m=p_setvalue(l,ts);
+                if (m<0)r=false;
                 break;
-                case 's':    second=p_setvalue(l,s);
-                if (second<0)r=false;
+                case 's':    s=p_setvalue(l,ts);
+                if (s<0)r=false;
                 break;
-                case 'D' :   day=p_setvalue(l,s);
-                if (day<1)r=false;
+                case 'D' :   d=p_setvalue(l,ts);
+                if (d<1)r=false;
                 break;
-                case 'M':    month=p_setvalue(l,s);
-                if (month<1)r=false;
+                case 'M':    mo=p_setvalue(l,ts);
+                if (mo<1)r=false;
                 break;
-                case 'Y':    year=p_setvalue(l,s,true);
-                if (year<0)r=false;
+                case 'Y':    y=p_setvalue(l,ts,true);
+                if (y<0)r=false;
                 break;
 
                 default: r=false;
@@ -361,7 +361,7 @@ bool hk_datetime::set_datetime_asstring(const hk_string& s)
         }
     }
 
-    if (r) r=set_datetime(day,month,year,hour,minute,second);
+    if (r) r=set_datetime(d,mo,y,h,m,s);
     return r;
 
 }
