@@ -14,11 +14,75 @@
 #include <list>
 #include <stdlib.h>
 #include <stdio.h>
+/*! \mainpage hk_classes
+ *
+ * \section intro_sec Introduction
+ *
+ <em>hk_classes</em> is  C++ library which allows rapid development of database
+applications with all features a modern database application should have like forms an reports.
+<em>hk_classes</em> is  database and GUI independent. In combination with
+<em>hk_kdeclasses</em> (which is part of the <a
+href="http://www.knoda.org" TARGET="_blank">knoda package</a>) it supports the rapid development of database
+applications for KDE.
+<p><em>hk_classes</em> is under heavy development, but it already works pretty
+well.
+<h2>hk_classes allows you to:</h2>
+<ul>
+<li>connect to a  database server (
+<a href="http://linux.techass.com/projects/xdb/" target="_blank">Dbase/Xbase</a>,
+<a href="http://www.firebirdsql.org" target="_blank">Firebird</a>,
+<a href="http://mdbtools.sourceforge.net" target="_blank">MS Access/Mdbtools</a>,
+<a href="http://www.mysql.com" target="_blank">Mysql</a>,
+<a href="http://pxlib.sourceforge.net" target="_blank">Paradox</a>,
+<a href="http://www.postgresql.org" target="_blank">Postgresql</a>,
+<a href="http://www.sqlite.org" target="_blank">SQLite</a> or
+<a href="http://www.unixodbc.org" target="_blank">ODBC</a>); </li>
+<li>create and delete databases;</li>
+<li>create, alter and delete tables and indices;</li>
+<li>add, change and delete data in tables;</li>
+<li>define, execute and store sql <strong>queries</strong>;</li>
+<li>create, alter and delete <strong>views</strong>;</li>
+<li><strong>import</strong> and <strong>export</strong> CSV data; </li>
+<li>define and use <strong>forms</strong>; and  </li>
+<li>define and print <strong>reports</strong></li>
+<li>write your own <strong>scripts</strong> in <a href="http://www.python.org" TARGET="_blank">Python</a></li>
+<li>use reports and queries in your own scripts with the command line tools
+<ul>
+<li>hk_actionquery</li>
+<li>hk_exportcsv</li>
+<li>hk_exportxml</li>
+<li>hk_importcsv</li>
+<li>hk_report</li>
+</ul>
+</li>
+</ul>
+<br>
+<h2>hk_kdeclasses offers you data widgets for KDE:</h2>
+<h3>high-level widgets</h3>
+<ul>
+<li><strong>hk_kdetable</strong><br> display and alter data in a grid and the
+possibility to alter the table structure</li>
+<li><strong>hk_kdequery</strong><br> allows you to define and execute a
+query</li>
+<li><strong>hk_kdeform</strong><br> allows you to design and view forms</li>
+<li><strong>hk_kdereport</strong><br> allows you to design and preview
+reports</li>
+</ul>
+<h3>low-level widgets</h3>
+<UL>
+<li><strong>hk_kdelineedit</strong> <br>a data sensitive standard field</li>
+<li><strong>hk_kdememo</strong><br>a data sensitive multiline field</li>
+<li><strong>hk_kdeboolean</strong><br>a data sensitive bool field</li>
+<li><strong>hk_kdecombobox</strong><br>a data sensitive combobox field</li>
+<li><strong>hk_kdegrid</strong><br>a data sensitive grid</li>
+<li><strong>hk_kderowselector</strong><br>a row selector to browse a table</li>
+</ul>
 
+ */
 using namespace std;
 
 #define  HK_DEBUG
-#define HK_VERSION "080"
+#define HK_VERSION "081"
 /*
 ** The HK_VERSION_NUMBER is an integer with the value
 ** (X*100000 + Y*1000 + Z). For example, for version "3.1.2",
@@ -29,7 +93,7 @@ using namespace std;
 #ifdef HK_VERSION_NUMBER
 # undef HK_VERSION_NUMBER
 #endif
-#define HK_VERSION_NUMBER 0008000
+#define HK_VERSION_NUMBER 0008001
 
 
 #ifdef HAVE_NO_SSTREAM
@@ -40,8 +104,10 @@ using namespace std;
 #define STRINGSTREAM stringstream
 #endif
 
+
+
 /**
- *@version $Revision: 1.62 $
+ *@version $Revision: 1.66 $
  */
 enum filetype{ft_table=1,ft_query=2,ft_form=3,ft_report=4,ft_view=6,ft_referentialintegrity=7};
 enum listtype{lt_table=1,lt_query=2,lt_form=3,lt_report=4,lt_index=5,lt_view=6};
@@ -135,6 +201,7 @@ typedef void    data_configurefunctiontype(hk_reportdata*);
 
 typedef void voidfunction(void);
 
+typedef struct_raw_data* psimagedatatype(struct_raw_data* imgdata,const hk_string& file,hk_string& errormsg);
 union number
 {
     long integer;
