@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.34 $
+//$Revision: 1.35 $
 #include "hk_dscombobox.h"
 #include "hk_datasource.h"
 #include "hk_dsgridcolumn.h"
@@ -52,7 +52,7 @@ bool operator=(const hk_dscomboboxmodeprivate& v)
 class hk_listvisible :public hk_dsdatavisible
 {
     public:
-        hk_listvisible(hk_dscombobox* combo,hk_form* form):hk_dsdatavisible()
+        hk_listvisible(hk_dscombobox* combo,hk_form* ):hk_dsdatavisible()
         {
 #ifdef HK_DEBUG
 //wanna_debug(true);
@@ -153,7 +153,7 @@ class hk_listvisible :public hk_dsdatavisible
 //************************************************************************
 //************************************************************************
 
-hk_dscombobox::hk_dscombobox(hk_form* form):hk_dsdatavisible(form)
+hk_dscombobox::hk_dscombobox(hk_form* f):hk_dsdatavisible(f)
 {
 #ifdef HK_DEBUG
 //wanna_debug(true);
@@ -163,7 +163,7 @@ hk_dscombobox::hk_dscombobox(hk_form* form):hk_dsdatavisible(form)
     p_designdata=new hk_dscomboboxmodeprivate;
     p_viewdata=new hk_dscomboboxmodeprivate;
     p_visibletype=combobox;
-    p_listvisible= new hk_listvisible(this,form);
+    p_listvisible= new hk_listvisible(this,f);
     p_listdatasource=-1;
     p_mode=combo;
     p_gridcolumn=NULL;
@@ -230,13 +230,13 @@ hk_datasource* hk_dscombobox::listdatasource(void)
 }
 
 
-void hk_dscombobox::set_listcolumnname(const hk_string& listcolumn,bool registerchange)
+void hk_dscombobox::set_listcolumnname(const hk_string& listcolumnnm,bool registerchange)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_dscombobox::set_listcolumnname");
 #endif
 
-    p_listvisible->set_columnname(listcolumn);
+    p_listvisible->set_columnname(listcolumnnm);
 
     has_changed(registerchange);
 }
@@ -248,12 +248,12 @@ hk_string hk_dscombobox::listcolumnname(void)
 }
 
 
-void hk_dscombobox::set_viewcolumnname(const hk_string& viewcolumn,bool registerchange)
+void hk_dscombobox::set_viewcolumnname(const hk_string& viewcolumnnm,bool registerchange)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_dscombobox::set_viewcolumnname");
 #endif
-    p_listvisible->set_viewcolumnname(viewcolumn);
+    p_listvisible->set_viewcolumnname(viewcolumnnm);
     has_changed(registerchange);
 
 }
@@ -316,10 +316,10 @@ void hk_dscombobox::loaddata(const hk_string& definition)
 
         int i=1;
         p_designdata->p_textlist.clear();
-	hk_string value;
-        while (get_tagvalue(definition,"LISTELEMENT",value,i))
+	hk_string valuestring;
+        while (get_tagvalue(definition,"LISTELEMENT",valuestring,i))
         {
-            p_designdata->p_textlist.push_back(value);
+            p_designdata->p_textlist.push_back(valuestring);
             ++i;
         }
     get_tagvalue(definition,"ONSELECT_ACTION",p_designdata->p_onselectaction);
