@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.61 $
+//$Revision: 1.63 $
 #include "hk_dsdatavisible.h"
 #include "hk_form.h"
 #include "hk_datasource.h"
@@ -371,11 +371,9 @@ void    hk_dsdatavisible::set_defaultvalue(const hk_string& def,bool registercha
     {
     p_designdata->p_defaultvalue=def;
     p_designdata->p_usedefault=true;
-
     }
     p_viewdata->p_usedefault=true;
     p_viewdata->p_defaultvalue=def;
-
     has_changed(registerchange);
 
 }
@@ -390,9 +388,8 @@ hk_string  hk_dsdatavisible::raw_defaultvalue(void)
 
 hk_string  hk_dsdatavisible::defaultvalue(void)
 {
-
     if (!p_column)
-    {
+    { 
     if (p_presentation && p_presentation->mode()==hk_presentation::viewmode)
     return p_viewdata->p_defaultvalue;
     else
@@ -402,7 +399,9 @@ hk_string  hk_dsdatavisible::defaultvalue(void)
 
     switch  (p_column->columntype())
     {
-        case hk_column::auto_inccolumn :  return hk_translate("[Auto]");
+        case hk_column::auto_inccolumn :  { 
+        					return hk_translate("[Auto]");
+        				  }
         case hk_column::datecolumn :  dt=p_date.date_asstring();break;
         case hk_column::timecolumn :  dt=p_date.time_asstring();break;
         case hk_column::datetimecolumn :;
@@ -410,12 +409,12 @@ hk_string  hk_dsdatavisible::defaultvalue(void)
         default:dt=p_date.datetime_asstring();
     }
     hk_string p_res=(p_presentation && p_presentation->mode()==hk_presentation::viewmode?p_viewdata->p_defaultvalue:p_designdata->p_defaultvalue);
+    if (!p_presentation &&p_viewdata->p_defaultvalue.size()>0)p_res=p_viewdata->p_defaultvalue;
     p_res=replace_all("%NOW%",p_res,dt);
     p_res=replace_all("%NOWTIME%",p_res,p_date.time_asstring());
     p_res=replace_all("%NOWDATE%",p_res,p_date.date_asstring());
     p_res=replace_all("%TRUE%",p_res,"TRUE");
     p_res=replace_all("%FALSE%",p_res,"FALSE");
-
     return p_res;
 }
 
@@ -452,23 +451,23 @@ void hk_dsdatavisible::before_insert_row(void)
 }
 
 
-void    hk_dsdatavisible::set_numberformat(bool use_numberseparator, int commadigits,bool registerchange)
+void    hk_dsdatavisible::set_numberformat(bool numsep, int dig,bool registerchange)
 {
-   set_numberformat(use_numberseparator,commadigits,registerchange,false);
+   set_numberformat(numsep,dig,registerchange,false);
 }
 
 
-void    hk_dsdatavisible::set_numberformat(bool use_numberseparator, int commadigits,bool registerchange,bool force_setting)
+void    hk_dsdatavisible::set_numberformat(bool numsep, int dig,bool registerchange,bool force_setting)
 {
 
     if (allow_datachanging(force_setting))
     {
-    p_designdata->p_use_numberseparator=use_numberseparator;
-    p_designdata->p_precision=(commadigits<0?-1:commadigits);
+    p_designdata->p_use_numberseparator=numsep;
+    p_designdata->p_precision=(dig<0?-1:dig);
 
     }
-    p_viewdata->p_use_numberseparator=use_numberseparator;
-    p_viewdata->p_precision=(commadigits<0?-1:commadigits);
+    p_viewdata->p_use_numberseparator=numsep;
+    p_viewdata->p_precision=(dig<0?-1:dig);
     widget_specific_numberformat();
     has_changed(registerchange);
 }
@@ -532,7 +531,7 @@ hk_string hk_dsdatavisible::value_at(unsigned long at)
     hkdebug("hk_dsdatavisible::value_at");
 #endif
     if (!column()) return p_private->p_value;
-    hk_string value;
+    hk_string valuestring;
     bool is_null=false;
     if (p_column->has_changed() &&
         ((datasource()->row_position()==at&&datasource()->mode()!=hk_datasource::mode_insertrow)
@@ -540,28 +539,28 @@ hk_string hk_dsdatavisible::value_at(unsigned long at)
 
         )
 	{
-        value=p_column->changed_data_asstring();
+        valuestring=p_column->changed_data_asstring();
 	is_null=p_column->changed_data_is_nullvalue();
 	}
     else
     if (datasource()->mode()==hk_datasource::mode_insertrow&& at>= datasource()->max_rows()&& use_defaultvalue())
     {
-        value=defaultvalue();
-	is_null=(value.size()==0);
+        valuestring=defaultvalue();
+	is_null=(valuestring.size()==0);
     }
     else
     {
-        value=p_column->asstring_at(at,true);
+        valuestring=p_column->asstring_at(at,true);
 	is_null=p_column->is_nullvalue_at(at);
      }
-    if (!is_null&&is_numerictype(p_column)&&p_column->columntype()!=hk_column::auto_inccolumn&&value.length()>0
+    if (!is_null&&is_numerictype(p_column)&&p_column->columntype()!=hk_column::auto_inccolumn&&valuestring.length()>0
         || (p_column->columntype()==hk_column::auto_inccolumn
         && (datasource()->mode()!=hk_datasource::mode_insertrow||at<datasource()->max_rows())))
     {
-        value=format_number(value,true,use_numberseparator(),commadigits(),locale());
+        valuestring=format_number(valuestring,true,use_numberseparator(),commadigits(),locale());
     }
 
-    return value;
+    return valuestring;
 
 }
 
