@@ -8,14 +8,14 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.58 $
+//$Revision: 1.59 $
 #include "hk_dsgrid.h"
 #include "hk_form.h"
 #include "hk_column.h"
 #include "hk_datasource.h"
 #include "hk_database.h"
 #include "hk_dsgridcolumn.h"
-hk_dsgrid::hk_dsgrid(hk_form* form):hk_dsvisible(form)
+hk_dsgrid::hk_dsgrid(hk_form* f):hk_dsvisible(f)
 {
 #ifdef HK_DEBUG
 //wanna_debug(true);
@@ -322,7 +322,7 @@ void hk_dsgrid::set_gridcolumnwidth(unsigned int col,int newwidth)
     hkdebug("hk_dsgrid::set_gridcolumnwidth");
 #endif
 
-    if (((unsigned)col <p_cols.size())&&(col>=0))
+    if (((unsigned)col <p_cols.size()))
     {
         p_cols[col]->set_columnwidth(newwidth);
         if (p_holdrowdefinition)p_automatic_columns=false;
@@ -331,7 +331,7 @@ void hk_dsgrid::set_gridcolumnwidth(unsigned int col,int newwidth)
 }
 
 
-void hk_dsgrid::change_columnposition(unsigned int from, unsigned int to)
+void hk_dsgrid::change_columnposition(unsigned int fromp, unsigned int top)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_dsgrid::change_columnposition");
@@ -339,26 +339,26 @@ void hk_dsgrid::change_columnposition(unsigned int from, unsigned int to)
 
     hk_dsgridcolumn* buffer;
 
-    if ((from==to))return;
-    if ((from<p_cols.size())&&(to<=p_cols.size()))
+    if ((fromp==top))return;
+    if ((fromp<p_cols.size())&&(top<=p_cols.size()))
     {
 
-        if (from<to)
+        if (fromp<top)
         {                                         //from<to von links nach rechts
-            buffer=p_cols[from];
-            for(unsigned int k=from;k<to-1;k++)
+            buffer=p_cols[fromp];
+            for(unsigned int k=fromp;k<top-1;k++)
                 p_cols[k]=p_cols[k+1];
 
-            p_cols[to-1]=buffer;
+            p_cols[top-1]=buffer;
         }
         else
         {                                         //from>to  = von rechts nach links
 
-            buffer=p_cols[from];
-            for(unsigned int k=from;k>to;k--)
+            buffer=p_cols[fromp];
+            for(unsigned int k=fromp;k>top;k--)
                 p_cols[k]=p_cols[k-1];
 
-            p_cols[to]=buffer;
+            p_cols[top]=buffer;
 
         }
 
@@ -546,10 +546,10 @@ void hk_dsgrid::set_gridcolumns(list<hk_string>&sl)
 //now store the whole chose
     clear_cols();
     p_cols.resize(newcols.size());
-    for (unsigned int k=0;k<newcols.size();k++)
+    for (unsigned int kl=0;kl<newcols.size();kl++)
     {
-        delete p_cols[k];
-	p_cols[k]=newcols[k];
+        delete p_cols[kl];
+	p_cols[kl]=newcols[kl];
     }
 
     if (p_holdrowdefinition)p_automatic_columns=false;
