@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.37 $
+//$Revision: 1.38 $
 #include "hk_dsvisible.h"
 #include "hk_database.h"
 #include "hk_presentation.h"
@@ -50,7 +50,7 @@ public:
 
 };
 
-hk_dsvisible::hk_dsvisible(hk_presentation* presentation):hk_visible(presentation)
+hk_dsvisible::hk_dsvisible(hk_presentation* p):hk_visible(p)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_dsvisible::constructor");
@@ -330,7 +330,7 @@ void hk_dsvisible::before_source_vanishes(void)
 }
 
 
-void    hk_dsvisible::list_changes(listtype type)
+void    hk_dsvisible::list_changes(listtype )
 {
 }
 
