@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.71 $
+//$Revision: 1.74 $
 #include "hk_form.h"
 #include "hk_visible.h"
 #include "hk_dsdatavisible.h"
@@ -42,11 +42,13 @@ hk_formprivate()
 {
 p_masterform=NULL;
 p_subform=NULL;
+p_while_loading=false;
 }
         list<hk_visible*>   p_visibles;
 	hk_form* p_masterform;
 	hk_subform* p_subform;
 	hk_string p_loadformname;
+	bool p_while_loading;
 
 };
 
@@ -385,7 +387,7 @@ void        hk_form::set_designsize(unsigned int w, unsigned int h,bool register
 }
 
 
-void        hk_form::widget_specific_fieldresize(hk_visible* v)
+void        hk_form::widget_specific_fieldresize(hk_visible* )
 {
 
 }
@@ -451,13 +453,19 @@ void hk_form::load_form(const hk_string& n)
     if (n.size()>0) set_name(n);
     enum_mode modebuffer=mode();
     hk_dsmodevisible::set_mode(designmode);
-    if (name().size()==0) if (!ask_name())return ;
+    p_private->p_while_loading=true;
+    if (name().size()==0) if (!ask_name())
+      {
+       p_private->p_while_loading=false;
+       return ;
+      }
     hk_string res =database()->load(name(),ft_form);
     p_private->p_loadformname=n;
     if (res.size()==0) show_warningmessage(hk_translate("Bug: form is empty!"));
     if ( res.find("encoding=\"UTF-8\"")<res.size() ) res=u2l(res);
 
     loaddata(res);
+    p_private->p_while_loading=false;
     hk_dsmodevisible::set_mode(modebuffer);
     widget_specific_after_loadform();
     reset_has_changed();
@@ -465,9 +473,18 @@ void hk_form::load_form(const hk_string& n)
 #ifdef HK_DEBUG
     hkdebug("hk_form::load_form ENDE");
 #endif
+}
+
+bool hk_form::while_load_form(void) const
+{
+  return p_private->p_while_loading;
 
 }
 
+bool hk_form::while_loading(void)
+{
+  return while_load_form();
+}
 
 void    hk_form::savedata(ostream& s)
 {
@@ -553,31 +570,31 @@ void    hk_form::loaddata(const hk_string& definition)
 }
 
 
-hk_visible* hk_form::new_object(const hk_string& name)
+hk_visible* hk_form::new_object(const hk_string& newname)
 {
-    if (name=="BUTTON") return new_button();
+    if (newname=="BUTTON") return new_button();
     else
-    if (name=="SELECTOR") return new_rowselector();
+    if (newname=="SELECTOR") return new_rowselector();
         else
-        if (name=="BOOLEAN") return new_bool();
+        if (newname=="BOOLEAN") return new_bool();
             else
-            if (name=="LINEEDIT") return new_lineedit();
+            if (newname=="LINEEDIT") return new_lineedit();
                 else
-                if (name=="MEMO") return new_memo();
+                if (newname=="MEMO") return new_memo();
                     else
-                    if (name=="COMBOBOX") return new_combobox();
+                    if (newname=="COMBOBOX") return new_combobox();
                         else
-                        if (name=="GRID") return new_grid();
+                        if (newname=="GRID") return new_grid();
                             else
-                            if (name=="TEXTLABEL") return new_label();
+                            if (newname=="TEXTLABEL") return new_label();
                             else
-                            if (name=="SUBFORM") return new_subform();
+                            if (newname=="SUBFORM") return new_subform();
                             else
-                            if (name=="IMAGE") return new_image();
+                            if (newname=="IMAGE") return new_image();
                             else
-                            if (name=="DATE") return new_date();
+                            if (newname=="DATE") return new_date();
                             else
-                            if (name=="TABVISIBLE") return new_tabvisible();
+                            if (newname=="TABVISIBLE") return new_tabvisible();
 
                                 return NULL;
 }
@@ -619,7 +636,7 @@ hk_visible* hk_form::get_visible(long nr)
     return NULL;
 }
 
-hk_visible* hk_form::get_visible(const hk_string &identifier)
+hk_visible* hk_form::get_visible(const hk_string &i)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_form::get_visible(identifier)");
@@ -627,7 +644,7 @@ hk_visible* hk_form::get_visible(const hk_string &identifier)
     list<hk_visible*>::iterator it=p_private->p_visibles.begin();
     while (it!=p_private->p_visibles.end())
     {
-        if ( (*it)->identifier()==identifier) return (*it);
+        if ( (*it)->identifier()==i) return (*it);
         it++;
     }
     return NULL;
@@ -669,14 +686,15 @@ void hk_form::bulk_operation(enum_bulkoperation bulkoperation)
 
 bool    hk_form::set_mode(enum_mode s)
 {// cerr <<"hk_form::set_mode: "<<(s==viewmode?"viewmode":"designmode")<<endl;
+    if (p_private->p_while_loading) return false;
     list<hk_visible*>::iterator it=p_private->p_visibles.begin();
 	while (it!=p_private->p_visibles.end())
         {
 	    if (s==viewmode&& (*it)->type()==subform)
 
 	    {
-	      hk_subform* s=static_cast<hk_subform*>(*it);
-	      s->internal_set_datasourcevalues();
+	      hk_subform* sub=static_cast<hk_subform*>(*it);
+	      sub->internal_set_datasourcevalues();
 	    }
 	    ++it;
         }
@@ -935,3 +953,11 @@ int hk_form::screen_height()
 {
 return -1;
 }
+
+
+
+bool hk_form::show_asdialog(hk_form*)
+{
+return false;
+}
+
