@@ -31,7 +31,7 @@ class hk_formmodeprivate;
 /**
  *
  *@short  base class for forms
- *@version $Revision: 1.48 $
+ *@version $Revision: 1.50 $
  *@author Horst Knorr (hk_classes@knoda.org)
  *
  */
@@ -172,10 +172,12 @@ virtual void set_focus(hk_visible*){}
         list<hk_visible*>*  visibles(void);
 	bool is_subform() const;
 virtual bool is_subpresentation(void);
-virtual bool show_asdialog(hk_form* parentform=NULL){return false;}
+virtual bool show_asdialog(hk_form* parentform=NULL);
 
 virtual int screen_width();
 virtual int screen_height();
+bool while_load_form(void) const;
+virtual bool while_loading(void);
     protected:
         void set_masterform(hk_form*);
         virtual hk_dsgrid*      widget_specific_new_grid(void){return NULL;}
