@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.42 $
+//$Revision: 1.43 $
 #include "hk_importcsv.h"
 #include "hk_database.h"
 #include "hk_column.h"
@@ -416,19 +416,19 @@ p_datamode=true;
 }
 
 
-void    hk_importcsv::set_filedefinition(const hk_string& fielddelimiter,const hk_string& betweenfields, const hk_string& rowdelimiter, const hk_string& datetimeformat, const hk_string& dateformat, const hk_string& timeformat,const hk_string& charset,const hk_string& locale)
+void    hk_importcsv::set_filedefinition(const hk_string& fielddel,const hk_string& between, const hk_string& rowdel, const hk_string& datetimef, const hk_string& datef, const hk_string& timef,const hk_string& charst,const hk_string& l)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_importcsv::set_filedefinition");
 #endif
-    p_textdelimiter=fielddelimiter;
-    if (betweenfields.size()>0) p_betweenfields=betweenfields;
-    p_rowdelimiter=rowdelimiter;
-    if (datetimeformat.size()>0)p_datetimeformat=datetimeformat;
-    if (timeformat.size()>0) p_timeformat=timeformat;
-    if (dateformat.size()>0) p_dateformat=dateformat;
-    p_charset=charset;
-    p_locale=locale;
+    p_textdelimiter=fielddel;
+    if (between.size()>0) p_betweenfields=between;
+    p_rowdelimiter=rowdel;
+    if (datetimef.size()>0)p_datetimeformat=datetimef;
+    if (timef.size()>0) p_timeformat=timef;
+    if (datef.size()>0) p_dateformat=datef;
+    p_charset=charst;
+    p_locale=l;
 }
 
 
@@ -508,17 +508,17 @@ vector<hk_string>* hk_importcsv::create_valuelist( hk_string& row)
 //cout <<"SUCHSTRING: "<<row<<endl;
     while (offset<=row.size())
     {
-        hk_string x(1,row[offset]);               //row[offset];
+        hk_string xc(1,row[offset]);               //row[offset];
         ++offset;
         switch (state)
         {
             case S_START :
-                if ( p_textdelimiter==x)
+                if ( p_textdelimiter==xc)
                 {
                     state = S_QUOTED_FIELD;      // cout <<"S_STARTED set S_QUOTED_FIELD"<<endl;
                     if (!p_datamode) field="X";   //to mark that this is a field of type string
                 }
-                else if (x == p_betweenfields||x==p_rowdelimiter)
+                else if (xc == p_betweenfields||xc==p_rowdelimiter)
                 {
                                                   //cout <<"LEERZEILTE S_START"<<endl;
                     p_valuelist.insert(p_valuelist.end(),"");//cerr <<"FIELD: "<<""<<endl;
@@ -526,14 +526,14 @@ vector<hk_string>* hk_importcsv::create_valuelist( hk_string& row)
                 }
                  else
                 {
-                    field += x;
+                    field += xc;
                     state = S_NORMAL_FIELD; //cout <<"S_STARTED MAYBE_NORMAL";
                 }
                 break;
 
 
             case S_QUOTED_FIELD :
-                if (x == p_textdelimiter)
+                if (xc == p_textdelimiter)
                 {
                                                 //  cout <<"S_QUOTED_FIELD set S_MAYBE_END_OF_QUOTED_FIELD"<<endl;
                     state = S_MAYBE_END_OF_QUOTED_FIELD;
@@ -541,18 +541,18 @@ vector<hk_string>* hk_importcsv::create_valuelist( hk_string& row)
 
                 else
                 {
-                    field += x;
+                    field += xc;
                 }
                 break;
 
             case S_MAYBE_END_OF_QUOTED_FIELD :
-                if (x == p_textdelimiter)
+                if (xc == p_textdelimiter)
                 {
-                    field += x;
+                    field += xc;
                     state = S_QUOTED_FIELD;
 		   // cerr <<"von S_MAYBE_END_OF_QUOTED_FIELD nach S_QUOTED_FIELD"<<endl;
                 }
-                else if (x == p_betweenfields||x==p_rowdelimiter  )
+                else if (xc == p_betweenfields||xc==p_rowdelimiter  )
                 {
                                           //        cout <<"S_MAYBE_END_OF_QUOTED_FIELD "<<field<<endl;
                     p_valuelist.insert(p_valuelist.end(),field);//cerr <<"FIELD: "<<field<<endl;
@@ -567,7 +567,7 @@ vector<hk_string>* hk_importcsv::create_valuelist( hk_string& row)
 
 
 	    case S_END_OF_QUOTED_FIELD :
-                if (x == p_betweenfields ||x==p_rowdelimiter)
+                if (xc == p_betweenfields ||xc==p_rowdelimiter)
                 {
                                                  // cout <<"S_END_OF_QUOTED_FIELD  nach S_START"<<field<<" x="<<x<<endl;
                     p_valuelist.insert(p_valuelist.end(),field);//cerr <<"FIELD: "<<field<<endl;
@@ -583,7 +583,7 @@ vector<hk_string>* hk_importcsv::create_valuelist( hk_string& row)
 
 
 	    case S_NORMAL_FIELD :
-                if (x == p_betweenfields ||x==p_rowdelimiter)
+                if (xc == p_betweenfields ||xc==p_rowdelimiter)
                 {
                                               //    cout <<"S_NORMAL_FIELD "<<field<<endl;
                     p_valuelist.insert(p_valuelist.end(),field);//cerr <<"FIELD: "<<field<<endl;
@@ -592,7 +592,7 @@ vector<hk_string>* hk_importcsv::create_valuelist( hk_string& row)
                 }
                 else
                 {
-                    field += x;
+                    field += xc;
                 }
         }
     }
@@ -844,9 +844,9 @@ bool hk_importcsv::detect_autoinc(void) const
   return p_detect_autoinc;
 }
 
-void hk_importcsv::set_progressdialog(progress_dialogtype* progressdialog)
+void hk_importcsv::set_progressdialog(progress_dialogtype* p)
 {
-p_progressdialog=progressdialog;
+p_progressdialog=p;
 }
 
 progress_dialogtype* hk_importcsv::progressdialog(void)const
