@@ -8,6 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
+#include <Python.h>
 #include "hk_interpreter.h"
 #include "hk_button.h"
 #include "hk_dslineedit.h"
@@ -26,8 +27,7 @@
 #include "hk_report.h"
 #include "hk_reportdata.h"
 
-#ifdef HAVE_PYTHON
-#include <Python.h>
+
 class hk_pythoninterpreterprivate
 {
 public:
@@ -37,7 +37,7 @@ PyObject* p_locals;
 };
 
 
-#endif
+
 static hk_visible* p_currentobject=NULL;
 
 hk_interpreter::hk_interpreter(hk_presentation* p)
@@ -204,7 +204,7 @@ void hk_no_interpreter::warning(void)
 
 
 
-#ifdef HAVE_PYTHON
+
 int hk_pythoninterpreter::p_referencecounting=0;
 
 hk_pythoninterpreter::hk_pythoninterpreter(hk_presentation* p):hk_interpreter(p)
@@ -242,9 +242,9 @@ if (p_referencecounting==0)
 
 void hk_pythoninterpreter::init(void)
 {
-PyObject* module=PyImport_AddModule("__main__");
+PyObject* module=PyImport_AddModule(const_cast<char*>("__main__"));
 PyObject* main_namespace=PyModule_GetDict(module);
-PyRun_SimpleString((char*)"import sys\nfrom hk_classes import *\nimport rexec\n");
+PyRun_SimpleString(const_cast<char*>("import sys\nfrom hk_classes import *\nimport rexec\n"));
 
 if (p_privatdata->p_globals)
 	{
@@ -493,7 +493,7 @@ if (script.size()==0) return true;
 //cerr <<"action: "<<action<<"  script: "<<script<<endl<<endl;
 
 hk_string hk="hk_this="+pystatement();
-PyObject*result=PyRun_String((char*)hk.c_str(),Py_file_input,p_privatdata->p_globals,p_privatdata->p_locals);
+PyObject*result=PyRun_String(const_cast<char*>(hk.c_str()),Py_file_input,p_privatdata->p_globals,p_privatdata->p_locals);
 hk_string errormsg=hk_translate("\nThis is due to an installation error. If you did install hk_classes from and .rpm or .deb package you should check if there is also a hk_classes-python package");
 if (!result)
    {
@@ -505,7 +505,7 @@ if (!result)
    if (f)
    {
      hk="hk_thisform=cast_form(hk_this.presentation())";
-    result=PyRun_String((char*)hk.c_str(),Py_file_input,p_privatdata->p_globals,p_privatdata->p_locals);
+    result=PyRun_String(const_cast<char*>(hk.c_str()),Py_file_input,p_privatdata->p_globals,p_privatdata->p_locals);
     if (!result)
      {
       show_warningmessage("error while loading hk_thisform: "+hk+errormsg);
@@ -519,7 +519,7 @@ if (!result)
     if (r)
     {
       hk="hk_thisreport=cast_report(hk_this.presentation())";
-      result=PyRun_String((char*)hk.c_str(),Py_file_input,p_privatdata->p_globals,p_privatdata->p_locals);
+      result=PyRun_String(const_cast<char*>(hk.c_str()),Py_file_input,p_privatdata->p_globals,p_privatdata->p_locals);
       if (!result)
        {
         show_warningmessage("error while loading hk_thisreport: "+hk+errormsg);
@@ -528,7 +528,7 @@ if (!result)
    }
   }
   hk_string sc=script+"\n";
-result=PyRun_String((char*)sc.c_str(),Py_file_input,p_privatdata->p_globals,p_privatdata->p_locals);
+result=PyRun_String(const_cast<char*>(sc.c_str()),Py_file_input,p_privatdata->p_globals,p_privatdata->p_locals);
 
 if (!result)
 { //an error occured
@@ -554,11 +554,11 @@ PyObject* type,*value,*traceback;
 PyObject* ln=NULL;
 if (traceback)
    {
-    ln=PyObject_GetAttrString(traceback,"tb_lineno");cerr <<"traceback object exists"<<endl;
+    ln=PyObject_GetAttrString(traceback,const_cast<char*>("tb_lineno"));
    }
    else
    {
-     ln=PyObject_GetAttrString(value,"lineno");cerr <<"no traceback object"<<endl;
+     ln=PyObject_GetAttrString(value,const_cast<char*>("lineno"));cerr <<"no traceback object"<<endl;
    }
 
 int linenumber=-1;
@@ -670,7 +670,7 @@ hk_dsdate* currentdsdate(void)
 
  }
 
-#endif //HAVE_PYTHON
+
 
  hk_button *cast_button(hk_visible* v)
  {
