@@ -37,7 +37,7 @@ class hk_subform;
 /**
  * hk_interpreter is the basic class for script handling
  * @short basic class for script handling
- *@version $Revision: 1.23 $
+ *@version $Revision: 1.24 $
  * @author Horst Knorr (hk_classes@knoda.org)
  */
 
@@ -178,7 +178,7 @@ private:
 /**
  * hk_nointerpreter always returns a warning message
  * @short basic dummy interpreter class that returns a warning message
- *@version $Revision: 1.23 $
+ *@version $Revision: 1.24 $
  *@internal
  * @author Horst Knorr (hk_classes@knoda.org)
  */
@@ -212,13 +212,13 @@ void warning(void);
  bool warning_already_displayed;
 };
 
-#ifdef HAVE_PYTHON
+
 
 class hk_pythoninterpreterprivate;
 /**
  * hk_pythoninterpreter is the basic class for Python script handling
  * @short basic class for Python script handling
- *@version $Revision: 1.23 $
+ *@version $Revision: 1.24 $
  *@internal
  * @author Horst Knorr (hk_classes@knoda.org)
  */
@@ -266,7 +266,7 @@ static int p_referencecounting;
 
 };
 
-#endif //HAVE_PYTHON
+
  hk_button* currentbutton(void);
  hk_dslineedit* currentlineedit(void);
  hk_dsmemo* currentmemo(void);
