@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.10 $
+//$Revision: 1.11 $
 #include "hk_label.h"
 class hk_labelmodeprivate
 {
@@ -31,7 +31,7 @@ public:
  }
 };
 
-hk_label::hk_label(hk_form* form):hk_visible(form)
+hk_label::hk_label(hk_form* f):hk_visible(f)
 {
 p_designdata=new hk_labelmodeprivate;
 p_viewdata=new hk_labelmodeprivate;
