@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.76 $
+//$Revision: 1.77 $
 
 #include "hk_presentation.h"
 #include "hk_database.h"
@@ -162,14 +162,14 @@ long hk_presentation::add_datasource(hk_datasource* d)
 }
 
 
-long    hk_presentation::new_datasource(const hk_string& name,datasourcetype dt)
+long    hk_presentation::new_datasource(const hk_string& newname,datasourcetype dt)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_presentation::new_datasource");
 #endif
     if (p_private->p_database==NULL) return -1;
-    hk_datasource* d=p_private->p_database->load_datasource(name,dt,this);
-    if (d) d->set_name(name,false);
+    hk_datasource* d=p_private->p_database->load_datasource(newname,dt,this);
+    if (d) d->set_name(newname,false);
     long i=add_datasource(d);
 #ifdef HK_DEBUG
     if (d)d->hkclassname(longint2string(i));
@@ -403,7 +403,7 @@ bool hk_presentation::set_mode(enum_mode s)
 }
 
 
-void hk_presentation::enable_datasources(bool enable,hk_datasource::enum_accessmode mode)
+void hk_presentation::enable_datasources(bool enable,hk_datasource::enum_accessmode m)
 {
     list<hk_datasource*>* mydatasources=datasources();
     list<hk_datasource*>::iterator it = mydatasources->begin();
@@ -414,7 +414,7 @@ void hk_presentation::enable_datasources(bool enable,hk_datasource::enum_accessm
             if ((*it)->datasource_used())
             {
                 if ((*it)->is_enabled()) (*it)->disable();
-                (*it)->set_accessmode(mode);
+                (*it)->set_accessmode(m);
                 //if (!((*it)->previous_enable_problems()))
 		   (*it)->enable();
             }
@@ -422,7 +422,7 @@ void hk_presentation::enable_datasources(bool enable,hk_datasource::enum_accessm
         else
         {
             (*it)->disable();
-            (*it)->set_accessmode(mode);
+            (*it)->set_accessmode(m);
         }
         it++;
     }
@@ -617,10 +617,10 @@ void hk_presentation::bulk_operation(enum_bulkoperation )
 
 
 
-void hk_presentation::set_sizetype(enum_sizetype type,bool registerchange)
+void hk_presentation::set_sizetype(enum_sizetype t,bool registerchange)
 {
-  if (type==p_private->p_sizetype) return;
-  p_private->p_sizetype=type;
+  if (t==p_private->p_sizetype) return;
+  p_private->p_sizetype=t;
   has_changed(registerchange);
   sizetype_changed();
 
@@ -669,7 +669,7 @@ hk_interpreter* hk_presentation::interpreter()
 
 }
 
-void hk_presentation::set_interpretername(const hk_string& n,bool registerchange)
+void hk_presentation::set_interpretername(const hk_string& n,bool /*registerchange*/)
 {
  p_private-> p_interpretername=n;
 }
