@@ -323,7 +323,7 @@ hk_string hk_qbe::create_where(void)
 
     if (i<condi.size() && condi[i].size()>0)
     {
-          if (where.size()>0) where+=") AND (";
+          if (where.size()>0) where+=")\n  AND (";
 	  hk_qbedataclass* cl=&(*it);
 
     if (cl->table>-1)
@@ -352,7 +352,7 @@ hk_string hk_qbe::create_where(void)
   if (where.size()>0)
      {
      where="(("+where+"))";
-     if (result.size()>0) result+=" OR "+where;
+     if (result.size()>0) result+="\n  OR "+where;
      else result=where;
      }
   }  // end for
@@ -360,7 +360,7 @@ hk_string hk_qbe::create_where(void)
   if (result.size() > 0 )
   {
     if(depending.size() > 0)
-        result="("+result+") AND ("+depending+" )";
+        result="("+result+")\n  AND ("+depending+" )";
   }
   else result=depending;
   return result;
@@ -377,13 +377,16 @@ hk_string hk_qbe::create_depending_where(void)
 #ifdef HK_DEBUG
     hkdebug("hk_qbe::create_depending_where");
 #endif
-
   list<hk_datasource*>::iterator it=datasources()->begin();
   hk_string newwhere;
   while (it!=datasources()->end())
   {
+    
+    if (it==datasources()->begin())
+           if ((*it)->database()->connection()->server_supports(hk_connection::SUPPORTS_SQL_JOINS)) return "";
+
     hk_datasource* p_depending_on_datasource=(*it)->depending_on();
-    if (p_depending_on_datasource!=NULL)
+    if (p_depending_on_datasource!=NULL &&!((*it)->depending_on_is_left_join()))
     {
         list<hk_string>::iterator this_ds;
         list<hk_string>::iterator master_ds;
@@ -394,7 +397,7 @@ hk_string hk_qbe::create_depending_where(void)
             if (newwhere=="")
 	     newwhere="(";
 	     else
-             newwhere=newwhere+") AND (";
+             newwhere=newwhere+")\n  AND (";
             newwhere=newwhere+"\""+unique_shortdatasourcename((*it)->presentationnumber())+"\".\""+*this_ds+"\"=";
 	    newwhere=newwhere+"\""+unique_shortdatasourcename(p_depending_on_datasource->presentationnumber())+"\""
             +"."+"\""+*master_ds+"\"";
@@ -423,19 +426,47 @@ hk_string result;
 
   list<hk_datasource*>::iterator it=datasources()->begin();
   bool needs_table_as=false;
+  bool supports_left_join=false;
   while (it!=datasources()->end())
   {
-  if (it==datasources()->begin()) needs_table_as=(*it)->database()->connection()->server_needs(hk_connection::NEEDS_TABLE_ALIAS_AS);
-  if (result.size()>0) result+=" , ";
+   (*it)->depending_on();
+   ++it;
+  }
+  it=datasources()->begin();
+  while (it!=datasources()->end())
+  {
+  if (it==datasources()->begin())
+    {
+     needs_table_as=(*it)->database()->connection()->server_needs(hk_connection::NEEDS_TABLE_ALIAS_AS);
+     supports_left_join=(*it)->database()->connection()->server_supports(hk_connection::SUPPORTS_SQL_JOINS);
+    }
   switch (p_private->p_querytype)
   {
   case qt_update:
   case qt_delete:
+  		  if (result.size()>0) result+=" , ";
   		  result+="\""+(*it)->name()+"\"";
 		  break;
-  default: result+="\""+(*it)->name()+"\""
-           +(needs_table_as?" AS ":" ");
-           result+="\""+unique_shortdatasourcename((*it)->presentationnumber())+"\"";
+  default: 
+  	   if (supports_left_join && (*it)->depending_on()) break;
+  	     if (result.size()>0) result+=" ,\n";
+
+           result+="\""+(*it)->name()+"\""
+          +(needs_table_as?" AS ":" ");
+          result+="\""+unique_shortdatasourcename((*it)->presentationnumber())+"\"";
+ 
+ 	list <hk_datasource*>* l=(*it)->dependinglist();
+ 	if (l->size()>0)
+ 	{
+ 	list <hk_datasource*>::iterator dit=l->begin();
+ 	while (dit!=l->end())
+ 	 {
+   	  result+=joindefinition(*dit);
+   	  ++dit;
+ 	 }
+ 	}
+  
+  	   
   }
   ++it;
   }
@@ -444,6 +475,69 @@ hk_string result;
 }
 
 
+hk_string hk_qbe::joindefinition(hk_datasource* ds)
+{
+ if (!ds || !ds->database()->connection()->server_supports(hk_connection::SUPPORTS_SQL_JOINS)) return "";
+ hk_string result;
+  bool   needs_table_as=ds->database()->connection()->server_needs(hk_connection::NEEDS_TABLE_ALIAS_AS);
+  bool   supports_left_join=ds->database()->connection()->server_supports(hk_connection::SUPPORTS_SQL_JOINS);
+  	   
+ if (supports_left_join && ds->depending_on_presentationdatasource()>-1 && ds->depending_on_is_left_join())
+     {
+  	     result="\n"+ds->database()->connection()->left_join_statement();
+     }
+     else
+     {
+       result="\n"+ds->database()->connection()->inner_join_statement();
+     }
+
+
+
+       hk_string malias=unique_shortdatasourcename(ds->depending_on_presentationdatasource());
+       hk_string salias=unique_shortdatasourcename(ds->presentationnumber());
+       result+="\""+ds->name()+"\""
+          +(needs_table_as?" AS ":" ");
+          result+="\""+salias+"\"\n ON ";
+           
+           
+       list<hk_string>::iterator this_ds;
+       list<hk_string>::iterator master_ds;
+       master_ds=ds->depending_on_masterfields()->begin();
+       hk_string newwhere;
+       for (this_ds=ds->depending_on_thisfields()->begin();
+            this_ds!=ds->depending_on_thisfields()->end();this_ds++)
+            {
+            if (newwhere=="")
+	     newwhere="(";
+	     else
+             newwhere=newwhere+")\n  AND (";
+            newwhere=newwhere+"\""+salias+"\".\""+*this_ds+"\"=";
+	    newwhere=newwhere+"\""+malias+"\""
+            +"."+"\""+*master_ds+"\"";
+
+            master_ds++;
+
+           }
+
+            if (newwhere.size()>0) newwhere+=")";
+            result+=newwhere;
+           
+ 
+
+ list <hk_datasource*>* l=ds->dependinglist();
+ if (l->size()>0)
+ {
+ list <hk_datasource*>::iterator dit=l->begin();
+ while (dit!=l->end())
+ {
+   result+=joindefinition(*dit);
+   ++dit;
+ }
+ }
+ 
+ return result;
+
+}
 
 
 
@@ -594,16 +688,16 @@ hk_string hk_qbe::create_select_sql(bool& valid)
        return "";
      }
 
-  result=(p_private->p_distinct?"SELECT DISTINCT ":"SELECT ")+result+" FROM " +from;
+  result=(p_private->p_distinct?"SELECT DISTINCT ":"SELECT ")+result+"\nFROM\n" +from;
   hk_string where=create_where();
   if (where.size()>0)
      {
-       result+=" WHERE "+where;
+       result+="\nWHERE "+where;
      }
   hk_string orderby=create_order_by();
   if (orderby.size()>0)
      {
-       result+=" ORDER BY "+orderby;
+       result+="\nORDER BY "+orderby;
      }
      valid=true;
   return result;
@@ -635,7 +729,7 @@ hk_string hk_qbe::create_groupselect_sql(bool& valid)
 
 
 
-  result=(p_private->p_distinct?"SELECT DISTINCT ":"SELECT ")+result+" FROM " +from;
+  result=(p_private->p_distinct?"SELECT DISTINCT ":"SELECT ")+result+"\nFROM\n" +from;
   hk_string group_by=create_group_by();
   if (group_by.size()==0)
      {
@@ -643,17 +737,17 @@ hk_string hk_qbe::create_groupselect_sql(bool& valid)
        valid=false;
        return "";
      }
-  result+=" GROUP BY "+group_by;
+  result+="\nGROUP BY\n"+group_by;
 
   hk_string where=create_where();
   if (where.size()>0)
      {
-       result+=" WHERE "+where;
+       result+="\nWHERE\n "+where;
      }else cerr <<"WHERE.size()==0!"<<endl;
   hk_string orderby=create_order_by();
   if (orderby.size()>0)
      {
-       result+=" ORDER BY "+orderby;
+       result+="\nORDER BY "+orderby;
      }
      valid=true;
 
@@ -719,7 +813,7 @@ hk_string hk_qbe::create_delete_sql(bool& valid)
   hk_string where=create_where();
   if (where.size()>0)
      {
-       result+=" WHERE "+where;
+       result+="\nWHERE\n "+where;
      }
 
 
