@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-// $Revision: 1.106 $
+// $Revision: 1.124 $
 #include "hk_report.h"
 #include "hk_reportsection.h"
 #include "hk_reportsectionpair.h"
@@ -34,9 +34,15 @@ public:
 hk_reportprivate()
   {
     p_while_executing=false;
+    p_print_full_pages_only=false;
+    p_nostrstream=false;
     p_rowposition=0;
+    p_fullpagereplacefunction=NULL;
     p_progressdialog=NULL;
     p_locale="";
+    p_useencodingtab=false;
+    p_cleanpage=true;
+    p_while_load_report=false;
   }
 ~hk_reportprivate(){}
 hk_string p_on_new_page_action;
@@ -51,6 +57,8 @@ hk_string p_on_new_page_action;
         unsigned int p_borderright;
         unsigned int p_bordertop;
         unsigned int p_borderbottom;
+        bool p_cleanpage;//used to mark whether a page is still virgin
+        bool p_while_load_report;
         hk_string       p_begin;
         hk_string       p_end;
         hk_string       p_filebegin;
@@ -82,13 +90,18 @@ hk_string p_on_new_page_action;
         int     p_default_precision;
         bool    p_default_use_thousandsseparator;
         list<hk_string> p_usedfonts;
+        list<hk_string> p_usedpsfonts;
         list<hk_string> p_suppliedfonts;
+        list<hk_string> p_suppliedfontspsnames;
         list<hk_string> p_neededfonts;
         hk_reportsection* p_datasection;
         bool p_use_standardpath;
+        bool p_print_full_pages_only;
         hk_string p_defaultfilename;
         hk_string p_outputfile;
         recodefunctiontype*     p_recodefunction;
+        recodefunctiontype*     p_fullpagereplacefunction;
+        hk_string p_fullpagereplacefunctionstring;
         hk_report::pageformattype p_pageformat;
         hk_report::orientationtype p_orientation;
         report_configurefunction* p_configurefunction;
@@ -103,6 +116,14 @@ hk_string p_on_new_page_action;
         bool p_while_executing;
         progress_dialogtype* p_progressdialog;
 	hk_string p_loadreportname;
+	hk_encodingtab p_encodingtab;
+	STRINGSTREAM p_stringstream;
+	bool p_nostrstream;
+	bool p_useencodingtab;
+	hk_string p_embeddedfontsdefinition;
+	int tag_FONT,tag_PSFONT,tag_PSEMBEDDEDFONTS,tag_FONTSIZE,tag_PTIME,tag_ABSOLUTEPAGENUMBER,tag_PAGENUMBER,
+	tag_BORDERLEFT,tag_BORDERRIGHT,tag_BORDERTOP,tag_BORDERBOTTOM,tag_RELBORDERTOP,tag_RELBORDERBOTTOM,
+	tag_RELBORDERLEFT,tag_RELBORDERRIGHT,tag_BOUNDINGBOX,tag_PSNEEDEDFONTS,tag_PSUSEDFONTS,tag_PSSUPPLIEDFONTS;
 };
 
 
@@ -115,12 +136,13 @@ list<hk_string>  hk_report::p_reporttypelist;
 hk_report::recodefunctionlisttype hk_report::p_recodefunctions;
 list<hk_string>  hk_report::p_recodelist;
 
+hk_report::recodefunctionlisttype hk_report::p_fullpagereplacefunctions;
+list<hk_string>  hk_report::p_fullpagereplacelist;
+
 hk_report::reportconfigurelisttype  hk_report::p_reportconfigurefunctions;
 list<hk_string> hk_report::p_reportconfigurelist;
 
-list<hk_string> hk_report::p_fontencodinglist;
-int hk_report::p_fontencoding=1;
-
+bool hk_report::p_embedfonts=false;
 int hk_report::p_defaultfilenumber=0;
 hk_string hk_report::p_printcommand="lpr";
 //********************************************
@@ -154,6 +176,28 @@ hk_report::hk_report(void):hk_presentation()
     p_defaultfilenumber++;
     set_backgroundcolour(hk_white,false,true);
     set_foregroundcolour(hk_black,false,true);
+    p_private->tag_FONT=register_tag("FONT");
+    p_private->tag_PSFONT=register_tag("PSFONT");
+    p_private->tag_PSEMBEDDEDFONTS=register_tag("PSEMBEDDEDFONTS");
+    p_private->tag_FONTSIZE=register_tag("FONTSIZE");
+    p_private->tag_PTIME=register_tag("PTIME");
+    p_private->tag_ABSOLUTEPAGENUMBER=register_tag("ABSOLUTEPAGENUMBER");
+    p_private->tag_PAGENUMBER=register_tag("PAGENUMBER");
+    p_private->tag_BORDERLEFT=register_tag("BORDERLEFT");
+    p_private->tag_BORDERRIGHT=register_tag("BORDERRIGHT");
+    p_private->tag_BORDERTOP=register_tag("BORDERTOP");
+    p_private->tag_BORDERBOTTOM=register_tag("BORDERBOTTOM");
+    p_private->tag_RELBORDERTOP=register_tag("RELBORDERTOP");
+    p_private->tag_RELBORDERBOTTOM=register_tag("RELBORDERBOTTOM");
+    p_private->tag_RELBORDERLEFT=register_tag("RELBORDERLEFT");
+    p_private->tag_RELBORDERRIGHT=register_tag("RELBORDERRIGHT");
+    p_private->tag_BOUNDINGBOX=register_tag("BOUNDINGBOX");
+    p_private->tag_PSNEEDEDFONTS=register_tag("PSNEEDEDFONTS");
+    p_private->tag_PSUSEDFONTS=register_tag("PSUSEDFONTS");
+    p_private->tag_PSSUPPLIEDFONTS=register_tag("PSSUPPLIEDFONTS");
+
+    
+    
     setup_reportbasics();
     init_report();
 }
@@ -173,28 +217,21 @@ void hk_report::setup_reportbasics(void)
         add_recodetype("None",NULL);
     }
 
+    if (p_fullpagereplacefunctions.size()==0)
+    {
+/*        add_recodetype("Postscript",&recode_postscript);
+        add_recodetype("Html",&recode_html);
+        add_recodetype("UTF8",&recode_utf8);*/
+        add_fullpagereplacefunctiontype("Postscript",&fullpagereplace_postscript);
+        add_fullpagereplacefunctiontype("None",NULL);
+    }
+
     if (p_reportconfigurefunctions.size()==0)
     {
         add_configurefunctiontype("Postscript",&configure_postscriptreport);
         add_configurefunctiontype("None",NULL);
     }
 
-    if (p_fontencodinglist.size()==0)
-    {
-        p_fontencodinglist.insert(p_fontencodinglist.end(),"ISO-8859-1");
-        p_fontencodinglist.insert(p_fontencodinglist.end(),"ISO-8859-2");
-        p_fontencodinglist.insert(p_fontencodinglist.end(),"ISO-8859-3");
-        p_fontencodinglist.insert(p_fontencodinglist.end(),"ISO-8859-4");
-        p_fontencodinglist.insert(p_fontencodinglist.end(),"ISO-8859-5");
-        p_fontencodinglist.insert(p_fontencodinglist.end(),"ISO-8859-6");
-        p_fontencodinglist.insert(p_fontencodinglist.end(),"ISO-8859-7");
-        p_fontencodinglist.insert(p_fontencodinglist.end(),"ISO-8859-8");
-        p_fontencodinglist.insert(p_fontencodinglist.end(),"ISO-8859-9");
-        p_fontencodinglist.insert(p_fontencodinglist.end(),"ISO-8859-10");
-        p_fontencodinglist.insert(p_fontencodinglist.end(),"KOI8-R");
-        p_fontencodinglist.insert(p_fontencodinglist.end(),"KOI8-U");
-        p_fontencodinglist.insert(p_fontencodinglist.end(),"ISO-8859-15");
-    }
 
 
 
@@ -376,6 +413,14 @@ hk_reportsectionpair* hk_report::new_sectionpair_at(unsigned int position,bool r
 bool hk_report::set_mode(hk_report::enum_mode m)
 {
 bool result=true;
+
+if (m==designmode && while_executing())
+{ 
+ stop_execution();
+}
+else
+if (m==viewmode && while_executing())
+  return true;
 hk_presentation::set_mode(m);
 
      if(m== viewmode)
@@ -413,9 +458,20 @@ bool hk_report::internal_execute(void)
     hkdebug("hk_report::internal_execute");
 #endif
 //prepare datasource for output, resort data
+    if (p_private->p_while_load_report) return false;
     if (datasource()==NULL) return false;
+    if (p_private->p_while_executing)
+    { 
+     return true;
+    }
     p_private->p_while_executing=true;
+    p_private->p_encodingtab.reset();
+    p_private->p_encodingtab.register_unicode(0x0A,".notdef");
+    p_private->p_encodingtab.register_unicode(0x20,"space");
     p_private->p_cancelreport=false;
+    p_private->p_nostrstream=false;
+    p_private->p_stringstream.str("");
+
     //enum_mode modebuffer=p_mode;
     p_private->p_currenttime=time(NULL);
     hk_string ds_sort=datasource()->temporarysorting();
@@ -497,18 +553,18 @@ bool hk_report::internal_execute(void)
         p_private->p_pagenamecolumn->set_dateformat(dateformat());
         p_private->p_pagenamecolumn->set_timeformat(timeformat());
     }
+    create_fontslists();
     new_outputstream();
     widget_specific_after_first_outstream_created();
 //start output
     p_private->p_rowcounter=0;
     p_private->p_pagenumber=p_private->p_startpagenumber;
     p_private->p_absolutepagenumber=1;
-    create_fontslists();
     if (p_private->p_masterreport==NULL)
     {
         if (p_private->p_output==&cout)*outputstream()<<replace(p_private->p_filebegin);
 	if (!action_on_new_page())stop_execution();
-        if (p_private->p_pageheader!=NULL)
+        if (p_private->p_pageheader!=NULL )
 	if (!p_private->p_pageheader->actual_string())
 	  stop_execution();
 	;
@@ -531,7 +587,7 @@ bool hk_report::internal_execute(void)
 //print header sections
      if (p_private->p_progressdialog)
         p_private->p_cancelreport=p_private->p_progressdialog(p_private->p_rowposition,datasource()->max_rows(),hk_translate("Creating output ..."));
-
+        if (p_private->p_cancelreport) stop_execution();
         vector<hk_reportsectionpair*>::iterator it=p_sectionpairs.begin();
         int p=0;
         bool printfootersection=true;
@@ -644,12 +700,25 @@ bool hk_report::internal_execute(void)
         }
 
     }                                             //end footersections
-
+    
     if (p_private->p_masterreport==NULL) if (!report_footer()->actual_string())stop_execution();
+    
+    
     (*outputstream()) << replace(p_private->p_end);
     if (p_private->p_masterreport==NULL)
     {
         if (p_private->p_pagefooter!=NULL) if (!p_private->p_pagefooter->actual_string())stop_execution();
+    }
+    
+    if (p_private->p_print_full_pages_only)
+    {
+         write_bufferedpage();
+         p_private->p_nostrstream=true;
+    
+    }
+    
+    if (p_private->p_masterreport==NULL)
+    {
         *outputstream()<<p_private->p_pagedelimiter;
         *outputstream()<<replace(p_private->p_fileend);
         widget_specific_before_last_outstream_closed();
@@ -674,6 +743,17 @@ bool hk_report::internal_execute(void)
     widget_specific_after_execute();
     //p_mode=modebuffer;
     p_private->p_while_executing=false;
+// if (!p_private->p_masterreport)
+// {
+// cerr <<"encoding:"<<endl;
+// HK_CHARSIZE w=0;
+// while (w<p_private->p_encodingtab.max_nr())
+// {
+// cerr <<"w: "<<w<<" uni2local:"<<p_private->p_encodingtab.local(w)<<" local2uni: "<<p_private->p_encodingtab.unicode(w)<<" glyph:"<<p_private->p_encodingtab.glyphname(w)<<endl;
+// ++w;
+// }
+// }
+
 
     return !execution_stopped();
 }
@@ -765,21 +845,42 @@ void hk_report::new_page(void)
         widget_specific_after_new_page();
         return;
     }
-
     if (p_private->p_pagefooter!=NULL) if (!p_private->p_pagefooter->actual_string())stop_execution();
     *outputstream() << p_private->p_pagedelimiter;
+    
+    if (p_private->p_print_full_pages_only )
+    {
+           write_bufferedpage();
+    }
     p_private->p_pagenumber++;
     p_private->p_absolutepagenumber++;
     set_pagenumber(p_private->p_pagenumber);
+    p_private->p_rowcounter=0;
     if(p_multiplefiles) new_outputstream();
     if (!action_on_new_page())stop_execution();
-    if (p_private->p_pageheader!=NULL) if (!p_private->p_pageheader->actual_string())stop_execution();
+    
+    if (p_private->p_pageheader!=NULL ) 
+        if (!p_private->p_pageheader->actual_string())stop_execution();
+    
     if (!execution_stopped()&& datasource())
             if (!widget_specific_after_new_page()) stop_execution();
     if (!datasource()) stop_execution();
+    p_private->p_cleanpage=true;
 }
 
 
+
+void hk_report::write_bufferedpage(void)
+{
+    if (!p_private->p_print_full_pages_only ) return;
+    
+    *p_private->p_output<<(p_private->p_fullpagereplacefunction?
+    				p_private->p_fullpagereplacefunction(p_private->p_stringstream.str(),this)
+    				:p_private->p_stringstream.str());
+    p_private->p_stringstream.str("");
+
+}
+
 void hk_report::set_pagenumber(long f)
 {
     p_private->p_pagenumber=f;
@@ -865,6 +966,10 @@ bool  hk_report::before_columns_deleted(void)
     return datasource_disable();
 }
 
+unsigned long   hk_report::current_rowcount(void)
+{
+  return p_private->p_rowcounter;
+}
 
 void hk_report::rowcount(unsigned long c)
 {
@@ -883,9 +988,12 @@ void hk_report::rowcount(unsigned long c)
         p_private->p_rowcounter=c;
         if (p_private->p_newpage_on_periodic)
         {
-            new_page();
+            if (!p_private->p_cleanpage)
+               new_page();
+            else p_private->p_cleanpage=false;
         }
     }
+    else p_private->p_cleanpage=false;
 
 }
 
@@ -920,7 +1028,7 @@ bool        hk_report::periodic_newpage(void)
     return p_private->p_newpage_on_periodic;
 }
 
-
+/*
 hk_string hk_report::replace(const hk_string& where)
 {
 #ifdef HK_DEBUG
@@ -930,7 +1038,10 @@ hk_string hk_report::replace(const hk_string& where)
     p_buffer=hk_presentation::replace(where);
     p_buffer=replace_all("%FONT%",p_buffer,font().fontname());
     p_buffer=replace_all("%PSFONT%",p_buffer,font().psfontname());
-
+//     if (p_private->p_embeddedfontsdefinition.size()>0)
+       p_buffer=replace_all("%PSEMBEDDEDFONTS%",p_buffer,p_private->p_embeddedfontsdefinition);
+//     p_buffer=replace_all("%PSEMBEDDEDFONTS%",p_buffer,p_private->p_embeddedfontsdefinition);
+//       cerr <<"%PSEMBEDDEDFONTS% wird erseztzt durch #"<<p_private->p_embeddedfontsdefinition<<"#"<<endl;
     p_buffer=replace_all("%FONTSIZE%",p_buffer,longint2string(font().fontsize()));
 
     time_t     p_nowtime=time(NULL);
@@ -963,24 +1074,128 @@ hk_string hk_report::replace(const hk_string& where)
     list<hk_string>::iterator it=p_private->p_neededfonts.begin();
     while (it!=p_private->p_neededfonts.end())
     {
-        r+="%%+ "+(*it)+"\n";
+        r+="%%+ font "+(*it)+"\n";
         it++;
     }
-    if (r.size()>0)r="%%DocumentNeededFonts:\n"+r;
     p_buffer=replace_all("%PSNEEDEDFONTS%",p_buffer,r);
-    p_buffer=replace_all("%PSSUPPLIEDFONTS%",p_buffer,"%%DocumentSuppliedFonts:\n");
-
+    
+    it=p_private->p_suppliedfontspsnames.begin();
+    r="";
+    while (it!=p_private->p_suppliedfontspsnames.end())
+    {
+        r+="%%+ font "+(*it)+"\n";
+        it++;
+    }
+    p_buffer=replace_all("%PSSUPPLIEDFONTS%",p_buffer,r);
+    
+    it=p_private->p_usedpsfonts.begin();
+    r="";
+    while (it!=p_private->p_usedpsfonts.end())
+    {
+        r+="%%+ font "+(*it)+"\n";
+        it++;
+    }
+    p_buffer=replace_all("%PSUSEDFONTS%",p_buffer,r);
     return p_buffer;
 }
 
+*/
+
+
+
+
+hk_string hk_report::tag_value(int tagnumber, bool& ok)
+{
+ok=true;
+    if (tagnumber==p_private->tag_FONT) return font().fontname();
+    if (tagnumber==p_private->tag_PSFONT) return font().psfontname();
+    if (tagnumber==p_private->tag_PSEMBEDDEDFONTS) return   p_private->p_embeddedfontsdefinition;
+    if (tagnumber==p_private->tag_FONTSIZE) return longint2string(font().fontsize());
+
+    if (tagnumber==p_private->tag_PTIME)
+    {
+    time_t     p_nowtime=time(NULL);
+    time_t     p_timediff=p_nowtime - p_private->p_currenttime;
+
+    return longint2string(p_timediff);
+    }
+    if (tagnumber==p_private->tag_ABSOLUTEPAGENUMBER) return longint2string(absolutepagenumber());
+    if (tagnumber==p_private->tag_PAGENUMBER) return longint2string(pagenumber());
+
+    if (tagnumber==p_private->tag_BORDERLEFT) return sizetype()==relative?ulongint2string(relativ2horizontal(border_left())):ulongint2string(border_left());
+    if (tagnumber==p_private->tag_BORDERRIGHT) return    sizetype()==relative?ulongint2string(relativ2horizontal(border_right())):ulongint2string(border_right());
+    if (tagnumber==p_private->tag_BORDERTOP)    return sizetype()==relative?ulongint2string(relativ2vertical(border_top())):ulongint2string(border_top());
+    if (tagnumber==p_private->tag_BORDERBOTTOM) return    sizetype()==relative?ulongint2string(relativ2vertical(border_bottom())):ulongint2string(border_bottom());
+    if (tagnumber==p_private->tag_RELBORDERLEFT) return sizetype()==relative?ulongint2string(border_left()):ulongint2string(horizontal2relativ(border_left()));
+    if (tagnumber==p_private->tag_RELBORDERRIGHT) return (sizetype()==relative?ulongint2string(border_right()):ulongint2string(horizontal2relativ(border_right())));
+    if (tagnumber==p_private->tag_RELBORDERTOP) return (sizetype()==relative?ulongint2string(border_top()):ulongint2string(vertical2relativ(border_top())));
+    if (tagnumber==p_private->tag_RELBORDERBOTTOM) return (sizetype()==relative?ulongint2string(border_bottom()):ulongint2string(vertical2relativ(border_bottom())));
+
+//Postscriptstuff
+    if (tagnumber==p_private->tag_BOUNDINGBOX)
+    {
+    hk_string boundingbox="%%BoundingBox: 0 0 ";
+
+    boundingbox+=longint2string(zmm2ps(p_private->p_orientation==portrait?designwidth():designheight()))+" ";
+    boundingbox+=longint2string(zmm2ps(p_private->p_orientation==portrait?designheight():designwidth()));
+//  cout <<"BOUNDINGBOX= "<<boundingbox<<endl;
+
+    return boundingbox;
+    }
+    
+    if (!p_private->p_masterreport)
+    {
+    list<hk_string>::iterator it=p_private->p_neededfonts.begin();
+     hk_string r;
+    if (tagnumber==p_private->tag_PSNEEDEDFONTS)
+    {
+     while (it!=p_private->p_neededfonts.end())
+     {
+        r+="%%+ font "+(*it)+"\n";
+        it++;
+     }
+     return r;
+     }
+    
+    if (tagnumber==p_private->tag_PSSUPPLIEDFONTS)
+    {it=p_private->p_suppliedfontspsnames.begin();
+    r="";
+    while (it!=p_private->p_suppliedfontspsnames.end())
+    {
+        r+="%%+ font "+(*it)+"\n";
+        it++;
+    }
+    return r;
+    }
+    if (tagnumber==p_private->tag_PSUSEDFONTS)
+    {
+    it=p_private->p_usedpsfonts.begin();
+    r="";
+    while (it!=p_private->p_usedpsfonts.end())
+    {
+        r+="%%+ font "+(*it)+"\n";
+        it++;
+    }
+    return r;
+    }
+    }
+return hk_dsvisible::tag_value(tagnumber,ok);
+}
+
+
 
 hk_font hk_report::font(void)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_report::font");
 #endif
-    if (hk_presentation::font().fontname().size()==0) return hk_font(hk_font::defaultfontname(),hk_font::defaultfontsize());
-    else return hk_presentation::font();
+    hk_font f;
+    
+    if (hk_presentation::font().fontname().size()==0) f= hk_font(hk_font::defaultfontname(),hk_font::defaultfontsize());
+    else f= hk_presentation::font();
+    
+    f.set_encodingtab(encodingtab());
+    return f;
 }
 
 
@@ -1080,6 +1295,7 @@ void  hk_report::savedata(ostream& s)
     set_tagvalue(s,"FILENAME",p_private->p_originalfilename);
     set_tagvalue(s,"STARTPAGENUMBER",p_private->p_startpagenumber);
     set_tagvalue(s,"MULTIPLEFILES",p_multiplefiles);
+    set_tagvalue(s,"PRINTFULLPAGESONLY",p_private->p_print_full_pages_only);
     set_tagvalue(s,"PAGENAME",p_private->p_pagename);
     set_tagvalue(s,"BORDERLEFT",(long unsigned int) p_private->p_borderleft);
     set_tagvalue(s,"BORDERRIGHT",(long unsigned int) p_private->p_borderright);
@@ -1154,9 +1370,11 @@ void  hk_report::savedata(ostream& s)
         set_tagvalue(s,"DEFAULTBEFORECOLUMN",p_default_beforedata);
         set_tagvalue(s,"DEFAULTAFTERCOLUMN",p_default_afterdata);
         set_tagvalue(s,"RECODEFUNCTION",p_private->p_recodefunctionstring);
+        set_tagvalue(s,"FULLPAGEREPLACEFUNCTION",p_private->p_fullpagereplacefunctionstring);
         set_tagvalue(s,"DEFAULTDATACONFIGUREFUNCTION",p_default_dataconfigurefunction);
         set_tagvalue(s,"DEFAULTSECTIONCOUNTFUNCTION",p_private->p_defaultsectioncountfunction);
         set_tagvalue(s,"REPORTCONFIGUREFUNCTION",p_private->p_configurefunctionstring);
+        set_tagvalue(s,"PRINTFULLPAGEONLY",p_private->p_print_full_pages_only);
     }
 
     end_mastertag(s,"REPORTDEFINITION");
@@ -1196,17 +1414,22 @@ bool hk_report::load_report(const hk_string& n)
         save_report();
         reset_has_changed();
     }
-
+    p_private->p_while_load_report=true;
     init_report();
     if (n.size()>0) set_name(n);
     enum_mode modebuffer=mode();
     hk_dsmodevisible::set_mode(designmode);
-    if (name().size()==0) if (!ask_name())return false;
+    if (name().size()==0) if (!ask_name())
+    				{
+    				 p_private->p_while_load_report=false;
+				 return false;
+    				}
     hk_string res= database()->load(name(),ft_report);
     p_private->p_loadreportname=n;
     if (res.size()==0)
     {
         show_warningmessage(hk_translate("No such report!"));
+            p_private->p_while_load_report=false;
         return false;
     }
     if ( res.find("encoding=\"UTF-8\"")<res.size() ) res=u2l(res);
@@ -1218,9 +1441,19 @@ bool hk_report::load_report(const hk_string& n)
 #ifdef HK_DEBUG
     hkdebug("hk_report::load_form ENDE");
 #endif
+p_private->p_while_load_report=false;
     return true;
 }
 
+bool hk_report::while_load_report(void) const
+{
+   return p_private->p_while_load_report;
+}
+
+bool hk_report::while_loading(void)
+{
+  return while_load_report();
+}
 
 void  hk_report::loaddata(const hk_string& definition)
 {
@@ -1247,6 +1480,7 @@ void  hk_report::loaddata(const hk_string& definition)
     if (get_tagvalue(r,"FILENAME",sbuffer))set_filename(sbuffer);
     if (get_tagvalue(r,"STARTPAGENUMBER",ibuffer))p_private->p_startpagenumber=ibuffer;
     if (get_tagvalue(r,"MULTIPLEFILES",bbuffer))p_multiplefiles=bbuffer;
+    get_tagvalue(r,"PRINTFULLPAGESONLY",p_private->p_print_full_pages_only);
     if (get_tagvalue(r,"PAGENAME",sbuffer))p_private->p_pagename=sbuffer;
     if (get_tagvalue(r,"BORDERLEFT",ibuffer))p_private->p_borderleft=ibuffer;
     if (get_tagvalue(r,"BORDERRIGHT",ibuffer)) p_private->p_borderright=ibuffer;
@@ -1339,10 +1573,14 @@ void  hk_report::loaddata(const hk_string& definition)
         get_tagvalue(r,"DEFAULTDATACONFIGUREFUNCTION",p_default_dataconfigurefunction);
         if (get_tagvalue(r,"RECODEFUNCTION",sbuffer))
             set_recodefunction(sbuffer);
+        if (get_tagvalue(r,"FULLPAGEREPLACEFUNCTION",sbuffer))
+            set_fullpagereplacefunction(sbuffer);
+
         get_tagvalue(r,"DEFAULTSECTIONCOUNTFUNCTION",p_private->p_defaultsectioncountfunction);
         if (get_tagvalue(r,"REPORTCONFIGUREFUNCTION",sbuffer))
             set_reportconfigurefunction(sbuffer,false);
-    }
+        get_tagvalue(r,"PRINTFULLPAGEONLY",p_private->p_print_full_pages_only);
+}
 
     set_reporttype(reptype);
 
@@ -1646,13 +1884,13 @@ void hk_report::set_pageformat(pageformattype t,bool registerchange)
 }
 
 
-void hk_report::set_pageformat(unsigned int width,unsigned  int height,bool registerchange)
+void hk_report::set_pageformat(unsigned int w,unsigned  int h,bool registerchange)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_report::set_pageformat(unsigned int,unsigned int)");
 #endif
     p_private->p_pageformat=userdefined;
-    set_designsize(width,height,registerchange);
+    set_designsize(w,h,registerchange);
     configure_page();
     has_changed(registerchange);
 
@@ -1666,7 +1904,7 @@ void hk_report::configure_page(void)
 #endif
     if (p_private->p_configurefunction!=NULL)
     {
-        p_private->p_configurefunction(this,p_fontencoding);
+        p_private->p_configurefunction(this,0);
     }
 
 }
@@ -1970,6 +2208,64 @@ void    hk_report::set_recodefunction(const hk_string& r,bool registerchange)
 }
 
 
+
+
+void        hk_report::set_fullpagereplacefunction(const hk_string& r,bool registerchange)
+{
+    if (r==p_private->p_fullpagereplacefunctionstring)return;
+
+    recodefunctionlisttype::iterator it=p_fullpagereplacefunctions.find(r);
+    if (it==p_fullpagereplacefunctions.end())
+    {
+
+        show_warningmessage(hk_translate("Replacefunctiontype not found"));
+        p_private->p_fullpagereplacefunction=NULL;
+        p_private->p_fullpagereplacefunctionstring="None";
+        return;
+    }
+
+    recodefunctiontype* rf=*it->second;
+    p_private->p_fullpagereplacefunction=rf;
+    p_private->p_fullpagereplacefunctionstring=r;
+
+    has_changed(registerchange);
+
+}
+
+recodefunctiontype* hk_report::fullpagereplacefunction(void)
+{
+    return p_private->p_fullpagereplacefunction;
+
+}
+
+hk_string      hk_report::fullpagereplacefunctionstring(void)
+{
+    return p_private->p_fullpagereplacefunctionstring;
+
+}
+
+
+void hk_report::add_fullpagereplacefunctiontype(const hk_string& name,recodefunctiontype* f)
+{
+    if (name.size()==0) return;
+    typedef recodefunctionlisttype::value_type recodevalue;
+    p_fullpagereplacefunctions.insert(recodevalue(name,f));
+    p_fullpagereplacelist.insert(p_fullpagereplacelist.end(),name);
+
+}
+
+list<hk_string>* hk_report::fullpagereplacefunctionlist(void)
+{
+    return &p_fullpagereplacelist;
+
+}
+
+
+
+
+
+
+
 void    hk_report::neutralize_definition(bool registerchange)
 {
 #ifdef HK_DEBUG
@@ -1988,6 +2284,8 @@ void    hk_report::neutralize_definition(bool registerchange)
     set_begin("",registerchange);
     set_end("",registerchange);
     set_reportconfigurefunction("None",registerchange);
+    set_recodefunction("None",registerchange);
+    set_fullpagereplacefunction("None",registerchange);
     vector<hk_reportsectionpair*>* s=sectionpairs();
     if (s!=NULL)
     {
@@ -1998,7 +2296,8 @@ void    hk_report::neutralize_definition(bool registerchange)
             section_it++;
         }
     }
-
+p_private->p_print_full_pages_only=false;
+p_private->p_useencodingtab=false;
 }
 
 
@@ -2093,76 +2392,35 @@ bool hk_report::is_subpresentation(void)
 
 ostream* hk_report::outputstream(void)
 {
-    if (p_private->p_masterreport==NULL)return p_private->p_output;
+    if (p_private->p_masterreport==NULL)
+    {
+     if (p_private->p_print_full_pages_only && !p_private->p_nostrstream)
+      return &p_private->p_stringstream;
+     else
+      return p_private->p_output;
+    }
     else return p_private->p_masterreport->outputstream();
 }
 
 
-list<hk_string>* hk_report::fontencodinglist(void)
-{
-    return &p_fontencodinglist;
-}
-
-
-bool  hk_report::set_fontencoding(int e)
-{
-    if (e<1||e>(int)p_fontencodinglist.size()) return false;
-    p_fontencoding=e;
-    return true;
-}
-
-
-bool hk_report::set_fontencoding(const hk_string& e)
-{
-    list<hk_string>::iterator it=p_fontencodinglist.begin();
-    int c=1;
-    while (it!=p_fontencodinglist.end())
-    {
-        if ((*it)==e)
-        {
-            return set_fontencoding(c);
-        }
-        it++;
-        c++;
-    }
-    return false;
-}
-
-
-hk_string   hk_report::fontencodingstring(void)
-{
-    list<hk_string>::iterator it=p_fontencodinglist.begin();
-    int c=1;
-    while (it!=p_fontencodinglist.end())
-    {
-        if (c==p_fontencoding)
-        {
-            return (*it);
-        }
-        it++;
-        c++;
-    }
-    return "";
-}
-
-
-int         hk_report::fontencoding(void)
-{
-    return p_fontencoding;
-}
-
 
 void hk_report::create_fontslists(void)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_report::create_fontslists");
 #endif
-    p_private->p_neededfonts.erase(p_private->p_neededfonts.begin(),p_private->p_neededfonts.end());
-    p_private->p_usedfonts.erase(p_private->p_usedfonts.begin(),p_private->p_usedfonts.end());
-    p_private->p_suppliedfonts.erase(p_private->p_suppliedfonts.begin(),p_private->p_suppliedfonts.end());
+    p_private->p_neededfonts.clear();
+    p_private->p_usedpsfonts.clear();
+    p_private->p_usedfonts.clear();
+    p_private->p_suppliedfonts.clear();
+    p_private->p_suppliedfontspsnames.clear();
+    p_private->p_embeddedfontsdefinition="";
 
+    search_sectionfonts(p_private->p_reportheader);
+    search_sectionfonts(p_private->p_reportfooter);
     search_sectionfonts(p_private->p_pageheader);
     search_sectionfonts(p_private->p_pagefooter);
+    search_sectionfonts(p_private->p_datasection);
     vector<hk_reportsectionpair*>::iterator it=p_sectionpairs.begin();
     while (it!=p_sectionpairs.end())
     {
@@ -2170,11 +2428,8 @@ void hk_report::create_fontslists(void)
         if ((*it)->footersection()!=NULL) search_sectionfonts((*it)->footersection());
         it++;
     }
-    if (p_private->p_usedfonts.size()==0&&is_newfont(font().fontname()))
-    {
-        p_private->p_usedfonts.insert(p_private->p_usedfonts.end(),font().fontname());
-        p_private->p_neededfonts.insert(p_private->p_neededfonts.end(),font().fontname());
-    }
+//     hk_font f=font();
+//     registerfont(&f);
 }
 
 
@@ -2190,10 +2445,16 @@ list<hk_string>* hk_report::usedfonts(void)
 }
 
 
+list<hk_string>* hk_report::usedpsfonts(void)
+{
+    return &p_private->p_usedpsfonts;
+}
+
+
 bool    hk_report::is_newfont(const hk_string&f)
 {
-    list<hk_string>::iterator it=p_private->p_usedfonts.begin();
-    while (it!=p_private->p_usedfonts.end())
+    list<hk_string>::iterator it=p_private->p_usedpsfonts.begin();
+    while (it!=p_private->p_usedpsfonts.end())
     {
         if ((*it)==f) return false;
         it++;
@@ -2201,6 +2462,35 @@ bool    hk_report::is_newfont(const hk_string&f)
     return true;
 }
 
+void hk_report::registerfont(hk_font* fnt)
+{
+  if (!fnt) return;
+  if (p_private->p_masterreport)
+      p_private->p_masterreport->registerfont(fnt);
+  hk_string f=fnt->psfontname();
+        if (is_newfont(f))
+        {
+            p_private->p_usedfonts.insert(p_private->p_usedfonts.end(),fnt->fontname());
+            p_private->p_usedpsfonts.insert(p_private->p_usedpsfonts.end(),f);
+        
+        if (p_embedfonts)
+        {
+          hk_string def=fnt->psfontembeddefinition();
+          if(def.size()>0)
+          {
+           p_private->p_embeddedfontsdefinition+="%%BeginResource: font "+f+"\n"+def+"\n%%EndResource\n";
+           p_private->p_suppliedfonts.push_back(fnt->fontname());
+           p_private->p_suppliedfontspsnames.push_back(f);
+          }
+          else
+            p_private->p_neededfonts.insert(p_private->p_neededfonts.end(),f);
+
+    
+        }
+        else
+            p_private->p_neededfonts.insert(p_private->p_neededfonts.end(),f);
+        }
+}
 
 void hk_report::search_sectionfonts(hk_reportsection* s)
 {
@@ -2208,13 +2498,15 @@ void hk_report::search_sectionfonts(hk_reportsection* s)
     vector<hk_reportdata*>::iterator it=s->datalist()->begin();
     while (it!=s->datalist()->end())
     {
-        if (is_newfont((*it)->font().fontname()))
-        {
-            p_private->p_usedfonts.insert(p_private->p_usedfonts.end(),(*it)->font().fontname());
-            p_private->p_neededfonts.insert(p_private->p_neededfonts.end(),(*it)->font().fontname());
-        }
+       hk_font fo=(*it)->font();
+       registerfont(&fo);
         it++;
     }
+    
+    if (s->subreport())
+    {
+      s->subreport()->create_fontslists();
+    }
 }
 
 
@@ -2343,7 +2635,7 @@ bool hk_report::move_sectionpair(unsigned int actualposition,int steps)
     hk_reportsectionpair* p_buffer= p_sectionpairs[actualposition];
     int p_steps = steps;
     if (steps>0&& actualposition+steps>=p_sectionpairs.size()) p_steps=p_sectionpairs.size()-1;
-    if (steps<0&& actualposition+steps<0)p_steps=actualposition;
+    if (steps<0)p_steps=actualposition;
 
     int s=0;
     if (steps>0)
@@ -2549,22 +2841,22 @@ hk_reportdata* result=NULL;
  return result;
 }
 
-hk_reportdata* hk_report::get_reportdatavisible(const hk_string& identifier)
+hk_reportdata* hk_report::get_reportdatavisible(const hk_string& i)
 {
 hk_reportdata* result=NULL;
     vector<hk_reportsectionpair*>::iterator it=p_sectionpairs.begin();
     while (it!=p_sectionpairs.end()&&result==NULL)
     {
-        if ((*it)->headersection()) result=(*it)->headersection()->get_reportdatavisible(identifier);
-        if ((*it)->footersection()&&!result) result=(*it)->footersection()->get_reportdatavisible(identifier);
+        if ((*it)->headersection()) result=(*it)->headersection()->get_reportdatavisible(i);
+        if ((*it)->footersection()&&!result) result=(*it)->footersection()->get_reportdatavisible(i);
         ++it;
     }
 
-   if (!result) result=p_private->p_datasection->get_reportdatavisible(identifier);
-    if (!result&&p_private->p_pageheader) result=p_private->p_pageheader->get_reportdatavisible(identifier);
-    if (!result&&p_private->p_pagefooter) result=p_private->p_pagefooter->get_reportdatavisible(identifier);
-    if (!result&&p_private->p_reportheader)result=p_private->p_reportheader->get_reportdatavisible(identifier);
-    if (!result&&p_private->p_reportfooter)result=p_private->p_reportfooter->get_reportdatavisible(identifier);
+   if (!result) result=p_private->p_datasection->get_reportdatavisible(i);
+    if (!result&&p_private->p_pageheader) result=p_private->p_pageheader->get_reportdatavisible(i);
+    if (!result&&p_private->p_pagefooter) result=p_private->p_pagefooter->get_reportdatavisible(i);
+    if (!result&&p_private->p_reportheader)result=p_private->p_reportheader->get_reportdatavisible(i);
+    if (!result&&p_private->p_reportfooter)result=p_private->p_reportfooter->get_reportdatavisible(i);
     return result;
 }
 
@@ -2591,6 +2883,8 @@ return interpreter()->on_print_new_page(this);
  void hk_report::stop_execution(void)
  {
 p_private->p_cancelreport=true;
+ if (p_private->p_masterreport)
+   p_private->p_masterreport->stop_execution();
  }
 
  bool hk_report::execution_stopped(void)
@@ -2647,9 +2941,9 @@ void hk_report::set_filecharset(const hk_string& l)
 p_private->p_charset=l;
 }
 
-void hk_report::set_progressdialog(progress_dialogtype* progressdialog)
+void hk_report::set_progressdialog(progress_dialogtype* p)
 {
-p_private->p_progressdialog=progressdialog;
+p_private->p_progressdialog=p;
 }
 
 progress_dialogtype* hk_report::progressdialog(void)const
@@ -2657,3 +2951,45 @@ progress_dialogtype* hk_report::progressdialog(void)const
   return p_private->p_progressdialog;
 }
 
+hk_encodingtab* hk_report::encodingtab(void) const
+{
+if (!p_private->p_useencodingtab) return NULL;
+   if (p_private->p_masterreport) return p_private->p_masterreport->encodingtab();
+   else
+   return &p_private->p_encodingtab;
+}
+
+
+void hk_report::set_print_full_pages_only(bool p, bool registerchange)
+{
+p_private->p_print_full_pages_only=p;
+has_changed(registerchange);
+}
+
+bool hk_report::print_full_pages_only(void)
+{
+  return p_private->p_print_full_pages_only;
+}
+
+
+void hk_report::set_embedfonts(bool e)
+{
+  p_embedfonts=e;
+}
+
+bool hk_report::embedfonts(void)
+{
+  return p_embedfonts;
+}
+
+void hk_report::set_useencodingtab(bool u)
+{
+  p_private->p_useencodingtab=u;
+}
+
+bool hk_report::useencodingtab(void)
+{
+return p_private->p_useencodingtab;
+}
+
+
