@@ -33,7 +33,7 @@ class hk_reportprivate;
  * CVS, HTML, XML, Postscript etc. It has all functions you need to create reports in any kind and any format.
  * See also the convenience class @ref hk_reportcvs.
  * @short basic class to create reports
- *@version $Revision: 1.57 $
+ *@version $Revision: 1.65 $
  * @author Horst Knorr (hk_classes@knoda.org)
 
  *
@@ -136,6 +136,8 @@ class hk_report :public hk_presentation
  */
         bool          execute(void);
 	bool    while_executing(void) const;
+	bool    while_load_report(void) const;
+	virtual bool while_loading(void);
        virtual bool            set_mode(enum_mode s);
 
 /**
@@ -149,15 +151,6 @@ class hk_report :public hk_presentation
 
         static void add_recodetype(const hk_string& name,recodefunctiontype* f);
         static list<hk_string>* recodelist(void);
-/**
- *list of supported character encodings ( mainly important for postscript)
- *existing types are:ISO 8859-1 to ..-10, KOI8-R and KOI8-U
- */
-        static list<hk_string>* fontencodinglist(void);
-        static bool set_fontencoding(int );
-        static bool set_fontencoding(const hk_string&);
-        static hk_string   fontencodingstring(void);
-        static int      fontencoding(void);
 
         void        new_page(void);
 
@@ -234,6 +227,7 @@ class hk_report :public hk_presentation
  *This function does the counting job for @ref set_periodic and will be called automaticallly
  */
         void        rowcount(unsigned long);
+        unsigned long   current_rowcount(void);
         virtual hk_font font(void);
 /**
  *the number of the page. To get more than one page you have to use either
@@ -401,6 +395,7 @@ class hk_report :public hk_presentation
         void   remove_sectionpair(hk_reportsectionpair*,bool registerchange=true);
         list<hk_string>* neededfonts(void);
         list<hk_string>* usedfonts(void);
+        list<hk_string>* usedpsfonts(void);
 /**
  *sets the printercommand. default is "lpr"
  */
@@ -432,12 +427,31 @@ bool execution_stopped(void);
         hk_string filecharset(void);
         void set_filelocale(const hk_string&);
         void set_filecharset(const hk_string&);
+        void set_useencodingtab(bool);
+        bool useencodingtab(void);
+        hk_encodingtab* encodingtab(void) const;
+/**
+*default is false: if true the section output will be buffered until a new_page is created, if false it is directly written to the stream
+*/        
+        void set_print_full_pages_only(bool, bool registerchange);
+        bool print_full_pages_only(void);
+
+
+        void        set_fullpagereplacefunction(const hk_string& r,bool registerchange=true);
+        recodefunctiontype* fullpagereplacefunction(void);
+        hk_string      fullpagereplacefunctionstring(void);
+
+        static void add_fullpagereplacefunctiontype(const hk_string& name,recodefunctiontype* f);
+        static list<hk_string>* fullpagereplacefunctionlist(void);
+        static void set_embedfonts(bool);
+        static bool embedfonts(void);
+virtual hk_string tag_value(int tagnumber, bool& ok);
 
     protected:
         void set_progressdialog(progress_dialogtype* progressdialog);
         progress_dialogtype* progressdialog(void)const;
         void   remove_section(hk_reportsection*);
-        virtual hk_string replace(const hk_string& where);
+//         virtual hk_string replace(const hk_string& where);
         virtual bool datasource_disable(void);
         virtual bool before_columns_deleted(void);
 
@@ -482,6 +496,8 @@ bool execution_stopped(void);
         void    create_fontslists(void);
         bool    is_newfont(const hk_string&);
         void    search_sectionfonts(hk_reportsection*);
+        void    write_bufferedpage(void);
+        void    registerfont(hk_font*);
 	hk_reportprivate* p_private;
 //   	bool 		p_lastpage;
 
@@ -492,15 +508,17 @@ bool execution_stopped(void);
         typedef  map<hk_string,recodefunctiontype*,less<hk_string> >  recodefunctionlisttype ;
         static    recodefunctionlisttype  p_recodefunctions;
         static  list<hk_string> p_recodelist;
-        static list<hk_string> p_fontencodinglist;
+
+        static    recodefunctionlisttype  p_fullpagereplacefunctions;
+        static  list<hk_string> p_fullpagereplacelist;
 
         typedef  map<hk_string,report_configurefunction*,less<hk_string> >  reportconfigurelisttype ;
         static    reportconfigurelisttype  p_reportconfigurefunctions;
         static  list<hk_string> p_reportconfigurelist;
-        static int p_fontencoding;
 
         static int p_defaultfilenumber;
         static hk_string p_printcommand;
+        static bool p_embedfonts;
 
 }
 
