@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.63 $
+//$Revision: 1.77 $
 #include "hk_reportdata.h"
 #include "hk_reportsection.h"
 #include "hk_report.h"
@@ -34,15 +34,45 @@ public:
         bool p_bottom;
         bool p_loru;
         bool p_luro;
-
+        bool p_linebreak;
+        bool p_dynamic_height;
+        bool p_is_image;
+        
+	bool operator=(const hk_reportdatamodeprivate* d)
+	{
+	if (!d)return false;
+	p_data=d->p_data;
+	p_beforedata=d->p_beforedata;
+	p_afterdata=d->p_afterdata;
+	p_displayname=d->p_displayname;
+	p_top=d->p_top;
+	p_left=d->p_left;
+	p_right=d->p_right;
+	p_bottom=d->p_bottom;
+	p_loru=d->p_loru;
+	p_luro=d->p_luro;
+	p_linebreak=d->p_linebreak;
+	p_dynamic_height=d->p_dynamic_height;
+	p_is_image=d->p_is_image;
+	return true;
+	}
+hk_reportdatamodeprivate()
+  {
+    p_top=p_bottom=p_left=p_right=p_luro=p_loru=false;
+    p_linebreak=false;
+    p_dynamic_height=false;
+    p_is_image=false;
+  }
 
 };
+
 class hk_reportdataprivate
 {
 public:
        unsigned long p_count;
         bool p_runningcount;
         bool p_minmax_alreadyset;
+        int number_displayrows;
         number sum;
         number min;
         number max;
@@ -54,8 +84,25 @@ public:
         data_configurefunctiontype* p_dataconfigurefunction;
         hk_string p_dataconfigurefunctionstring;
 	hk_string p_on_print_action;
-        bool p_wordbreak;
-
+	list<hk_string> p_valuelines;
+	hk_string  p_value;
+	bool p_fully_printed;
+	int p_offset;
+	int p_pages;
+	bool p_first_print;
+	int tag_VALUE,tag_ROWNUMBER,tag_ALIGN,tag_ABSOLUTEPAGENUMBER,tag_PAGENUMBER,tag_RELHEIGHT,tag_RELWIDTH,
+	tag_RELYPOS,tag_RELXPOS,tag_WIDTH,tag_YPOS,tag_XPOS,tag_COUNT,tag_SUM,tag_MIN,tag_MAX,tag_AVERAGE,
+	tag_STDDEV,tag_STDDEVSAMPLE, tag_FIELDNAME,tag_DISPLAYNAME,
+	tag_HEIGHT,tag_FONT,tag_PSFONT,tag_FONTSIZE
+	;
+hk_reportdataprivate()
+  {
+  p_fully_printed=false;
+  p_offset=0;
+  p_pages=0;
+  p_first_print=true;
+  number_displayrows=-1;
+  }
 };
 
 
@@ -93,8 +140,6 @@ hk_reportdata::hk_reportdata(hk_reportsection* s):hk_dsdatavisible(s->report())
     p_private->p_minmax_alreadyset=false;
     p_private->p_replacefunction=NULL;
     p_private->p_datacountfunction=NULL;
-    p_designdata->p_top=p_designdata->p_bottom=p_designdata->p_left=p_designdata->p_right=p_designdata->p_luro=p_designdata->p_loru=false;
-    p_private->p_wordbreak=false;
     set_height(40,false);
     set_width(300,false);
 //  wanna_debug(true);
@@ -108,6 +153,7 @@ hk_reportdata::hk_reportdata(hk_reportsection* s):hk_dsdatavisible(s->report())
 
     if (p_datacountfunctions.size()==0)
     {
+//         add_datacountfunctiontype("Postscript",&recount_postscriptdata);
         add_datacountfunctiontype("None",NULL);
     }
     set_datacountfunction("None",false);
@@ -115,10 +161,36 @@ hk_reportdata::hk_reportdata(hk_reportsection* s):hk_dsdatavisible(s->report())
     if (p_datareplacefunctions.size()==0)
     {
         add_datareplacefunctiontype("FILECHARACTERSET",&encodefilecharsetfunction);
+        add_datareplacefunctiontype("Postscript",&replacepsdatafunction);
         add_datareplacefunctiontype("None",NULL);
     }
     set_replacefunction("None",false);
     set_data("%VALUE%",false);
+  p_private->tag_VALUE=register_tag("VALUE");
+  p_private->tag_ROWNUMBER=register_tag("ROWNUMBER");
+  p_private->tag_ALIGN=register_tag("ALIGN");
+  p_private->tag_ABSOLUTEPAGENUMBER=register_tag("ABSOLUTEPAGENUMBER");
+  p_private->tag_PAGENUMBER=register_tag("PAGENUMBER");
+  p_private->tag_RELHEIGHT=register_tag("RELHEIGHT");
+  p_private->tag_RELWIDTH=register_tag("RELWIDTH");
+  p_private->tag_RELYPOS=register_tag("RELYPOS");
+  p_private->tag_RELXPOS=register_tag("RELXPOS");
+  p_private->tag_WIDTH=register_tag("WIDTH");
+  p_private->tag_YPOS=register_tag("YPOS");
+  p_private->tag_XPOS=register_tag("XPOS");
+  p_private->tag_COUNT=register_tag("COUNT");
+  p_private->tag_SUM=register_tag("SUM");
+  p_private->tag_MIN=register_tag("MIN");
+  p_private->tag_MAX=register_tag("MAX");
+  p_private->tag_AVERAGE=register_tag("AVERAGE");
+  p_private->tag_STDDEV=register_tag("STDDEV");
+  p_private->tag_STDDEVSAMPLE=register_tag("STDDEVSAMPLE");
+  p_private->tag_FIELDNAME=register_tag("FIELDNAME");
+  p_private->tag_DISPLAYNAME=register_tag("DISPLAYNAME");
+  p_private->tag_HEIGHT=register_tag("HEIGHT");
+  p_private->tag_FONT=register_tag("FONT");
+  p_private->tag_PSFONT=register_tag("PSFONT");
+  p_private->tag_FONTSIZE=register_tag("FONTSIZE");
 
 }
 
@@ -166,167 +238,133 @@ void hk_reportdata::set_afterdata(const hk_string& a,bool registerchange)
 }
 
 
-hk_string hk_reportdata::replace(const hk_string& where)
-{
-    hk_string p_localbuffer;
-#ifdef HK_DEBUG
-    hkdebug("hk_reportdata::replace");
-#endif
-    p_localbuffer=smallstringconversion(hk_dsdatavisible::replace(where),nl_langinfo(CODESET),p_report?p_report->fontencodingstring():"");
-    if (!p_report->datasource()) return "";
-    list<hk_column*>* cols=p_report->datasource()->columns();
-    if (!cols) return "";
-
-    list<hk_column*>::iterator it=cols->begin();
-    while(it!=cols->end())
-    {
-        hk_string name="#";
-        name+=(*it)->name();
-        name+="#";
-        if (p_report->recodefunction()==NULL)
-            p_localbuffer=replace_all(name,p_localbuffer,(*it)->asstring(true));
-        else     p_localbuffer=replace_all(name,p_localbuffer,p_report->recodefunction()((*it)->asstring(true),p_report));
-        it++;
-    }
-    p_localbuffer=replace_all("%XPOS%",p_localbuffer,p_report->sizetype()==hk_presentation::relative?longint2string(p_section->relativ2horizontal(x())):longint2string(x()));
-    p_localbuffer=replace_all("%YPOS%",p_localbuffer,p_report->sizetype()==hk_presentation::relative?longint2string(p_section->relativ2vertical(y())):longint2string(y()));
-    p_localbuffer=replace_all("%WIDTH%",p_localbuffer,p_report->sizetype()==hk_presentation::relative?longint2string(p_section->relativ2horizontal(width())):longint2string(width()));
-    p_localbuffer=replace_all("%HEIGHT%",p_localbuffer,p_report->sizetype()==hk_presentation::relative?longint2string(p_section->relativ2vertical(height())):longint2string(height()));
-    p_localbuffer=replace_all("%RELXPOS%",p_localbuffer,p_report->sizetype()==hk_presentation::relative?longint2string(x()):longint2string(p_section->horizontal2relativ(x())));
-    p_localbuffer=replace_all("%RELYPOS%",p_localbuffer,p_report->sizetype()==hk_presentation::relative?longint2string(y()):longint2string(p_section->vertical2relativ(y())));
-    p_localbuffer=replace_all("%RELWIDTH%",p_localbuffer,p_report->sizetype()==hk_presentation::relative?longint2string(width()):longint2string(p_section->horizontal2relativ(width())));
-    p_localbuffer=replace_all("%RELHEIGHT%",p_localbuffer,p_report->sizetype()==hk_presentation::relative?longint2string(height()):longint2string(p_section->vertical2relativ(height())));
-    p_localbuffer=replace_all("%PAGENUMBER%",p_localbuffer,format_number(p_report->pagenumber(),use_numberseparator(),(commadigits()<0?0:commadigits())));
-    p_localbuffer=replace_all("%ABSOLUTEPAGENUMBER%",p_localbuffer,format_number(p_report->absolutepagenumber(),use_numberseparator(),(commadigits()<0?0:commadigits())));
-    p_localbuffer=replace_all("%ROWNUMBER%",p_localbuffer,format_number(p_report->rownumber(),use_numberseparator(),(commadigits()<0?0:commadigits())));
-
-    hk_string align;
-    switch (alignment())
-    {
-        case alignright : align="RIGHT";break;
-        case aligncenter : align="CENTER";break;
-        default         : align="LEFT";
-    };
-
-    p_localbuffer=replace_all("%ALIGN%",p_localbuffer,align);
-
-    if (column()!=NULL)
-    {
-        p_localbuffer=replace_all("%value%",p_localbuffer,column()->asstring(true));
-        p_localbuffer=replace_all("%fieldname%",p_localbuffer,columnname());
-        p_localbuffer=replace_all("%displayname%",p_localbuffer,p_viewdata->p_displayname);
-        p_localbuffer=replace_all("%COUNT%",p_localbuffer,format_number(p_private->p_count,use_numberseparator(),(commadigits()<0?0:commadigits())));
-        hk_string format="%.3f";
-        switch  (column()->columntype())
-        {
-            case  hk_column::integercolumn: ;
-            case hk_column::auto_inccolumn: ;
-            case hk_column::smallintegercolumn :
-            {
-                p_localbuffer=replace_all("%SUM%",p_localbuffer,format_number(p_private->sum.integer,use_numberseparator(),(commadigits()<0?0:commadigits())));
-                p_localbuffer=replace_all("%MIN%",p_localbuffer,format_number(p_private->min.integer,use_numberseparator(),(commadigits()<0?0:commadigits())));
-                p_localbuffer=replace_all("%MAX%",p_localbuffer,format_number(p_private->max.integer,use_numberseparator(),(commadigits()<0?0:commadigits())));
-                if (p_private->p_count>0)
-                {
-                    double average=(double)p_private->sum.integer/(double)p_private->p_count;
-                    p_localbuffer=replace_all("%AVERAGE%",p_localbuffer,format_number(average,use_numberseparator(),commadigits()));
-                    double stddev=sqrt((p_private->squaresum.integer-2.0*average*p_private->sum.integer+p_private->p_count*average*average)/p_private->p_count);
-                    p_localbuffer=replace_all("%STDDEV%",p_localbuffer,format_number(stddev,use_numberseparator(),commadigits()));
-                    stddev=sqrt((p_private->squaresum.integer-2.0*average*p_private->sum.integer+p_private->p_count*average*average)/(p_private->p_count-1));
-                    p_localbuffer=replace_all("%STDDEVSAMPLE%",p_localbuffer,format_number(stddev,use_numberseparator(),commadigits()));
-                }
-            };break;
-
-            case hk_column::floatingcolumn:  ;
-            case hk_column::smallfloatingcolumn:
-            {
-                p_localbuffer=replace_all("%SUM%",p_localbuffer,format_number(p_private->sum.real,use_numberseparator(),commadigits())); //cerr <<"sum="<<p_private->sum.real<<endl;
-                p_localbuffer=replace_all("%MIN%",p_localbuffer,format_number(p_private->min.real,use_numberseparator(),commadigits()));
-                p_localbuffer=replace_all("%MAX%",p_localbuffer,format_number(p_private->max.real,use_numberseparator(),commadigits()));
-                if (p_private->p_count>0)
-                {
-                    double average=p_private->sum.real/(double)p_private->p_count;
-                    p_localbuffer=replace_all("%AVERAGE%",p_localbuffer,format_number(average,use_numberseparator(),commadigits()));
-                    double stddev=sqrt((p_private->squaresum.real-2*average*p_private->sum.real+p_private->p_count*average*average)/p_private->p_count);
-                    p_localbuffer=replace_all("%STDDEV%",p_localbuffer,format_number(stddev,use_numberseparator(),commadigits()));
-                    stddev=sqrt((p_private->squaresum.real-2*average*p_private->sum.real+p_private->p_count*average*average)/(p_private->p_count-1));
-                    p_localbuffer=replace_all("%STDDEVSAMPLE%",p_localbuffer,format_number(stddev,use_numberseparator(),commadigits()));
-
-                }
-                const char* i="?";
-                p_localbuffer=replace_all("%AVERAGE%",p_localbuffer,i);
-                p_localbuffer=replace_all("%STDDEV%",p_localbuffer,i);
-                p_localbuffer=replace_all("%STDDEVSAMPLE%",p_localbuffer,i);
-            } break;
-            default:;
-
-        }
-
-        if (p_report!=NULL)
-        {
-            recodefunctiontype* r=p_report->recodefunction();
-            hk_string value;
-            hk_string name;
-            hk_string display;
-
-            if (!column()->is_nullvalue())
-            {
-             if (is_numerictype(column()))
-             {
-                double n=localestring2double(column()->asstring(true));
-                value=format_number(n,use_numberseparator(),commadigits()<0?(is_integertype(column())?0:-1):commadigits(),p_report->filelocale());
-//                value=format_number(n,use_numberseparator(),is_integertype(column())?(commadigits()<0)?0:commadigits():(commadigits()<0)?-1:commadigits());
-             }
-             else   value=column()->asstring(true);
-	    }
-             name=columnname();
-             display=p_viewdata->p_displayname;
-             
-             if (r!=NULL)
-              {
-                value=r(value,p_report);
-                name=r(name,p_report);
-                display=r(display,p_report);
-              }
-            
-            p_localbuffer=replace_all("%VALUE%",p_localbuffer,value);
-            p_localbuffer=replace_all("%FIELDNAME%",p_localbuffer,name);
-            p_localbuffer=replace_all("%DISPLAYNAME%",p_localbuffer,display);
-        }
-
-    }
-    p_localbuffer=replace_all("%FONT%",p_localbuffer,font().fontname());
-    p_localbuffer=replace_all("%PSFONT%",p_localbuffer,font().psfontname());
-    p_localbuffer=replace_all("%FONTSIZE%",p_localbuffer,longint2string(font().fontsize()));
-    return p_localbuffer;
-
-}
-
 
 hk_string hk_reportdata::actual_string(void)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_reportdata::actual_string");
 #endif
+    hk_string displayvalue=p_viewdata->p_data;
+
+    if (!linebreak()) 
+      {
+        displayvalue=p_private->p_value;
+        p_private->p_fully_printed=true;
+      }
+    else
+    {
+//        int h=(p_private->p_first_print?y():0)+height();
+//        if (p_report->sizetype()==hk_presentation::relative)
+//            h=p_section->relativ2vertical(h);
+       int restsize=p_report->periodic_when()-p_report->current_rowcount();
+       p_private->number_displayrows=-1;
+       unsigned int max_rows= (zmm2ps(restsize-(p_private->p_first_print?y():0))-font().char_descender_size()-1)/font().fontsize();
+        if (max_rows<p_private->p_valuelines.size())
+         {
+           p_private->number_displayrows=max_rows;
+           p_private->p_fully_printed=false;
+         }
+       else
+       {
+            p_private->number_displayrows=p_private->p_valuelines.size();
+           p_private->p_fully_printed=true;
+       }
+       list<hk_string>::iterator it=p_private->p_valuelines.begin();
+       displayvalue="";
+       int c=0;
+       while (it!=p_private->p_valuelines.end() && c<p_private->number_displayrows)
+       {
+          if (c>0)displayvalue+="\n";
+          displayvalue+=*it;
+         ++c;
+         ++it;
+       }
+       p_private->p_value=displayvalue;
+       unsigned int oc=p_private->number_displayrows;
+       while (oc>0 && p_private->p_valuelines.size()>oc)
+        {
+         p_private->p_valuelines.erase(p_private->p_valuelines.begin());
+         --oc;
+        }
+
+
+    
+    }
+    hk_string r=replace(p_viewdata->p_beforedata);
+   recodefunctiontype* rf=(p_report?p_report->recodefunction():NULL);
+
+    r+=rf?rf(displayvalue,p_report):displayvalue;
+    r+=replace(p_viewdata->p_afterdata);
+    if (p_private->p_datacountfunction!=NULL)set_counts_as(p_private->p_datacountfunction(this));
+    p_report->rowcount(counts_as());
+    p_private->p_first_print=false;
+    ++p_private->p_pages;
+    return  r;
+
+}
+
+bool hk_reportdata::data_fully_printed(void)
+{
+  return p_private->p_fully_printed;
+}
+
+int hk_reportdata::pagescount()
+{
+   return p_private->p_pages;
+}
+
+void hk_reportdata::reset_data_fully_printed(void)
+{
+  p_private->p_fully_printed=false;
+  p_private->p_offset=0;
+  p_private->p_pages=0;
+    
+    
     hk_string r;
     hk_string b;
     if (!action_on_print())
     {
       report()->stop_execution();
-      return "";
+      return ;
     }
-    r=p_viewdata->p_beforedata+p_viewdata->p_data+p_viewdata->p_afterdata;
-    r=replace(r);
-    b=r;
-    if (p_private->p_replacefunction!=NULL) b=p_private->p_replacefunction(this,r);
-    if (p_private->p_datacountfunction!=NULL)set_counts_as(p_private->p_datacountfunction(this));
-    p_report->rowcount(counts_as());
-    r=b;
-    return  r;
+    if (column())p_private->p_value=column()->asstring(true);
+    b=replace(p_viewdata->p_data);
+    hk_string displayvalue=p_viewdata->p_data;
+    p_private->p_valuelines.clear();
+    if (!linebreak()) 
+      {
+        p_private->p_valuelines.push_back(b); 
+        displayvalue=b;
+        if (report()->useencodingtab()) 
+           font().register_string(b);// just needed to register the characters in encodingtab()
+       p_private->p_value=displayvalue;
+        p_private->number_displayrows=1;
+      }
+    else
+    if (!font().text2lines((p_report->sizetype()==hk_presentation::relative?p_section->relativ2horizontal(width()):width())-ps2zmm(4), &p_private->p_valuelines, b))
+        cerr <<" TEXT2LINES hat nicht funktioniert!"<<endl;
+    else
+    { //linebreak
+       displayvalue="";
+       int h=(p_private->p_first_print?y():0)+height();
+       if (p_report->sizetype()==hk_presentation::relative)
+           h=p_section->relativ2vertical(h);
+       int restsize=p_report->periodic_when()-p_report->current_rowcount();
+           p_private->number_displayrows=-1;
+       if (h>=restsize)
+         {
+           p_private->number_displayrows=(zmm2ps(restsize-(p_private->p_first_print?y():0))-font().char_descender_size()-1)/font().fontsize();
+
+         }
+    
+    }
+  
+  
+  p_private->p_first_print=true;
+
 
 }
 
-
 void hk_reportdata::count(void)
 {
 #ifdef HK_DEBUG
@@ -523,9 +561,26 @@ bool    hk_reportdata::diagonalluro(void)
 }
 
 
-bool    hk_reportdata::wordbreak(void)
+bool    hk_reportdata::linebreak(void)
 {
-    return p_private->p_wordbreak;
+        if (p_report->mode()==hk_presentation::designmode) return p_designdata->p_linebreak;
+	else return p_viewdata->p_linebreak;
+}
+
+
+void hk_reportdata::set_dynamic_height(bool b,bool registerchange)
+{
+        if (p_report->mode()==hk_presentation::designmode) p_designdata->p_dynamic_height=b;
+    p_viewdata->p_dynamic_height=b;
+    if(p_private->p_dataconfigurefunction!=NULL)p_private->p_dataconfigurefunction(this);
+    has_changed(registerchange);
+    
+}
+
+bool    hk_reportdata::dynamic_height(void) const
+{
+        if (p_report->mode()==hk_presentation::designmode) return p_designdata->p_dynamic_height;
+	else return p_viewdata->p_dynamic_height;
 }
 
 
@@ -574,8 +629,11 @@ hk_font hk_reportdata::font(void)
 #ifdef HK_DEBUG
     hkdebug("hk_reportdata::font");
 #endif
-    if (hk_dsdatavisible::font().fontname().size()==0) return p_section->font();
-    else return hk_dsdatavisible::font();
+    hk_font f;
+    if (hk_dsdatavisible::font().fontname().size()==0) f= p_section->font();
+    else f= hk_dsdatavisible::font();
+    f.set_encodingtab(p_report->masterreport()?p_report->masterreport()->encodingtab():p_report->encodingtab());
+    return f;
 }
 
 
@@ -661,14 +719,20 @@ void     hk_reportdata::set_frame(bool l,bool registerchange)
 }
 
 
-void hk_reportdata::set_wordbreak(bool b,bool registerchange)
+void hk_reportdata::set_linebreak(bool b,bool registerchange)
 {
-    p_private->p_wordbreak=b;
+        if (p_report->mode()==hk_presentation::designmode) p_designdata->p_linebreak=b;
+    p_viewdata->p_linebreak=b;
     if(p_private->p_dataconfigurefunction!=NULL)p_private->p_dataconfigurefunction(this);
     has_changed(registerchange);
+
+    
+    
 }
 
 
+
+
 void  hk_reportdata::savedata(ostream& s,bool userdefined)
 {
 #ifdef HK_DEBUG
@@ -684,7 +748,9 @@ void  hk_reportdata::savedata(ostream& s,bool userdefined)
     set_tagvalue(s,"BOTTOMBORDER",p_designdata->p_bottom);
     set_tagvalue(s,"DIAGONALLORU",p_designdata->p_loru);
     set_tagvalue(s,"DIAGONALLURO",p_designdata->p_luro);
-    set_tagvalue(s,"WORDBREAK",p_private->p_wordbreak);
+    set_tagvalue(s,"WORDBREAK",p_designdata->p_linebreak);
+    set_tagvalue(s,"IS_IMAGE",p_designdata->p_is_image);
+    set_tagvalue(s,"DYNAMIC_HEIGHT",p_designdata->p_dynamic_height);
     set_tagvalue(s,"RUNNINGCOUNT",p_private->p_runningcount);
     set_tagvalue(s,"ONPRINT_ACTION",p_private->p_on_print_action);
 
@@ -727,25 +793,24 @@ void  hk_reportdata::loaddata(const hk_string& definition,bool userdefined)
     }
     get_tagvalue(definition,"DISPLAYNAME",p_designdata->p_displayname);
     get_tagvalue(definition,"TOPBORDER",p_designdata->p_top);
-    p_viewdata->p_top=p_designdata->p_top;
     get_tagvalue(definition,"LEFTBORDER",p_designdata->p_left);
-    p_viewdata->p_left=p_designdata->p_left;
     get_tagvalue(definition,"RIGHTBORDER",p_designdata->p_right);
-    p_viewdata->p_right=p_designdata->p_right;
     get_tagvalue(definition,"BOTTOMBORDER",p_designdata->p_bottom);
-    p_viewdata->p_bottom=p_designdata->p_bottom;
     get_tagvalue(definition,"DIAGONALLORU",p_designdata->p_loru);
-    p_viewdata->p_loru=p_designdata->p_loru;
     get_tagvalue(definition,"DIAGONALLURO",p_designdata->p_luro);
-    p_viewdata->p_luro=p_designdata->p_luro;
-    get_tagvalue(definition,"WORDBREAK",p_private->p_wordbreak);
+    get_tagvalue(definition,"WORDBREAK",p_designdata->p_linebreak);
     get_tagvalue(definition,"RUNNINGCOUNT",p_private->p_runningcount);
+    get_tagvalue(definition,"DYNAMIC_HEIGHT",p_designdata->p_dynamic_height);
     get_tagvalue(definition,"ONPRINT_ACTION",p_private->p_on_print_action);
+    get_tagvalue(definition,"IS_IMAGE",p_designdata->p_is_image);
+    *p_viewdata=*p_designdata;
 
     hk_string configurefunc;
     get_tagvalue(definition,"DATACONFIGUREFUNCTION",configurefunc);
     if  (configurefunc=="POSTSCRIPT") p_private->p_dataconfigurefunction=&configure_postscriptdata;
     if(p_private->p_dataconfigurefunction!=NULL)p_private->p_dataconfigurefunction(this);
+    
+
 }
 
 
@@ -977,3 +1042,282 @@ hk_string hk_reportdata::afterdata()
 }
 
 
+list<hk_string>*  hk_reportdata::value_in_lines()
+{
+  return &p_private->p_valuelines;
+}
+
+
+unsigned int    hk_reportdata::height(void) 
+{
+ unsigned int h=hk_dsdatavisible::height();
+ if (dynamic_height() && p_report->mode()==hk_presentation::viewmode )
+ {  
+   unsigned int n=ps2zmm(font().fontsize()*p_private->number_displayrows+font().char_descender_size()+1);
+   if (n>h)h=n;
+ }
+//  hk_font f=font();
+//  cerr <<"font:"<<f.fontname()<<" descender:"<<f.char_descender_size()<<endl;
+ return h;
+}
+
+
+
+hk_string hk_reportdata::tag_value(int tagnumber, bool& ok)
+{
+  ok=false;
+    if (!p_report->datasource()) return "";
+    ok=true;
+
+
+   int w=0;
+
+    hk_string result;
+//    if (p_private->p_replacefunction!=NULL) p_localbuffer=p_private->p_replacefunction(this,p_localbuffer);
+
+      if (tagnumber==p_private->tag_XPOS)
+    {
+       return (p_report->sizetype()==hk_presentation::relative?longint2string(p_section->relativ2horizontal(x())):longint2string(x()));
+     }
+      if (tagnumber==p_private->tag_YPOS)
+    {
+     if (!p_private->p_first_print)
+      return longint2string(0);
+     else
+      return (p_report->sizetype()==hk_presentation::relative?longint2string(p_section->relativ2vertical(y())):longint2string(y()));
+    }
+    
+    
+      if (tagnumber==p_private->tag_WIDTH)
+    {
+    return (p_report->sizetype()==hk_presentation::relative?longint2string(p_section->relativ2horizontal(width())):longint2string(width()));
+    }
+    w=p_report->sizetype()==hk_presentation::relative?p_section->relativ2horizontal(width()):width();
+    
+    if (tagnumber==p_private->tag_RELXPOS)
+    {
+     return (p_report->sizetype()==hk_presentation::relative?longint2string(x()):longint2string(p_section->horizontal2relativ(x())));
+    }
+    
+    
+    if (tagnumber==p_private->tag_RELYPOS)
+    {
+    return (p_report->sizetype()==hk_presentation::relative?longint2string(y()):longint2string(p_section->vertical2relativ(y())));
+    }
+    
+        if (tagnumber==p_private->tag_RELWIDTH)
+    {
+      return (p_report->sizetype()==hk_presentation::relative?longint2string(width()):longint2string(p_section->horizontal2relativ(width())));
+    }
+    
+        if (tagnumber==p_private->tag_RELHEIGHT)
+    {
+
+    return (p_report->sizetype()==hk_presentation::relative?longint2string(height()):longint2string(p_section->vertical2relativ(height())));
+    }
+    
+    
+    if (tagnumber==p_private->tag_PAGENUMBER)
+    {
+    return (format_number(p_report->pagenumber(),use_numberseparator(),(commadigits()<0?0:commadigits())));
+    }
+    
+    if (tagnumber==p_private->tag_ABSOLUTEPAGENUMBER)
+    {
+    return (format_number(p_report->absolutepagenumber(),use_numberseparator(),(commadigits()<0?0:commadigits())));
+    }
+    if (tagnumber==p_private->tag_ROWNUMBER)
+    {
+    
+    return (format_number(p_report->rownumber(),use_numberseparator(),(commadigits()<0?0:commadigits())));
+    }
+    if (tagnumber==p_private->tag_ALIGN)
+    {
+    hk_string align;
+    switch (alignment())
+    {
+        case alignright : align="RIGHT";break;
+        case aligncenter : align="CENTER";break;
+        default         : align="LEFT";
+    };
+
+    return align;
+    }
+    
+    if (column()!=NULL)
+    {
+      if (tagnumber==p_private->tag_COUNT)
+      {
+        return (format_number(p_private->p_count,use_numberseparator(),(commadigits()<0?0:commadigits())));
+      }
+        hk_string format="%.3f";
+        switch  (column()->columntype())
+        {
+            case  hk_column::integercolumn: ;
+            case hk_column::auto_inccolumn: ;
+            case hk_column::smallintegercolumn :
+            {
+                   if (tagnumber==p_private->tag_SUM)
+    			{
+ 			  return (format_number(p_private->sum.integer,use_numberseparator(),(commadigits()<0?0:commadigits())));
+                	}
+                   if (tagnumber==p_private->tag_MIN)
+    			{
+ 			 return (format_number(p_private->min.integer,use_numberseparator(),(commadigits()<0?0:commadigits())));
+                	}
+   		   if (tagnumber==p_private->tag_MAX)
+                    {
+                        return (format_number(p_private->max.integer,use_numberseparator(),(commadigits()<0?0:commadigits())));
+                    }
+                if (p_private->p_count>0)
+                {
+                    double average=(double)p_private->sum.integer/(double)p_private->p_count;
+   			if (tagnumber==p_private->tag_AVERAGE)
+    			{
+                         return (format_number(average,use_numberseparator(),commadigits()));
+                        }
+                    double stddev=sqrt((p_private->squaresum.integer-2.0*average*p_private->sum.integer+p_private->p_count*average*average)/p_private->p_count);
+                       if (tagnumber==p_private->tag_STDDEV)
+    			{
+ 
+                          return (format_number(stddev,use_numberseparator(),commadigits()));
+                        }
+                       if (tagnumber==p_private->tag_STDDEVSAMPLE)
+    			{
+ 
+                    stddev=sqrt((p_private->squaresum.integer-2.0*average*p_private->sum.integer+p_private->p_count*average*average)/(p_private->p_count-1));
+                    return (format_number(stddev,use_numberseparator(),commadigits()));
+                        }
+                }
+            };break;
+
+            case hk_column::floatingcolumn:  ;
+            case hk_column::smallfloatingcolumn:
+            {
+                   if (tagnumber==p_private->tag_SUM)
+    		{
+ 			return (format_number(p_private->sum.real,use_numberseparator(),commadigits())); //cerr <<"sum="<<p_private->sum.real<<endl;
+ 		}
+                   if (tagnumber==p_private->tag_MIN)
+    		{
+ 			return (format_number(p_private->min.real,use_numberseparator(),commadigits()));
+                }
+                   if (tagnumber==p_private->tag_MAX)
+    		{
+ 
+                return (format_number(p_private->max.real,use_numberseparator(),commadigits()));
+                }
+                if (p_private->p_count>0)
+                {
+ 			double average=p_private->sum.real/(double)p_private->p_count;
+                       if (tagnumber==p_private->tag_AVERAGE)
+    			{
+                        return (format_number(average,use_numberseparator(),commadigits()));
+                        }
+                    
+                       if (tagnumber==p_private->tag_STDDEV)
+    			{
+ 			double stddev=sqrt((p_private->squaresum.real-2*average*p_private->sum.real+p_private->p_count*average*average)/p_private->p_count);
+                        return (format_number(stddev,use_numberseparator(),commadigits()));
+                        }
+                    
+                       if (tagnumber==p_private->tag_STDDEVSAMPLE)
+    			{
+ 			  double stddev=sqrt((p_private->squaresum.real-2*average*p_private->sum.real+p_private->p_count*average*average)/(p_private->p_count-1));
+                    	  return (format_number(stddev,use_numberseparator(),commadigits()));
+			}
+                }
+                hk_string i="?";
+                   if (tagnumber==p_private->tag_AVERAGE)
+                   return i;
+                   if (tagnumber==p_private->tag_STDDEV)
+                   return i;
+                   if (tagnumber==p_private->tag_STDDEVSAMPLE)
+                   return i;
+            } break;
+            default:;
+
+        }
+
+        if (p_report!=NULL)
+        {
+            hk_string val, tstvalue;
+            hk_string name;
+            hk_string display;
+
+            if (!column()->is_nullvalue())
+            {
+             if (is_numerictype(column()))
+             {
+                double n=localestring2double(column()->asstring(true));
+                val=format_number(n,use_numberseparator(),commadigits()<0?(is_integertype(column())?0:-1):commadigits(),p_report->filelocale());
+             }
+             else   val=p_private->p_value;
+	    }
+             name=columnname();
+             display=p_viewdata->p_displayname;
+             tstvalue=val;
+   	   if (tagnumber==p_private->tag_VALUE)
+   	   {
+             
+             return val;
+           } 
+             if (tagnumber==p_private->tag_FIELDNAME)
+            return name;
+            
+   	   if (tagnumber==p_private->tag_DISPLAYNAME)
+             return display;
+
+        
+        }
+
+    }
+    
+       if (tagnumber==p_private->tag_HEIGHT)
+       return (p_report->sizetype()==hk_presentation::relative?longint2string(p_section->relativ2vertical(height())):longint2string(height()));
+
+       if (tagnumber==p_private->tag_FONT)
+        return font().fontname();
+       if (tagnumber==p_private->tag_PSFONT)
+       return font().psfontname();
+       if (tagnumber==p_private->tag_FONTSIZE)
+       return longint2string(font().fontsize());
+    ok=false;
+    return hk_dsdatavisible::tag_value(tagnumber,ok);
+
+
+}
+
+
+
+hk_string hk_reportdata::column_value(const hk_string& colname,bool& ok)
+{
+ok=false;
+
+ if (datasource())
+ {
+  hk_column* c=datasource()->column_by_name(colname);
+  if (c)
+  {
+    ok=true;
+    return c->asstring();
+  }
+ }
+return "";
+}
+
+
+void    hk_reportdata::set_is_image(bool  img,bool registerchange)
+{
+   p_viewdata->p_is_image=img;
+    if (p_report->mode()==hk_presentation::designmode) p_designdata->p_is_image=img;
+    has_changed(registerchange);
+}
+
+bool    hk_reportdata::is_image(void)
+{
+     if (p_report->mode()==hk_presentation::designmode) return p_designdata->p_is_image;
+     else return p_viewdata->p_is_image;
+}
+
+
