@@ -29,7 +29,7 @@ class hk_reportdataprivate;
 /**
  * represents the data of a field within a section
  * @short represents the data of a field within a section.
- *@version $Revision: 1.34 $
+ *@version $Revision: 1.40 $
  * @author Horst Knorr (hk_classes@knoda.org)
 
  *
@@ -54,11 +54,9 @@ class hk_reportdataprivate;
 </pre>
 *If you have set @ref set_columnname  you have additionally the following variable names
 <pre>
-%value%          the raw value of the column defined with @ref set_columnname
-%fieldname%      the name of the column not recoded defined with set_columnname
-%VALUE%          the value of the column defined with @ref set_columnname recoded
+%VALUE%          the value of the column defined with @ref set_columnname 
 with @ref hk_report::set_recodefunction
-%FIELDNAME%      the recoded (with @ref hk_report::set_recodefunction ) name of the column
+%FIELDNAME%      the  name of the column
 defined with @ref set_columnname
 %COUNT%          the number of values
 </pre>
@@ -191,8 +189,11 @@ To create a html link use set_data("<A HREF=\"#url#\">#name#</A>");
  *
  *See @ref set_configurefunction  for details
  */
-        void    set_wordbreak(bool b=true,bool registerchange=true);
-        bool    wordbreak(void);
+        void    set_linebreak(bool b=true,bool registerchange=true);
+        bool    linebreak(void);
+	void    set_dynamic_height(bool dynamic,bool registerchange=true);
+	bool    dynamic_height(void) const;
+
 /**
  *in this function you have to define how to react on i.e. set_bottomline etc.
  */
@@ -230,11 +231,20 @@ To create a html link use set_data("<A HREF=\"#url#\">#name#</A>");
         virtual void raise_widget(bool registerchange=true);
 	void set_on_print_action(const hk_string&,bool registerchange=true);
 	hk_string on_print_action(void);
+	list<hk_string>*  value_in_lines();
+        
+        unsigned int    height(void) ;
+	bool data_fully_printed(void);
+	void reset_data_fully_printed(void);
+	int pagescount(void);
+virtual hk_string tag_value(int tagnumber, bool& ok);
+virtual hk_string column_value(const hk_string& colname,bool& ok);
+void    set_is_image(bool,bool registerchange=true );
+bool    is_image(void);
 
     protected:
         hk_reportdata(hk_reportsection*);
         virtual     ~hk_reportdata(void);
-        virtual hk_string replace(const hk_string& where);
         virtual void new_column_pointer_created(void);
 	virtual void sizetype_changed(void);
 	virtual bool	presentationmode_changed(void);
