@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.62 $
+//$Revision: 1.70 $
 #include "hk_reportsection.h"
 #include "hk_reportsectionpair.h"
 #include "hk_report.h"
@@ -39,6 +39,7 @@ hk_reportsection::hk_reportsection(hk_report* e):hk_dsdatavisible(e)
     p_visibletype=hk_visible::reportsection;
     p_report=e;
     p_unique=false;
+    p_printsection=true;
     p_automatic_create_datas=true;
     p_already_automaticcreated_data=false;
     p_uniqueendsection=false;
@@ -420,6 +421,7 @@ bool hk_reportsection::actual_string(void)
 #ifdef HK_DEBUG
     hkdebug("hk_reportsection::actual_string");
 #endif
+if (!p_printsection) return true;
     bool result=true;
     hk_string   p_buffer;
     p_buffer="";
@@ -434,13 +436,39 @@ bool hk_reportsection::actual_string(void)
     {
         p_forcenewsection=false;
         vector<hk_reportdata*>::iterator vit=p_data.begin();
+        while (vit!=p_data.end())
+        {
+          (*vit)->reset_data_fully_printed();
+          ++vit;
+        }
+        
+        
+        
+        bool first_try=true;
+        if (p_print_subreport_before_data) result=print_subreport();
+        do 
+        {
+        if (!first_try)
+        {
+          p_report->new_page();
+         p_buffer="";
+        }
+        else
+        first_try=false;
+        
+        vit=p_data.begin();
         p_buffer+=replace(sectionbegin());
+        int c=0;
         while (vit!=p_data.end()&&!report()->execution_stopped())
         {
 
-            if (vit!=p_data.begin())
+            if (!(*vit)->data_fully_printed())
+            {
+            if (c>0)
                 p_buffer+=replace(betweendata());
             p_buffer+=(*vit)->actual_string();
+            ++c;
+            }
 //if(uni)(*vit)->reset_count();
             vit++;
 
@@ -449,17 +477,34 @@ bool hk_reportsection::actual_string(void)
         p_buffer+=replace(sectionend());
         p_sectionwasprinted=true;
         if (p_replacefunction!=NULL) p_buffer=p_replacefunction(this,p_buffer);
-        if (p_print_subreport_before_data) result=print_subreport();
 //         if (p_sectioncountfunction!=NULL) p_counts_as=p_sectioncountfunction(this);
-        p_report->rowcount(counts_as());
-        if (uni&&p_uniqueendsection) reset_count();
+        if (p_report->page_header()!=this &&p_report->page_footer()!=this  )p_report->rowcount(counts_as());
         *(p_report->outputstream()) <<p_buffer;
+        } while (!is_fully_printed()) ;// end !is_fully printed
+        
+//         p_report->rowcount(p_report->sizetype()==hk_presentation::relative?relativ2vertical(offset()):offset());
+        if (uni&&p_uniqueendsection) reset_count();
         if (!p_print_subreport_before_data) result=print_subreport();
     }
     else p_sectionwasprinted=false;
  return result;
 }
 
+bool hk_reportsection::is_fully_printed(void)
+{
+        if (!p_printsection) return true;
+        vector<hk_reportdata*>::iterator vit=p_data.begin();
+        while (vit!=p_data.end())
+        {
+          if (!(*vit)->data_fully_printed())
+           {
+             return false;
+           }
+          ++vit;
+        }
+return true;
+}
+
 
 void hk_reportsection::create_countingfields(void)
 {
@@ -583,13 +628,13 @@ bool hk_reportsection::print_subreport(void)
 }
 
 
-void    hk_reportsection::set_unique(bool unique, bool endsection,bool registerchange)
+void    hk_reportsection::set_unique(bool u, bool end,bool registerchange)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_reportsection::set_unique");
 #endif
-    p_unique=unique;
-    p_uniqueendsection=endsection;
+    p_unique=u;
+    p_uniqueendsection=end;
     has_changed(registerchange);
 }
 
@@ -609,14 +654,18 @@ void hk_reportsection::reset(void)
 
 hk_font hk_reportsection::font(void)
 {
-    if (hk_dsdatavisible::font().fontname().size()==0) return p_report->font();
-    else return hk_dsdatavisible::font();
+    hk_font f;
+    if (hk_dsdatavisible::font().fontname().size()==0) f= p_report->font();
+    else f=hk_dsdatavisible::font();
+     f.set_encodingtab(p_report->encodingtab());
+
+return f;
 }
 
 
 
 
-void    hk_reportsection::set_subreport(const hk_string& subreport,bool before_data,bool registerchange)
+void    hk_reportsection::set_subreport(const hk_string& sub,bool before_data,bool registerchange)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_reportsection::set_subreport");
@@ -634,7 +683,7 @@ void    hk_reportsection::set_subreport(const hk_string& subreport,bool before_d
     p_subreport=NULL;
 
     }
-    p_subreportstring=subreport;
+    p_subreportstring=sub;
     if (p_subreportstring.size()==0)return;
     hk_database* db=p_report->database();
 
@@ -642,7 +691,7 @@ void    hk_reportsection::set_subreport(const hk_string& subreport,bool before_d
     {
         p_subreport=new hk_report();
         p_subreport->set_database(db);
-        if (!p_subreport->load_report(subreport))
+        if (!p_subreport->load_report(sub))
         {
             delete p_subreport;
             p_subreport=NULL;
@@ -1227,13 +1276,13 @@ hk_reportdata* hk_reportsection::get_reportdatavisible(long nr)
 return NULL;
 }
 
-hk_reportdata* hk_reportsection::get_reportdatavisible(const hk_string& identifier)
+hk_reportdata* hk_reportsection::get_reportdatavisible(const hk_string& i)
 {
 
     vector<hk_reportdata*>::iterator it=p_data.begin();
     while (it!=p_data.end())
     {
-        if ( (*it)->identifier()==identifier) return (*it);
+        if ( (*it)->identifier()==i) return (*it);
         it++;
     }
 
@@ -1260,3 +1309,18 @@ hk_string hk_reportsection::sectioncountfunctionstring(void)
 {
 return p_sectioncountfunctionstring;
 }
+
+
+
+void hk_reportsection::set_print_section(bool p)
+{
+p_printsection=p;
+}
+
+bool hk_reportsection::print_section(void)
+{
+  return p_printsection;
+}
+
+
+
