@@ -85,7 +85,7 @@ typedef struct
 </pre>
 
 * @short represents a section of the report.
-*@version $Revision: 1.43 $
+*@version $Revision: 1.45 $
 * @author Horst Knorr (hk_classes@knoda.org)
 */
 
@@ -261,6 +261,10 @@ class hk_reportsection : public hk_dsdatavisible
         reportsectionautomaticcreatedatatype* automaticcreatedatafunction(void){ return p_automaticreatedatafunction;}
 hk_reportdata* get_reportdatavisible(long nr);
 hk_reportdata* get_reportdatavisible(const hk_string& identifier);
+         bool is_fully_printed(void);
+         void set_print_section(bool);
+         bool print_section(void);
+
 
     protected:
         hk_reportsection(hk_report*);
@@ -326,5 +330,6 @@ hk_reportdata* get_reportdatavisible(const hk_string& identifier);
         hk_reportsectionpair* p_pair;
         bool p_forcenewsection;
         reportsectionautomaticcreatedatatype* p_automaticreatedatafunction;
+        bool p_printsection;
 };
 #endif
