@@ -8,7 +8,8 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.34 $
+//$Revision: 1.37 $
+using namespace std;
 #include "hk_string.h"
 #include "hk_class.h"
 #include <stdlib.h>
@@ -39,7 +40,7 @@ hk_string smallstringconversion(const hk_string & what, const hk_string& from, c
     }
 
     size_t buffersize=100;
-    char* outbuffer= new char[buffersize+sizeof(size_t)];
+    char* outbuffer= new char[buffersize+sizeof(wchar_t)];
     char* outbufferpointer=outbuffer;
     const char* inbufferpointer=what.c_str();
     size_t availableinbuffersize=what.size();
@@ -62,16 +63,16 @@ hk_string smallstringconversion(const hk_string & what, const hk_string& from, c
             if (errno==EILSEQ)
             {
 //undefined character => ignore it
-                  cerr <<"hk_string smallstringconversion: undefined character !!!"<<endl;
+//                   cerr <<"hk_string smallstringconversion: undefined character !!!"<<endl;
                 inbufferpointer +=sizeof(char);
                 if (availableinbuffersize>sizeof(char))availableinbuffersize -=sizeof(char);
 
             }
             else
             {                                     //a real error occured
-                cerr<<"hk_string:: Error while converting  errno:"<<errno<<" convertresult: '"<<convertresult<<"'"<<endl;
-		cerr <<"conversion from: '"<<from<< "' to: '"<<to<<"'"<<endl;
-                iconv_close(handle);
+//                 cerr<<"hk_string:: Error while converting  errno:"<<errno<<" convertresult: '"<<convertresult<<"'"<<endl;
+// 		cerr <<"conversion from: '"<<from<< "' to: '"<<to<<"'"<<endl;
+                iconv_close(handle); 
                 delete[] outbuffer;
                 return what; //nevertheless return the string unchanged
             }
@@ -79,12 +80,11 @@ hk_string smallstringconversion(const hk_string & what, const hk_string& from, c
         else
         {
             process_convert=false;
-            *outbufferpointer='\0';
-            result+=outbuffer;
+            *outbufferpointer=L'\0';
+            result.append(outbuffer,outbufferpointer-outbuffer);
         }
 
     }
-
     iconv_close(handle);
     delete[] outbuffer;
     return result;
@@ -341,7 +341,7 @@ hk_string trimright(const hk_string& t)
 {
  if (t.size()==0) return t;
  hk_string result=t;
- hk_string::size_type p=result.size()-1;
+ long p=result.size()-1;
  while(p>=0)
  {
   if (!isspace(result[p]))
