@@ -15,7 +15,14 @@
 #include <list>
 class hk_form;
 class hk_subformprivate;
+class hk_subformmodeprivate;
 
+/**
+ *@short represents a subform in a form
+ *@version $Revision: 1.5 $
+ *@author Horst Knorr (hk_classes@knoda.org)
+ *
+ */
 
 
 class hk_subform: public hk_dsvisible
@@ -24,11 +31,31 @@ friend class hk_form;
 public:
 hk_subform(hk_presentation* parent);
 virtual ~hk_subform();
+/**
+*sets the name of the subform.
+*/
 void set_name(const hk_string&, bool registerchange=true);
 hk_string name(void) const;
+/**
+*returns the form object that will internally be used to display the subform
+*/
 hk_form* subform();
+/**
+ *@param subfield fieldname of a column of the main subform-datasource which has to be connected to the main datasource of the master form.
+ *@param masterfield columnname of the main masterform-datasource which value has to be equal with the value of subfield.
+ *@param registerchange if this class is part of a hk_presentation object (i.e. a form or a report) and registerchange
+ *is true, then the changes will be stored when the hk_presentation object is closed.
+
+*/
 void        add_depending_fields( const hk_string& subfield,const hk_string& masterfield,bool registerchange=true);
+/**
+*clears the list of fields set with add_depending_fields
+*/
 void        clear_depending_fields(bool registerchange=true);
+/**
+*when the subform is set during runtime, the subform will be loaded and displayed when calling this function
+*/
+void   activate_subform(void);
 list<dependingclass>* depending_on_fields(void);
 virtual void savedata(ostream& s, bool savedatasource,bool saveall);
 virtual void savedata(ostream& s  );
@@ -42,6 +69,8 @@ void internal_set_datasourcevalues(void);
 private:
 
 hk_subformprivate* p_private;
+hk_subformmodeprivate* p_viewdata;
+hk_subformmodeprivate* p_designdata;
 };
 
 #endif
