@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.87 $
+//$Revision: 1.90 $
 #include "hk_visible.h"
 #include "hk_presentation.h"
 #include "hk_form.h"
@@ -74,6 +74,9 @@ p_enabled=true;
 
 };
 
+
+typedef map<hk_string,int,less<hk_string> > tagtype;
+
 class hk_visibleprivate
 {
 public:
@@ -87,6 +90,8 @@ public:
 	hk_key p_key;
 	hk_tabvisible* p_tabvisible;
 	bool p_movebuddylabel;
+	tagtype p_tags;
+	int tag_counts_as,tag_time,tag_date,tag_fgred,tag_fggreen,tag_fgblue,tag_bgred,tag_bggreen,tag_bgblue;
 
 };
 
@@ -118,6 +123,15 @@ p_private=new hk_visibleprivate;
     p_designdata->p_foregroundcolour=hk_black;
     p_designdata->p_backgroundcolour=hk_grey;
    *p_viewdata=*p_designdata;
+   p_private->tag_counts_as=register_tag("COUNTS_AS");
+   p_private->tag_time=register_tag("TIME");
+   p_private->tag_date=register_tag("DATE");
+   p_private->tag_fgred=register_tag("FGRED");
+   p_private->tag_fggreen=register_tag("FGGREEN");
+   p_private->tag_fgblue=register_tag("FGBLUE");
+   p_private->tag_bgred=register_tag("BGRED");
+   p_private->tag_bggreen=register_tag("BGGREEN");
+   p_private->tag_bgblue=register_tag("BGBLUE");
 
 }
 
@@ -142,12 +156,12 @@ hk_visible::~hk_visible(void)
 }
 
 
-void hk_visible::set_size(unsigned int x, unsigned int y,unsigned int w, unsigned int h, bool registerchange)
+void hk_visible::set_size(unsigned int xv, unsigned int yv,unsigned int wv, unsigned int hv, bool registerchange)
 {
-   set_size(x,y,w,h,registerchange,false);
+   set_size(xv,yv,wv,hv,registerchange,false);
 }
 
-void hk_visible::set_size(unsigned int x, unsigned int y,unsigned int w, unsigned int h, bool registerchange,bool force_setting)
+void hk_visible::set_size(unsigned int xv, unsigned int yv,unsigned int wv, unsigned int hv, bool registerchange,bool force_setting)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_visible:set_size");
@@ -161,14 +175,14 @@ void hk_visible::set_size(unsigned int x, unsigned int y,unsigned int w, unsigne
     }
 
     p_setcoordinates=true;
-    unsigned int ppx=x;
-    unsigned int ppy=y;
-    unsigned int ppw=w;
-    unsigned int pph=h;
-    unsigned int usex=x;
-    unsigned int usey=y;
-    unsigned int usew=w;
-    unsigned int useh=h;
+    unsigned int ppx=xv;
+    unsigned int ppy=yv;
+    unsigned int ppw=wv;
+    unsigned int pph=hv;
+    unsigned int usex=xv;
+    unsigned int usey=yv;
+    unsigned int usew=wv;
+    unsigned int useh=hv;
     if (p_presentation!=NULL&&p_presentation->sizetype()==hk_presentation::relative)
     {
         if (ppw<100)
@@ -304,15 +318,15 @@ void hk_visible::set_width(unsigned int pwidth, bool registerchange)
 }
 
 
-void hk_visible::set_size(unsigned int width, unsigned int height, bool registerchange)
+void hk_visible::set_size(unsigned int w, unsigned int h, bool registerchange)
 {
-    set_size(x(),y(),width,height,registerchange);
+    set_size(x(),y(),w,h,registerchange);
 }
 
 
-void hk_visible::set_position(unsigned int x, unsigned int y, bool registerchange)
+void hk_visible::set_position(unsigned int xv, unsigned int yv, bool registerchange)
 {
-    set_size(x,y,width(),height(),registerchange);
+    set_size(xv,yv,width(),height(),registerchange);
 }
 
 
@@ -348,7 +362,7 @@ if (p_presentation && p_presentation->mode()==hk_presentation::viewmode)
 }
 
 
-unsigned int hk_visible::height() const
+unsigned int hk_visible::height() 
 {
 if (p_presentation && p_presentation->mode()==hk_presentation::viewmode)
     return p_viewdata->p_height;
@@ -357,7 +371,7 @@ if (p_presentation && p_presentation->mode()==hk_presentation::viewmode)
 }
 
 
-bool    hk_visible::widget_specific_coordinates(unsigned int px,unsigned int py,unsigned int pwidth,unsigned int pheight)
+bool    hk_visible::widget_specific_coordinates(unsigned int /*px*/,unsigned int /*py*/,unsigned int /*pwidth*/,unsigned int /*pheight*/)
 {
     return true;
 }
@@ -443,8 +457,8 @@ if (f &&f->get_visible(i))
   }
   else
   {
-  hk_report* f=dynamic_cast<hk_report*> (p_presentation);
-  if (f &&f->get_reportdatavisible(i))
+  hk_report* r=dynamic_cast<hk_report*> (p_presentation);
+  if (r &&r->get_reportdatavisible(i))
   {
     if (a==interactive)show_warningmessage(replace_all("%1",hk_translate("Identifier '%1' already in use"),i));
     return false;
@@ -608,49 +622,49 @@ void hk_visible::loaddata(const hk_string& definition)
 }
 
 
-void hk_visible::has_changed(bool registerchange,enum_has_changed forcesetting)
+void hk_visible::has_changed(bool registerchange,enum_has_changed f)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_visible::has_changed(bool registerchange)");
 #endif
     if ( (!registerchange)||(p_presentation==NULL)||p_private->p_neverregisterchange) return;
 
-    p_presentation->set_has_changed(forcesetting);
+    p_presentation->set_has_changed(f);
 }
 
 
-void hk_visible::set_font(const hk_string& font,int size,bool registerchange)
+void hk_visible::set_font(const hk_string& f,int s,bool registerchange)
 {
-   set_font(font,size,registerchange,false);
+   set_font(f,s,registerchange,false);
 }
 
 
-void hk_visible::set_font(const hk_string& font,int size,bool registerchange,bool force_setting)
+void hk_visible::set_font(const hk_string& f,int s,bool registerchange,bool force_setting)
 {
     if (allow_datachanging(force_setting))
     {
-    p_designdata->p_font.set_font(font,size);
+    p_designdata->p_font.set_font(f,s);
     }
-    p_viewdata->p_font.set_font(font,size);
+    p_viewdata->p_font.set_font(f,s);
     has_changed(registerchange);
     widget_specific_font_changed();
 }
 
 
-void hk_visible::set_font(const hk_font& font,bool registerchange)
+void hk_visible::set_font(const hk_font& f,bool registerchange)
 {
-  set_font(font,registerchange,false);
+  set_font(f,registerchange,false);
 }
 
 
 
-void hk_visible::set_font(const hk_font& font,bool registerchange,bool force_setting)
+void hk_visible::set_font(const hk_font& f,bool registerchange,bool force_setting)
 {
     if (allow_datachanging(force_setting))
     {
-    p_designdata->p_font=font;
+    p_designdata->p_font=f;
     }
-    p_viewdata->p_font=font;
+    p_viewdata->p_font=f;
     has_changed(registerchange);
     widget_specific_font_changed();
 }
@@ -672,31 +686,31 @@ void hk_visible::set_neverregisterchange(bool n)
    set_neverregisterchange(n,false);
 }
 
-void hk_visible::set_neverregisterchange(bool n,bool force_setting)
+void hk_visible::set_neverregisterchange(bool n,bool /*force_setting*/)
 {
 
     p_private->p_neverregisterchange=n;
 }
 
 
-void hk_visible::set_datetimeformat(const hk_string& datetime,const hk_string& date, const hk_string&  time)
+void hk_visible::set_datetimeformat(const hk_string& dt,const hk_string& d, const hk_string&  t)
 {
-   set_datetimeformat(datetime,date,time,false);
+   set_datetimeformat(dt,d,t,false);
 }
 
 
 
-void hk_visible::set_datetimeformat(const hk_string& datetime,const hk_string& date, const hk_string&  time,bool force_setting)
+void hk_visible::set_datetimeformat(const hk_string& dt,const hk_string& d, const hk_string&  t,bool force_setting)
 {
     if (allow_datachanging(force_setting))
     {
-    p_designdata->p_datetimeformat=datetime;
-    p_designdata->p_dateformat=date;
-    p_designdata->p_timeformat=time;
+    p_designdata->p_datetimeformat=dt;
+    p_designdata->p_dateformat=d;
+    p_designdata->p_timeformat=t;
     }
-    p_viewdata->p_datetimeformat=datetime;
-    p_viewdata->p_dateformat=date;
-    p_viewdata->p_timeformat=time;
+    p_viewdata->p_datetimeformat=dt;
+    p_viewdata->p_dateformat=d;
+    p_viewdata->p_timeformat=t;
 }
 
 
@@ -758,19 +772,98 @@ hk_string hk_visible::replace(const hk_string& where)
 #ifdef HK_DEBUG
     hkdebug("hk_visible::replace");
 #endif
-    hk_string p_buffer;
-    p_buffer=replace_all("%COUNTS_AS%",where,longint2string(counts_as()));
-    hk_datetime dt;
-    dt.set_now();
-    p_buffer=replace_all("%TIME%",p_buffer,dt.time_asstring());
-    p_buffer=replace_all("%DATE%",p_buffer,dt.date_asstring());
-    p_buffer=replace_all("%FGRED%",p_buffer,format_standard_number((p_presentation && p_presentation->mode()==hk_presentation::viewmode)?p_viewdata->p_foregroundcolour.red():p_designdata->p_foregroundcolour.red(),0,0));
-    p_buffer=replace_all("%FGGREEN%",p_buffer,format_standard_number((p_presentation && p_presentation->mode()==hk_presentation::viewmode)?p_viewdata->p_foregroundcolour.green():p_designdata->p_foregroundcolour.green(),0,0));
-    p_buffer=replace_all("%FGBLUE%",p_buffer,format_standard_number((p_presentation && p_presentation->mode()==hk_presentation::viewmode)?p_viewdata->p_foregroundcolour.blue():p_designdata->p_foregroundcolour.blue(),0,0));
-    p_buffer=replace_all("%BGRED%",p_buffer,format_standard_number((p_presentation && p_presentation->mode()==hk_presentation::viewmode)?p_viewdata->p_backgroundcolour.red():p_designdata->p_backgroundcolour.red(),0,0));
-    p_buffer=replace_all("%BGGREEN%",p_buffer,format_standard_number((p_presentation && p_presentation->mode()==hk_presentation::viewmode)?p_viewdata->p_backgroundcolour.green():p_designdata->p_backgroundcolour.green(),0,0));
-    p_buffer=replace_all("%BGBLUE%",p_buffer,format_standard_number((p_presentation && p_presentation->mode()==hk_presentation::viewmode)?p_viewdata->p_backgroundcolour.blue():p_designdata->p_backgroundcolour.blue(),0,0));
-    return p_buffer;
+
+    enum
+    {
+	S_START,S_IN_TAG,S_MAYBE_IN_FIELDNAME
+    } state=S_START;
+
+hk_string::size_type offset=0;
+hk_string result;
+hk_string tag;
+while (offset<where.size())
+{
+	hk_string xc(1,where[offset]);
+	switch (state)
+	{
+	case S_START:   if (xc=="%")
+			{
+			  state=S_IN_TAG;
+			  tag="";
+			}
+			else
+			if (xc=="#")
+			{
+			  state=S_MAYBE_IN_FIELDNAME;
+			  tag="";
+			}
+			else result+=xc;
+			break;
+	case S_IN_TAG: {
+	                 if (xc=="%")
+	                 {
+	                   state=S_START;
+	                   if (tag.size()>0)
+	                   {
+	                   bool ok;
+	                   hk_string v=tag_value(tag,ok);
+	                   if (ok) result+=v;
+	                   else result+="%"+tag+"%";
+	                   }
+	                   else result+="%%";
+	                 }
+	                 else
+	                 if (isspace(xc[0]))
+	                 {
+	                 tag+=xc;
+	                 state=S_START;
+	                 result+="%"+tag;
+	                 }
+	                 else
+	                 tag+=xc;
+			break;
+			}
+	case S_MAYBE_IN_FIELDNAME: {
+	                 if (xc=="#")
+	                 {
+	                   state=S_START;
+	                   if (tag.size()>0)
+	                   {
+	                   bool ok;
+	                   hk_string v=column_value(tag,ok);
+	                   if (ok) result+=v;
+	                   else result+="#"+tag+"#";
+	                   }
+	                   else result+="##";
+	                 }
+	                 else
+	                 if (xc=="\n")
+	                 {
+	                 tag+=xc;
+	                 state=S_START;
+	                 result+="#"+tag;
+	                 }
+	                 else
+	                 if (xc=="%")
+	                 {
+	                 --offset;
+	                 state=S_START;
+	                 result+="#"+tag;
+	                 }
+	                 else
+	                 tag+=xc;
+	                 break;
+			}
+	default:;
+	}
+++offset;
+}
+if (state==S_MAYBE_IN_FIELDNAME)
+   result+="#"+tag;
+else
+if (state==S_IN_TAG)
+   result+="%"+tag;
+return result;
 
 }
 
@@ -1313,9 +1406,9 @@ void hk_visible::hide_widget(void)
 
 }
 
-void hk_visible::close_widget(void)
+bool hk_visible::close_widget(void)
 {
-
+return true;
 }
 
 
@@ -1363,3 +1456,106 @@ bool hk_visible::move_buddylabel(void) const
 
 
 
+int hk_visible::tag_number(const hk_string& tag)
+{
+  tagtype::iterator it=p_private->p_tags.find(tag);
+  if (it!=p_private->p_tags.end())
+    { 
+   int result =(*it).second;
+     return result;
+    }
+  else
+ {
+ return -1;
+ }
+}
+
+hk_string hk_visible::column_value(const hk_string& ,bool& ok)
+{
+ok=false;
+return "";
+}
+
+
+
+hk_string hk_visible::tag_value(int tagnumber, bool& ok)
+{
+  ok=true;
+    hk_datetime dt;
+    dt.set_now();
+    hk_string result;
+  if (tagnumber==p_private->tag_counts_as)
+    {
+     result=longint2string(counts_as());
+     return result;
+    }
+  if (tagnumber==p_private->tag_time) 
+    {
+     result= dt.time_asstring();
+     return result;
+    }
+  if (tagnumber==p_private->tag_date)
+  {
+   result=dt.date_asstring();
+   return result;
+  }
+  if (tagnumber==p_private->tag_fgred)
+  {
+   result=format_standard_number((p_presentation && p_presentation->mode()==hk_presentation::viewmode)?p_viewdata->p_foregroundcolour.red():p_designdata->p_foregroundcolour.red(),0,0) ;
+
+  return result;
+  }
+  if (tagnumber==p_private->tag_fggreen)
+  {
+   result=format_standard_number((p_presentation && p_presentation->mode()==hk_presentation::viewmode)?p_viewdata->p_foregroundcolour.green():p_designdata->p_foregroundcolour.green(),0,0) ;
+
+   return result;
+  }
+  if (tagnumber==p_private->tag_fgblue)
+  {
+   result=format_standard_number((p_presentation && p_presentation->mode()==hk_presentation::viewmode)?p_viewdata->p_foregroundcolour.blue():p_designdata->p_foregroundcolour.blue(),0,0);
+
+  return result;
+  }
+  if (tagnumber==p_private->tag_bgred)
+  {
+   result=format_standard_number((p_presentation && p_presentation->mode()==hk_presentation::viewmode)?p_viewdata->p_backgroundcolour.red():p_designdata->p_backgroundcolour.red(),0,0);
+
+   return result;
+  }
+  if (tagnumber==p_private->tag_bggreen)
+  {
+   result=format_standard_number((p_presentation && p_presentation->mode()==hk_presentation::viewmode)?p_viewdata->p_backgroundcolour.green():p_designdata->p_backgroundcolour.green(),0,0);
+
+   return result;
+  }
+  if (tagnumber==p_private->tag_bgblue)
+  {
+   result= format_standard_number((p_presentation && p_presentation->mode()==hk_presentation::viewmode)?p_viewdata->p_backgroundcolour.blue():p_designdata->p_backgroundcolour.blue(),0,0);
+
+   return result;
+  }
+  ok=false;
+  return "";
+}
+
+hk_string hk_visible::tag_value(const hk_string& tag, bool& ok)
+{
+
+  return tag_value(tag_number(tag),ok);
+}
+
+int hk_visible::register_tag(const hk_string& tag)
+{
+  tagtype::iterator it=p_private->p_tags.find(tag);
+  if (it!=p_private->p_tags.end())
+    {
+     return (*it).second;
+    }
+  int pos=p_private->p_tags.size(); 
+  p_private->p_tags.insert(tagtype::value_type(tag,pos));
+  return pos;
+}
+
+
+
