@@ -27,7 +27,7 @@ class hk_tabvisible;
 /**
  *
  *@short base class for visible widgets
- *@version $Revision: 1.66 $
+ *@version $Revision: 1.68 $
  *@author Horst Knorr (hk_classes@knoda.org)
  *
  *base class for visible widgets.
@@ -61,7 +61,7 @@ class hk_visible:public hk_class
         unsigned int    x(void) const;
         unsigned int    y(void) const;
         unsigned int    width(void)const;
-        unsigned int    height(void) const;
+        unsigned int    height(void) ;
 /**
  *sets the size and the position of the object.  In forms the coordinates are in a range from 0 to 10000 (100.00%)
      */
@@ -183,7 +183,7 @@ hk_string tooltip(void);
 
 virtual void show_widget(void);
 virtual void hide_widget(void);
-virtual void close_widget(void);
+virtual bool close_widget(void);
 
 
 
@@ -289,6 +289,12 @@ void set_movebuddylabel(bool);
 bool move_buddylabel(void) const;
 
 
+int tag_number(const hk_string&);
+virtual hk_string tag_value(int tagnumber, bool& ok);
+virtual hk_string column_value(const hk_string& colname,bool& ok);
+hk_string tag_value(const hk_string&, bool& ok);
+int register_tag(const hk_string&);
+
     protected:
         virtual void        widget_specific_form_resizes(void);
         virtual void        widget_specific_font_changed(void);
