@@ -20,6 +20,7 @@
 
 #define MAXLEN 1024
 
+
 hk_firebirddatasource::hk_firebirddatasource(hk_firebirddatabase* d,hk_presentation* p):hk_storagedatasource(d,p)
 {
 #ifdef HK_DEBUG
@@ -333,7 +334,7 @@ bool hk_firebirddatasource::datasource_open(void)
      }
    }
 
-   if (isc_dsql_prepare(p_status,&p_transaction,&p_stmt,0,(char*)p_sql.c_str(),SQL_DIALECT_V6,p_sqlhandle))
+   if (isc_dsql_prepare(p_status,&p_transaction,&p_stmt,0,const_cast<char*>(p_sql.c_str()),SQL_DIALECT_V6,p_sqlhandle))
    {
    	set_error();
    	free_handles();
@@ -374,11 +375,11 @@ bool hk_firebirddatasource::datasource_open(void)
    {
      short length,alignment;
      length=alignment=var->sqllen;
-     short type=var->sqltype & ~1;
+     short tp=var->sqltype & ~1;
 
-     if (type == SQL_TEXT)
+     if (tp == SQL_TEXT)
      alignment = 1;
-     else if (type == SQL_VARYING)
+     else if (tp == SQL_VARYING)
         {
             length += sizeof (short) + 1;
             alignment = sizeof (short);
@@ -387,10 +388,14 @@ bool hk_firebirddatasource::datasource_open(void)
         **  So the output buffer values must be placed on
         **  word boundaries where appropriate
         */
+#ifdef FB_ALIGN
         offset = FB_ALIGN(offset, alignment);
+#endif        
         var->sqldata = (char *) buffer + offset;
         offset += length;
+#ifdef FB_ALIGN        
         offset = FB_ALIGN(offset, sizeof (short));
+#endif
         var->sqlind = (short*) ((char *) buffer + offset);
         offset += sizeof  (short);
 
@@ -531,7 +536,11 @@ if (fetchstatus!=0) return false;
 	       				if (!isc_open_blob(p_status,&h,&p_transaction,&blob_handle,&blob_id))
 	       				{
 	       				//first query the total size of the blob
-	       				SLONG max_size=0;
+	       				#ifdef HAVE_FIREBIRD2
+					ISC_LONG max_size=0;
+					#else
+					SLONG max_size=0;
+					#endif
 	       				char blob_items[]={isc_info_blob_total_length};
 	       				char res_buffer[20],*p,item;
 	       				isc_blob_info(p_status,&blob_handle,sizeof(blob_items),blob_items,sizeof(res_buffer),res_buffer);
@@ -633,10 +642,20 @@ void hk_firebirddatasource::free_handles(void)
 
 void hk_firebirddatasource::set_error(void)
 {
+#ifdef HAVE_FIREBIRD2
+  const ISC_STATUS* pvector=p_status;
+#else
   long* pvector=p_status;
+#endif
   char msg[512];
   hk_string errors;
-  while (isc_interprete(msg,&pvector))
+  while (
+#ifdef HAVE_FIREBIRD2
+  fb_interpret(msg,sizeof(msg),&pvector)
+#else
+  isc_interprete(msg,&pvector)
+#endif 
+  )
   {
     errors+=msg;
     errors+="\n";
@@ -666,18 +685,18 @@ isc_tr_handle transaction=NULL;
         cerr <<"vor fields"<<endl;
         while ( it!=p_columns->end() )
         {
-            hk_column* x=*it;
+            hk_column* xc=*it;
             ++it;
-            if (x!=NULL)
-                if (x->has_changed())
+            if (xc!=NULL)
+                if (xc->has_changed())
             {
                 if (fields.size()==0) fields=" (";
                 else
                 {
                     fields+=" , ";
                 }
-                fields+=p_identifierdelimiter+x->name()+p_identifierdelimiter;
-                if (x->columntype()==hk_column::binarycolumn||x->columntype()==hk_column::memocolumn)
+                fields+=p_identifierdelimiter+xc->name()+p_identifierdelimiter;
+                if (xc->columntype()==hk_column::binarycolumn||xc->columntype()==hk_column::memocolumn)
                    ++count_changed_fields;
             }
         }
@@ -689,9 +708,9 @@ isc_tr_handle transaction=NULL;
 	it=p_columns->begin();
         while ( it!=p_columns->end() )
         {
-            hk_column* x=*it;
+            hk_column* xc=*it;
             ++it;
-            if (x->has_changed())
+            if (xc->has_changed())
             {
                 if (inssql.size()==0)
                 {
@@ -704,17 +723,17 @@ isc_tr_handle transaction=NULL;
                 }
 
 //write data
-                if((x->transformed_changed_data()->data!=NULL))
-                {   cerr <<"column:"<<x->name()<<" type="<<x->columntype()<<" is Binary:"<<(x->columntype()==hk_column::binarycolumn?"ja":"nein")<<endl;
+                if((xc->transformed_changed_data()->data!=NULL))
+                {   cerr <<"column:"<<xc->name()<<" type="<<xc->columntype()<<" is Binary:"<<(xc->columntype()==hk_column::binarycolumn?"ja":"nein")<<endl;
 
-		    if (x->columntype()==hk_column::binarycolumn||x->columntype()==hk_column::memocolumn)
+		    if (xc->columntype()==hk_column::binarycolumn||xc->columntype()==hk_column::memocolumn)
 		    {
 			inssql+=" ? ";
 		    }
 		    else
 		    {
-			hk_string tf(x->transformed_changed_data()->data,x->transformed_changed_data()->length);
-			inssql+=x->get_delimiter()+tf+x->get_delimiter();
+			hk_string tf(xc->transformed_changed_data()->data,xc->transformed_changed_data()->length);
+			inssql+=xc->get_delimiter()+tf+xc->get_delimiter();
 		    }
                 }
                 else
@@ -764,12 +783,12 @@ isc_tr_handle transaction=NULL;
 	int c=0;
         while ( it!=p_columns->end() )
         {
-            hk_column* x=*it;
+            hk_column* xc=*it;
             ++it;
 
-            if (x->has_changed()
-                &&(x->transformed_changed_data()->data!=NULL)
-                &&(x->columntype()==hk_column::binarycolumn||x->columntype()==hk_column::memocolumn))
+            if (xc->has_changed()
+                &&(xc->transformed_changed_data()->data!=NULL)
+                &&(xc->columntype()==hk_column::binarycolumn||xc->columntype()==hk_column::memocolumn))
                 {
                   if (isc_create_blob(p_status,&h,&transaction,&blob_handle[c],&blob_id[c]))
    			{
@@ -780,8 +799,8 @@ isc_tr_handle transaction=NULL;
    			}
    			int s=0;
    		// Now writing data in chunks
-   		char* dp=x->transformed_changed_data()->data;
-   		unsigned long int dl=x->transformed_changed_data()->length;
+   		char* dp=xc->transformed_changed_data()->data;
+   		unsigned long int dl=xc->transformed_changed_data()->length;
    		int segmentsize=dl>32767?32767:dl;
    		while (segmentsize>0)
    		{
@@ -805,14 +824,14 @@ isc_tr_handle transaction=NULL;
 		 c++;
                 }
         } // end while p_columns
-	bool result=true;
-        if (isc_dsql_execute_immediate(p_status,&h,&transaction,0,(char*)inssql.c_str(),SQL_DIALECT_V6,xsqlda))
+	bool rslt=true;
+        if (isc_dsql_execute_immediate(p_status,&h,&transaction,0,const_cast<char*>(inssql.c_str()),SQL_DIALECT_V6,xsqlda))
    			{
    			  set_error();
-   			  result= false;
+   			  rslt= false;
    			}
 
-                if (result)
+                if (rslt)
                 {
 #ifdef HK_DEBUG
                     hkdebug("Einfügen hat funktioniert");
@@ -831,7 +850,7 @@ isc_tr_handle transaction=NULL;
                     transaction_commit();
                     goto_last();
                     inform_visible_objects_row_add();
-		    result=true;
+		    rslt=true;
                 }
                 else
                 {
@@ -841,7 +860,7 @@ isc_tr_handle transaction=NULL;
                     transaction_rollback();
                     hk_string reason=replace_all("%NAME%",hk_translate("Table %NAME%: Row could NOT be inserted!"),name())+"\n"+hk_translate("Servermessage: ")+database()->connection()->last_servermessage();
                     if (interaction==interactive) show_warningmessage(reason);
-		    result=false;
+		    rslt=false;
                 }
 		execute_visible_object_after_insert();
           free (xsqlda);
@@ -901,10 +920,10 @@ list<hk_column*>::iterator it=p_columns->begin();
 	bool hchanged=false;
        while ( it!=p_columns->end() )
         {
-            hk_column* x=*it;
+            hk_column* xc=*it;
             ++it;
 			// Figure out the column type
-            if (x->has_changed())
+            if (xc->has_changed())
             {   hchanged=true;
                 if (upsql.size()==0)
                 {
@@ -914,11 +933,11 @@ list<hk_column*>::iterator it=p_columns->begin();
                 {
                     upsql+=" , ";
                 }
-		upsql+=p_identifierdelimiter+x->name()+p_identifierdelimiter+" = ";
-                if (x->transformed_changed_data()->data)
+		upsql+=p_identifierdelimiter+xc->name()+p_identifierdelimiter+" = ";
+                if (xc->transformed_changed_data()->data)
                 {
 
-		    if (x->columntype()==hk_column::binarycolumn||x->columntype()==hk_column::memocolumn)
+		    if (xc->columntype()==hk_column::binarycolumn||xc->columntype()==hk_column::memocolumn)
 		    {
 			upsql+=" ? ";
 			++count_changed_fields;
@@ -926,8 +945,8 @@ list<hk_column*>::iterator it=p_columns->begin();
 		    }
 		    else
 		    {
-			hk_string tf(x->transformed_changed_data()->data,x->transformed_changed_data()->length);
-			upsql+=x->get_delimiter()+tf+x->get_delimiter();
+			hk_string tf(xc->transformed_changed_data()->data,xc->transformed_changed_data()->length);
+			upsql+=xc->get_delimiter()+tf+xc->get_delimiter();
 		    }
 
 
@@ -990,12 +1009,12 @@ list<hk_column*>::iterator it=p_columns->begin();
 	int c=0;
         while ( it!=p_columns->end() )
         {
-            hk_column* x=*it;
+            hk_column* xc=*it;
             ++it;
 
-            if (x->has_changed()
-                &&(x->transformed_changed_data()->data!=NULL)
-                &&(x->columntype()==hk_column::binarycolumn||x->columntype()==hk_column::memocolumn))
+            if (xc->has_changed()
+                &&(xc->transformed_changed_data()->data!=NULL)
+                &&(xc->columntype()==hk_column::binarycolumn||xc->columntype()==hk_column::memocolumn))
                 {
                   if (isc_create_blob(p_status,&h,&transaction,&blob_handle[c],&blob_id[c]))
    			{
@@ -1006,8 +1025,8 @@ list<hk_column*>::iterator it=p_columns->begin();
    			}
    			int s=0;
    		// Now writing data in chunks
-   		char* dp=x->transformed_changed_data()->data;
-   		unsigned long int dl=x->transformed_changed_data()->length;
+   		char* dp=xc->transformed_changed_data()->data;
+   		unsigned long int dl=xc->transformed_changed_data()->length;
    		int segmentsize=dl>32767?32767:dl;
    		while (segmentsize>0)
    		{
@@ -1032,7 +1051,7 @@ list<hk_column*>::iterator it=p_columns->begin();
                 }
         } // end while p_columns
 	bool result=true;
-        if (isc_dsql_execute_immediate(p_status,&h,&transaction,0,(char*)upsql.c_str(),SQL_DIALECT_V6,xsqlda))
+        if (isc_dsql_execute_immediate(p_status,&h,&transaction,0,const_cast<char*>(upsql.c_str()),SQL_DIALECT_V6,xsqlda))
    			{
    			  set_error();
    			  result= false;
