@@ -64,12 +64,17 @@ bool  hk_mysqlconnection::driver_specific_connect()
 #endif
 
     char* db=0;
-    char* xunix_port=0;
     if (!p_connected)
     {
         p_SQL_Connection=mysql_init(p_SQL_Connection);
-//cout <<"MYSQL TCP PORT:" <<tcp_port()<<endl;
-        p_connected=mysql_real_connect(p_SQL_Connection,host().size()>0?host().c_str():NULL,user().c_str(),password().c_str(),db,tcp_port(),xunix_port,0);
+        mysql_options(p_SQL_Connection,MYSQL_READ_DEFAULT_GROUP,"hk_classes");
+        p_connected=mysql_real_connect(p_SQL_Connection,
+         host().size()>0?host().c_str():NULL
+        ,user().c_str()
+        ,password().c_str()
+        ,db,tcp_port()
+        ,NULL
+        ,0);
         if (!p_connected)
         {servermessage();
             mysql_close(p_SQL_Connection);
@@ -147,6 +152,7 @@ hk_database* hk_mysqlconnection::driver_specific_new_database(void)
 bool hk_mysqlconnection::server_supports(support_enum t) const
 {
  bool supports_views=false;
+ bool supports_union=false;
  if ( database() )
  {
    switch (t)
@@ -154,6 +160,7 @@ bool hk_mysqlconnection::server_supports(support_enum t) const
    case SUPPORTS_VIEWS:
    case SUPPORTS_NEW_VIEW:
    case SUPPORTS_ALTER_VIEW:
+   case SUPPORTS_SQL_UNION:
    {
    hk_datasource* r=database()->new_resultquery();
    if (r)
@@ -165,7 +172,9 @@ bool hk_mysqlconnection::server_supports(support_enum t) const
      hk_column* c=r->column_by_name("v");
      if (c)
       {
-        supports_views=(c->asstring()>"5.0.0");
+        hk_string version=c->asstring();
+        supports_views=(version>"5.0.0");
+        supports_union=(version>"4.0.0");
       }
    }
 
@@ -183,6 +192,7 @@ bool hk_mysqlconnection::server_supports(support_enum t) const
 	case SUPPORTS_NEW_VIEW:
 	case SUPPORTS_ALTER_VIEW:
 	case SUPPORTS_DELETE_VIEW: return supports_views;
+	case SUPPORTS_SQL_UNION: return supports_union;
         case SUPPORTS_REFERENTIALINTEGRITY:
         case SUPPORTS_TRANSACTIONS:
 	case SUPPORTS_RENAME_DATABASE:
