@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.26 $
+//$Revision: 1.27 $
 #include "hk_mysqltable.h"
 #include "hk_mysqldatabase.h"
 #include "hk_actionquery.h"
@@ -26,7 +26,7 @@ hk_datasource::enum_datasourcetypes hk_mysqltable::type() const
 }
 
 
-bool hk_mysqltable::driver_specific_name(const hk_string& n)
+bool hk_mysqltable::driver_specific_name(const hk_string& )
 {
     return true;
 }
@@ -278,7 +278,7 @@ hk_string  hk_mysqltable::internal_alter_fields_arguments(void)
     if (p_altercolumns.size()==0)return "";
     char* m= new char[50];
     hk_string result;
-    hk_string name;
+    hk_string nm;
     list<class_altercolumns>::iterator it=p_altercolumns.begin();
     while (it!=p_altercolumns.end())
     {
@@ -291,9 +291,9 @@ hk_string  hk_mysqltable::internal_alter_fields_arguments(void)
             result+=" CHANGE COLUMN ";
             result+=p_identifierdelimiter+(*it).name+p_identifierdelimiter;
             result+=" ";
-            if ((*it).newname=="HK_NULL") name=(*it).name;
-            else name=(*it).newname;
-            result+=p_identifierdelimiter+name+p_identifierdelimiter;
+            if ((*it).newname=="HK_NULL") nm=(*it).name;
+            else nm=(*it).newname;
+            result+=p_identifierdelimiter+nm+p_identifierdelimiter;
             result+=" ";
             hk_column::enum_columntype newcolumntype=(*it).type;
             if (newcolumntype==hk_column::othercolumn) newcolumntype=c->columntype();
