@@ -93,7 +93,7 @@ list<hk_column*>* hk_odbcdatasource::driver_specific_columns(void)
             return p_columns;
         }
         hk_string sql_string= "SELECT * FROM "+p_identifierdelimiter+p_name+p_identifierdelimiter+" WHERE 1=0";
-        ret= SQLExecDirect(p_result ,(SQLCHAR*)(sql_string.c_str()) ,SQL_NTS);
+        ret= SQLExecDirect(p_result ,(SQLCHAR*)const_cast<char*>((sql_string.c_str())) ,SQL_NTS);
         if (ret!=SQL_SUCCESS)
         {cerr <<"hk_odbcdatasource::driver_specific_columns : could not select fields with 'WHERE 1=0'"<<endl;
             clear_result();
@@ -274,15 +274,15 @@ bool hk_odbcdatasource::driver_specific_enable(void)
 	  ret=SQLGetTypeInfo(p_result,SQL_ALL_TYPES);
 	else
 	if (value=="PRIMARYKEYS")
-	ret= SQLPrimaryKeys(p_result,0,0,0,0 ,(SQLCHAR*)(value2.c_str()) ,SQL_NTS);
+	ret= SQLPrimaryKeys(p_result,0,0,0,0 ,(SQLCHAR*)const_cast<char*>((value2.c_str())) ,SQL_NTS);
 	else
 	if (value=="STATISTICS")
-	ret= SQLStatistics( p_result, 0, 0, 0, 0, (SQLCHAR*)(value2.c_str()), SQL_NTS, 0, 0 );
+	ret= SQLStatistics( p_result, 0, 0, 0, 0, (SQLCHAR*)const_cast<char*>((value2.c_str())), SQL_NTS, 0, 0 );
 	else
 	if (value=="COLUMNS")
-	ret= SQLColumns( p_result, 0, 0, 0, 0,(SQLCHAR*) value2.c_str(), SQL_NTS, 0, 0 );
+	ret= SQLColumns( p_result, 0, 0, 0, 0,(SQLCHAR*) const_cast<char*>(value2.c_str()), SQL_NTS, 0, 0 );
 	else
-	ret= SQLExecDirect(p_result ,(SQLCHAR*)(p_sql.c_str()) ,SQL_NTS);
+	ret= SQLExecDirect(p_result ,(SQLCHAR*)const_cast<char*>((p_sql.c_str())) ,SQL_NTS);
         if (ret!=SQL_SUCCESS)
         {
             clear_result();
@@ -501,7 +501,7 @@ bool hk_odbcdatasource::driver_specific_batch_enable(void)
             clear_result();
             return false;
         }
-        ret= SQLExecDirect(p_result ,(SQLCHAR*)(p_sql.c_str()) ,SQL_NTS);
+        ret= SQLExecDirect(p_result ,(SQLCHAR*)const_cast<char*>((p_sql.c_str())) ,SQL_NTS);
         if (ret!=SQL_SUCCESS)
         {
             clear_result();
