@@ -8,7 +8,7 @@
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 // ****************************************************************************
-//$Revision: 1.18 $
+//$Revision: 1.19 $
 #include "hk_odbctable.h"
 #include "hk_odbcdatabase.h"
 #include "hk_odbcconnection.h"
@@ -30,7 +30,7 @@ hk_datasource::enum_datasourcetypes hk_odbctable::type() const
 }
 
 
-bool hk_odbctable::driver_specific_name(const hk_string& n)
+bool hk_odbctable::driver_specific_name(const hk_string& )
 {
     return true;
 }
@@ -151,7 +151,7 @@ hk_string hk_odbctable::internal_new_fields_arguments(bool alter)
 }
 
 
-hk_string hk_odbctable::field2string(hk_column::enum_columntype f,const hk_string& m)
+hk_string hk_odbctable::field2string(hk_column::enum_columntype f,const hk_string& )
 {
 #ifdef HK_DEBUG
     hkdebug("hk_odbctable::field2string");
@@ -298,7 +298,7 @@ hk_string  hk_odbctable::internal_alter_fields_arguments(void)
     if (p_altercolumns.size()==0)return "";
     char* m= new char[50];
     hk_string result;
-    hk_string name;
+    hk_string nm;
     list<class_altercolumns>::iterator it=p_altercolumns.begin();
     while (it!=p_altercolumns.end())
     {
@@ -311,9 +311,9 @@ hk_string  hk_odbctable::internal_alter_fields_arguments(void)
             result+=" CHANGE COLUMN ";
             result+=(*it).name;
             result+=" ";
-            if ((*it).newname=="HK_NULL") name=(*it).name;
-            else name=(*it).newname;
-            result+=name;
+            if ((*it).newname=="HK_NULL") nm=(*it).name;
+            else nm=(*it).newname;
+            result+=nm;
             result+=" ";
             hk_column::enum_columntype newcolumntype=(*it).type;
             if (newcolumntype==hk_column::othercolumn) newcolumntype=c->columntype();
@@ -414,7 +414,7 @@ list<hk_datasource::indexclass>* hk_odbctable::driver_specific_indices(void)
         SQLFreeHandle(SQL_HANDLE_STMT,result);
     SQLAllocHandle(SQL_HANDLE_STMT,p_odbcdatabase->connection()->connectionhandle(),&result);
 
-    ret=SQLPrimaryKeys( result, 0, 0, 0, 0, (SQLCHAR*)name().c_str(), SQL_NTS);
+    ret=SQLPrimaryKeys( result, 0, 0, 0, 0, (SQLCHAR*)const_cast<char*>(name().c_str()), SQL_NTS);
 cerr <<endl<<"PRIMARYKEYS werden ermittelt"<<endl<<endl;
     if (ret==SQL_SUCCESS)
     {  cerr <<"innerhalb Primarykeys"<<endl;
@@ -510,7 +510,7 @@ bool hk_odbctable::driver_specific_create_columns(void)
 //  return true;
     SQLHSTMT r;
     SQLRETURN ret= SQLAllocHandle(SQL_HANDLE_STMT,p_odbcdatabase->connection()->connectionhandle(),&r);
-    ret=SQLColumns( r, 0, 0, 0, 0,(SQLCHAR*) name().c_str(), SQL_NTS, 0, 0 );
+    ret=SQLColumns( r, 0, 0, 0, 0,(SQLCHAR*) const_cast<char*>(name().c_str()), SQL_NTS, 0, 0 );
     SQLINTEGER nCol=0;
     SQLCHAR szColumnName[101]="";
 
@@ -543,7 +543,7 @@ bool hk_odbctable::driver_specific_create_columns(void)
 
 //now set primary key
     ret= SQLAllocHandle(SQL_HANDLE_STMT,p_odbcdatabase->connection()->connectionhandle(),&r);
-    ret=SQLPrimaryKeys( r, 0, 0, 0, 0,(SQLCHAR*) name().c_str(), SQL_NTS);
+    ret=SQLPrimaryKeys( r, 0, 0, 0, 0,(SQLCHAR*)const_cast<char*>( name().c_str()), SQL_NTS);
     nCol=0;
 
     ret = SQLFetch( r );
