@@ -122,7 +122,6 @@ vector<hk_string>* hk_postgresqlconnection::driver_specific_dblist(void)
 {
 
     PGresult  * Res;
-    unsigned int i;
     p_databaselist.erase(p_databaselist.begin(),p_databaselist.end());
 
     if (p_connected)
@@ -131,7 +130,7 @@ vector<hk_string>* hk_postgresqlconnection::driver_specific_dblist(void)
         Res=PQexec(dbhandler() , "SELECT datname FROM pg_database");
         if (  (PQresultStatus(Res)) == PGRES_TUPLES_OK )
         {
-            for (i=0 ; i < PQntuples(Res); i++)
+            for (int i=0 ; i < PQntuples(Res); i++)
             {
                 p_databaselist.insert(p_databaselist.end(), PQgetvalue(Res , i , 0) );
             }
