@@ -20,6 +20,29 @@
 hk_postgresqldatabase::hk_postgresqldatabase(hk_postgresqlconnection* c):hk_database(c)
 {
     p_postgresqlconnection=c;
+    p_systemdateformat="Y-M-D";
+    hk_datasource* d=driver_specific_new_resultquery(NULL);
+    if (d)
+    {
+    d->set_sql("show DateStyle",true);
+    d->enable();
+    hk_column* col=d->column_by_name("DateStyle");
+    if (col)
+    {
+      hk_string result=string2upper(col->asstring());
+      bool DMY=(result.find("DMY")!=hk_string::npos);
+      if (result.find("SQL")!=hk_string::npos)
+          {
+            p_systemdateformat=(DMY?"D/M/Y":"M/D/Y");
+          }
+      else 
+      if (result.find("GERMAN")!=hk_string::npos)
+      {
+        p_systemdateformat="D.M.Y";
+      }
+    }
+    delete d;
+    }
 }
 
 
@@ -31,7 +54,7 @@ hk_postgresqlconnection* hk_postgresqldatabase::connection(void)
 
 void hk_postgresqldatabase::driver_specific_tablelist(void)
 {
-    unsigned int i;
+
     p_tablelist.erase(p_tablelist.begin(),p_tablelist.end());
     if (p_postgresqlconnection!=NULL)
     {
@@ -42,7 +65,7 @@ void hk_postgresqldatabase::driver_specific_tablelist(void)
             PGresult* Res = PQexec(p_postgresqlconnection->dbhandler() , "select relname as name from pg_class,pg_namespace where relkind='r' and nspname!~'information_schema' and nspname!~'pg_catalog' and pg_class.relnamespace = pg_namespace.oid ORDER BY relname" );
             if (PQresultStatus(Res) == PGRES_TUPLES_OK)
             {
-                for (i=0; i<PQntuples(Res);i++)
+                for (long i=0; i<PQntuples(Res);i++)
                 {
                     p_tablelist.insert(p_tablelist.end(), PQgetvalue(Res ,i ,  0));
                 }
@@ -57,7 +80,6 @@ void hk_postgresqldatabase::driver_specific_tablelist(void)
 
 void hk_postgresqldatabase::driver_specific_viewlist(void)
 {
-    unsigned int i;
     p_viewlist.erase(p_viewlist.begin(),p_viewlist.end());
     if (p_postgresqlconnection!=NULL)
     {
@@ -68,7 +90,7 @@ void hk_postgresqldatabase::driver_specific_viewlist(void)
             PGresult* Res = PQexec(p_postgresqlconnection->dbhandler() , "select relname as name from pg_class,pg_namespace where relkind='v' and nspname!~'information_schema' and nspname!~'pg_catalog' and pg_class.relnamespace = pg_namespace.oid ORDER BY relname" );
             if (PQresultStatus(Res) == PGRES_TUPLES_OK)
             {
-                for (i=0; i<PQntuples(Res);i++)
+                for (long i=0; i<PQntuples(Res);i++)
                 {
                     p_viewlist.insert(p_viewlist.end(), PQgetvalue(Res ,i ,  0));
                 }
@@ -142,3 +164,7 @@ bool    hk_postgresqldatabase::driver_specific_rename_table(const hk_string& old
 
 
 
+hk_string hk_postgresqldatabase::systemdateformat(void)
+{
+return p_systemdateformat;
+}
