@@ -147,6 +147,8 @@ bool hk_sqliteconnection::server_supports(support_enum t) const
 	  case SUPPORTS_NONALPHANUM_FIELDNAMES:;
 	  case SUPPORTS_NONASCII_FIELDNAMES:;
 	  case SUPPORTS_SPACE_FIELDNAMES:;
+	  case SUPPORTS_SQL_JOINS:;
+	  case SUPPORTS_SQL_UNION:;
             return true;
         default : return false;
     }
@@ -177,7 +179,7 @@ bool hk_sqliteconnection::server_needs(need_enum t) const
 }
 
 
-bool hk_sqliteconnection::driver_specific_new_password(const hk_string& newpasswd)
+bool hk_sqliteconnection::driver_specific_new_password(const hk_string& /*newpasswd*/)
 {
 #ifdef HK_DEBUG
     hkdebug("hk_sqliteconnection::driver_specific_new_password");
@@ -239,11 +241,11 @@ bool    hk_sqliteconnection::create_database(const hk_string& dbase)
     return true;
 }
 
-bool    hk_sqliteconnection::delete_database(const hk_string& dbase)
+bool    hk_sqliteconnection::delete_database(const hk_string& dbase,enum_interaction c)
 {
     hk_string warning=hk_translate("Delete the database \"%DBNAME%\"?");
     warning=replace_all("%DBNAME%",warning,dbase);
-    if(!show_yesnodialog(warning,true)) return false;
+    if(c==interactive && !show_yesnodialog(warning,true)) return false;
 
     hk_url url=dbase;
     hk_string filename=url.directory().size()>0?dbase:databasepath()+"/"+dbase+".hk_sqlite";
