@@ -6,17 +6,17 @@ static char args_doc[]="DATASOURCE";
 static struct argp_option options[] =
 {
     DEFAULTPARAMETER,
-    {"filter",'f',"FILTER",0,"filter"},
-    {"query",'q',0,0,"if set the datasource is a query, else it is a table"},
-    {"noheader",13,0,0,"if set the column names will not be included in the first row"},
-    {"between",11,"BETWEEN",0,"column separator, default is ','"},
-    {"delimiter",12,"TEXTDELIMITER",0,"the text delimiter, default is '\"'"},
-    {"charset",'c',"CHARSET",0,"charset of the import file"},
-    {"locale",'l',"LOCALE",0,"locale of the import file, influences the number appearance"},
-    {"tf",14,"TIMEFORMAT",0,"time format"},
-    {"df",15,"DATEFORMAT",0,"date format"},
-    {"dtf",16,"DATETIMEFORMAT",0,"datetimeformat"},
-    {0}
+    {"filter",'f',"FILTER",0,"filter",0},
+    {"query",'q',0,0,"if set the datasource is a query, else it is a table",0},
+    {"noheader",13,0,0,"if set the column names will not be included in the first row",0},
+    {"between",11,"BETWEEN",0,"column separator, default is ','",0},
+    {"delimiter",12,"TEXTDELIMITER",0,"the text delimiter, default is '\"'",0},
+    {"charset",'c',"CHARSET",0,"charset of the import file",0},
+    {"locale",'o',"LOCALE",0,"locale of the import file, influences the number appearance",0},
+    {"tf",14,"TIMEFORMAT",0,"time format",0},
+    {"df",15,"DATEFORMAT",0,"date format",0},
+    {"dtf",16,"DATETIMEFORMAT",0,"datetimeformat",0},
+    {0,0,0,0,0,0}
 
 };
 
@@ -52,7 +52,7 @@ static error_t parse_options (int key,char* arg, struct argp_state* state)
         break;
         case 'c' : arguments->charset=arg;
         break;
-        case 'l' : arguments->locale=arg;
+        case 'o' : arguments->locale=arg;
         break;
         case 13 : arguments->noheader=true;
         break;
@@ -85,7 +85,7 @@ static error_t parse_options (int key,char* arg, struct argp_state* state)
 }
 
 
-static struct argp argstruct={options,parse_options,args_doc,doc};
+static struct argp argstruct={options,parse_options,args_doc,doc,0,0,0};
 
 void verify_arguments(csvargumentclass& arguments)
 {
@@ -111,10 +111,10 @@ void verify_arguments(csvargumentclass& arguments)
 int main(int argc, char** argv)
 {
     umask(0077);
+    hk_drivermanager d;
     csvargumentclass arguments;
     argp_parse(&argstruct,argc,argv,0,0, &arguments);
     verify_arguments(arguments);
-    hk_drivermanager d;
     hk_connection * c=d.new_connection(arguments.driver,hk_connection::noninteractive);
     if (!c)
     {
